(function(/*! Brunch !*/) {
  'use strict';

  var globals = typeof window !== 'undefined' ? window : global;
  if (typeof globals.require === 'function') return;

  var modules = {};
  var cache = {};

  var has = function(object, name) {
    return ({}).hasOwnProperty.call(object, name);
  };

  var expand = function(root, name) {
    var results = [], parts, part;
    if (/^\.\.?(\/|$)/.test(name)) {
      parts = [root, name].join('/').split('/');
    } else {
      parts = name.split('/');
    }
    for (var i = 0, length = parts.length; i < length; i++) {
      part = parts[i];
      if (part === '..') {
        results.pop();
      } else if (part !== '.' && part !== '') {
        results.push(part);
      }
    }
    return results.join('/');
  };

  var dirname = function(path) {
    return path.split('/').slice(0, -1).join('/');
  };

  var localRequire = function(path) {
    return function(name) {
      var dir = dirname(path);
      var absolute = expand(dir, name);
      return globals.require(absolute);
    };
  };

  var initModule = function(name, definition) {
    var module = {id: name, exports: {}};
    definition(module.exports, localRequire(name), module);
    var exports = cache[name] = module.exports;
    return exports;
  };

  var require = function(name) {
    var path = expand(name, '.');

    if (has(cache, path)) return cache[path];
    if (has(modules, path)) return initModule(path, modules[path]);

    var dirIndex = expand(path, './index');
    if (has(cache, dirIndex)) return cache[dirIndex];
    if (has(modules, dirIndex)) return initModule(dirIndex, modules[dirIndex]);

    throw new Error('Cannot find module "' + name + '"');
  };

  var define = function(bundle) {
    for (var key in bundle) {
      if (has(bundle, key)) {
        modules[key] = bundle[key];
      }
    }
  }

  globals.require = require;
  globals.require.define = define;
  globals.require.brunch = true;
})();

window.require.define({"test/controllers/main-controller-test": function(exports, require, module) {
  var Main;

  Main = require('controllers/main-controller');

  describe('Main', function() {
    return beforeEach(function() {
      return this.controller = new Main();
    });
  });
  
}});

window.require.define({"test/controllers/shout-controller-test": function(exports, require, module) {
  var Shout;

  Shout = require('controllers/shout-controller');

  describe('Shout', function() {
    return beforeEach(function() {
      return this.controller = new Shout();
    });
  });
  
}});

window.require.define({"test/models/birthdays-test": function(exports, require, module) {
  var Birthdays;

  Birthdays = require('models/birthdays');

  describe('Birthdays', function() {
    return beforeEach(function() {
      return this.model = new Birthdays();
    });
  });
  
}});

window.require.define({"test/models/shout-test": function(exports, require, module) {
  var Shout;

  Shout = require('models/shout');

  describe('Shout', function() {
    return beforeEach(function() {
      return this.model = new Shout();
    });
  });
  
}});

window.require.define({"test/test-helpers": function(exports, require, module) {
  var chai, sinonChai;

  chai = require('chai');

  sinonChai = require('sinon-chai');

  chai.use(sinonChai);

  module.exports = {
    expect: chai.expect,
    sinon: require('sinon')
  };
  
}});

window.require.define({"test/views/birthdays-view-test": function(exports, require, module) {
  var BirthdaysView;

  BirthdaysView = require('views/birthdays-view');

  describe('BirthdaysView', function() {
    return beforeEach(function() {
      return this.view = new BirthdaysView();
    });
  });
  
}});

window.require.define({"test/views/header-view-test": function(exports, require, module) {
  var HeaderView;

  HeaderView = require('views/header-view');

  describe('HeaderView', function() {
    return beforeEach(function() {
      return this.view = new HeaderView();
    });
  });
  
}});

window.require.define({"test/views/home-page-view-test": function(exports, require, module) {
  var HomePageView;

  HomePageView = require('views/home-page-view');

  describe('HomePageView', function() {
    beforeEach(function() {
      return this.view = new HomePageView;
    });
    afterEach(function() {
      return this.view.dispose();
    });
    return it('should auto-render', function() {
      return expect(this.view.$el.find('img')).to.have.length(1);
    });
  });
  
}});

window.require.define({"test/views/main-view-test": function(exports, require, module) {
  var MainView;

  MainView = require('views/main-view');

  describe('MainView', function() {
    return beforeEach(function() {
      return this.view = new MainView();
    });
  });
  
}});

window.require.define({"test/views/shout-comments-view-test": function(exports, require, module) {
  var ShoutCommentsView;

  ShoutCommentsView = require('views/shout-comments-view');

  describe('ShoutCommentsView', function() {
    return beforeEach(function() {
      return this.view = new ShoutCommentsView();
    });
  });
  
}});

window.require('test/controllers/main-controller-test');
window.require('test/controllers/shout-controller-test');
window.require('test/models/birthdays-test');
window.require('test/models/shout-test');
window.require('test/views/birthdays-view-test');
window.require('test/views/header-view-test');
window.require('test/views/home-page-view-test');
window.require('test/views/main-view-test');
window.require('test/views/shout-comments-view-test');
