(function(/*! Brunch !*/) {
  'use strict';

  var globals = typeof window !== 'undefined' ? window : global;
  if (typeof globals.require === 'function') return;

  var modules = {};
  var cache = {};

  var has = function(object, name) {
    return ({}).hasOwnProperty.call(object, name);
  };

  var expand = function(root, name) {
    var results = [], parts, part;
    if (/^\.\.?(\/|$)/.test(name)) {
      parts = [root, name].join('/').split('/');
    } else {
      parts = name.split('/');
    }
    for (var i = 0, length = parts.length; i < length; i++) {
      part = parts[i];
      if (part === '..') {
        results.pop();
      } else if (part !== '.' && part !== '') {
        results.push(part);
      }
    }
    return results.join('/');
  };

  var dirname = function(path) {
    return path.split('/').slice(0, -1).join('/');
  };

  var localRequire = function(path) {
    return function(name) {
      var dir = dirname(path);
      var absolute = expand(dir, name);
      return globals.require(absolute);
    };
  };

  var initModule = function(name, definition) {
    var module = {id: name, exports: {}};
    definition(module.exports, localRequire(name), module);
    var exports = cache[name] = module.exports;
    return exports;
  };

  var require = function(name) {
    var path = expand(name, '.');

    if (has(cache, path)) return cache[path];
    if (has(modules, path)) return initModule(path, modules[path]);

    var dirIndex = expand(path, './index');
    if (has(cache, dirIndex)) return cache[dirIndex];
    if (has(modules, dirIndex)) return initModule(dirIndex, modules[dirIndex]);

    throw new Error('Cannot find module "' + name + '"');
  };

  var define = function(bundle) {
    for (var key in bundle) {
      if (has(bundle, key)) {
        modules[key] = bundle[key];
      }
    }
  }

  globals.require = require;
  globals.require.define = define;
  globals.require.brunch = true;
})();

window.require.define({"application": function(exports, require, module) {
  var Application, AuthController, AuthModel, Backbone, Chaplin, HeaderController, Layout, MenuController, alert, config, mediator, routes,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  Backbone = require('backbone');

  mediator = require('mediator');

  routes = require('routes');

  MenuController = require('controllers/menu-controller');

  HeaderController = require('controllers/header-controller');

  AuthController = require('controllers/auth-controller');

  Layout = require('views/layout');

  AuthModel = require('models/auth-model');

  alert = window.alert;

  window.alert = function(msg, cb, title, button) {
    if (title == null) {
      title = "Błąd";
    }
    if (button == null) {
      button = "Powrót";
    }
    if (navigator.notification) {
      if (!cb) {
        cb = function() {};
      }
      return navigator.notification.alert(msg, cb, title, button);
    } else {
      return alert(msg);
    }
  };

  config = {};

  try {
    config = require('config');
  } catch (e) {
    console.error("Brakuje pliku konfiguracyjnego\nSkopiuj ./config.coffee.example do ./config.coffee\ni uzupełnij konfiguracje");
  }

  module.exports = Application = (function(_super) {

    __extends(Application, _super);

    function Application() {
      return Application.__super__.constructor.apply(this, arguments);
    }

    Application.prototype.title = 'NK Mobile';

    Application.prototype.initGlobals = function() {
      window.friends_page = {};
      window.friends = {};
      window.friends_filter = {};
      window.albumCollection = {};
      window.photoCollection = {};
      window.top.scrollPositions = {};
      window.backbuttonConfirmOpened = false;
      window.top.scrollPositions = {};
      window.backbuttonConfirmOpened = false;
      window.mailModels = [];
      window.last_rotate = 0;
      window.transform_rotate = '';
      window.transform_iscroll = '';
      window.rotated = false;
      return window.profile_comments = {};
    };

    Application.prototype.initialize = function() {
      var _this = this;
      Application.__super__.initialize.apply(this, arguments);
      $(document.body).on('click', '.trigger-timeout', function(e) {
        console.log('suuubmit');
        setTimeout(function() {
          return $('.timeout-disable').attr('disabled', 'disabled');
        }, 10);
        return setTimeout(function() {
          return $('.timeout-disable').removeAttr('disabled');
        }, 3000);
      });
      this.initGlobals();
      window.tapButton = function() {};
      if (top === window) {
        document.addEventListener("backbutton", function(e) {
          $(document.body).unbind('touchmove.stop-scroll');
          if ($('.remove-on-backbutton').length > 0) {
            $('.btn-add-shout').parent().css('display', '');
            return $('.remove-on-backbutton').remove();
          } else {
            if ($('.click-on-backbutton').length > 0) {
              $('.click-on-backbutton').click();
              window.tapButton();
              return window.tapButton = function() {};
            } else {
              if (location.hash === '') {
                try {
                  if (window.backbuttonConfirmOpened === false) {
                    window.backbuttonConfirmOpened = true;
                    return navigator.notification.confirm('Czy na pewno chcesz wyjść z aplikacji nk.pl?', function(buttonIndex) {
                      window.backbuttonConfirmOpened = false;
                      if (buttonIndex === 1) {
                        return navigator.app.exitApp();
                      }
                    }, 'Wyjście z aplikacji', 'tak,nie');
                  }
                } catch (_error) {}
              } else {
                return history.back();
              }
            }
          }
        }, false);
      }
      $(window).bind('scroll', function(e) {
        if (window.scrollY > 0) {
          window.top.scrollPositions[location.hash.toString() || 'main'] = window.scrollY;
          window.last_scroll = new Date().getTime();
          try {
            if (($('.input-blur-top').offset().top - window.scrollY) < 70) {
              return $('.input-blur-top').blur();
            }
          } catch (_error) {}
        }
      });
      document.addEventListener("resume", function() {
        return _this.publishEvent("!refresh");
      });
      $(document.body).on('click', 'input.bottom', function(e) {
        $(e.currentTarget).parent().parent().parent().css('margin-bottom', '204px');
        return setTimeout(function() {
          return window.scrollTo(0, 9999);
        }, 100);
      });
      $(document.body).on('blur', 'input.bottom', function(e) {
        return $(e.currentTarget).parent().parent().parent().css('margin-bottom', '0px');
      });
      $(document.body).on('focus', 'input.login', function(e) {
        return setTimeout(function() {
          return $('.form-signin img').addClass('hidden');
        }, 200);
      });
      $.ajaxSetup({
        dataType: "json",
        contentType: "application/json",
        xhrFields: {
          withCredentials: true
        },
        statusCode: {
          400: function(jqXHR) {
            var error;
            error = JSON.parse(jqXHR.responseText);
            if (_.isNull(error)) {

            } else if (typeof error === 'object' && error[0]) {
              return window.alert(error[0], (function() {}), 'Komunikat', 'Powrót');
            } else {
              return window.alert(error, (function() {}), 'Komunikat', 'Powrót');
            }
          },
          401: function() {
            return mediator.auth.destroy();
          }
        },
        beforeSend: function(jqXHR, settings) {
          var errorCallback;
          if (window.Connection && navigator.connection && navigator.connection.type === Connection.NONE) {
            window.alert('Brak połączenia z siecią, spróbuj ponownie za chwilę', (function() {}), 'Połączenie', 'OK');
            return settings.error(jqXHR, 793);
          } else {
            errorCallback = settings.error;
            settings.error = function(jqXHR, status, options) {
              if (status === "timeout") {
                return window.alert("Nie udało się pobrać danych, spróbuj ponownie za chwilę", (function() {}), 'Błąd', 'Powrót');
              } else {
                return typeof errorCallback === "function" ? errorCallback(jqXHR, status, options) : void 0;
              }
            };
            if (config.host) {
              return settings.url = "http://" + config.host + settings.url;
            } else {
              return settings.url = "http://sebo-mnk.nk-net.pl" + settings.url;
            }
          }
        }
      });
      this.initLayout();
      this.initMediator();
      this.subscribeEvent("!login", function() {
        _this.initControllers();
        _this.initDispatcher({
          controllerSuffix: '-controller'
        });
        _this.initRouter(routes, {
          pushState: false
        });
        return console.log("!login");
      });
      this.subscribeEvent("!logout", function() {
        var _ref, _ref1, _ref2, _ref3, _ref4, _ref5;
        localStorage.clear();
        _this.initGlobals();
        if ((_ref = _this.header) != null) {
          _ref.dispose();
        }
        if ((_ref1 = _this.menu) != null) {
          _ref1.dispose();
        }
        if ((_ref2 = _this.router) != null) {
          _ref2.dispose();
        }
        console.log("!logout");
        if ((_ref3 = _this.dispatcher) != null) {
          if ((_ref4 = _ref3.currentController) != null) {
            _ref4.dispose();
          }
        }
        return (_ref5 = _this.dispatcher) != null ? _ref5.dispose() : void 0;
      });
      mediator.auth.fetch({
        success: function(auth) {
          new AuthController();
          if (auth.id) {
            mediator.auth.relogin(function(status) {
              if (!status) {
                return auth.destroy();
              }
            });
          }
          return setTimeout((function() {
            return _this.publishEvent("!refresh");
          }), 1000);
        }
      });
      if (top === window) {
        return setTimeout(function() {
          var _ref;
          return (_ref = navigator.splashscreen) != null ? _ref.hide() : void 0;
        }, 550);
      }
    };

    Application.prototype.initLayout = function() {
      return this.layout = new Layout({
        title: this.title
      });
    };

    Application.prototype.initControllers = function() {
      this.header = new HeaderController();
      return this.menu = new MenuController();
    };

    Application.prototype.initMediator = function() {
      mediator.auth = new AuthModel();
      return mediator.config = config;
    };

    return Application;

  })(Chaplin.Application);
  
}});

window.require.define({"config": function(exports, require, module) {
  
  module.exports = {
    host: "m.nk.pl",
    gallery: true
  };
  
}});

window.require.define({"controllers/auth-controller": function(exports, require, module) {
  var AuthModalController, AuthModalView, AuthModel, ModalController, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  ModalController = require('controllers/base/modal-controller');

  mediator = require('mediator');

  AuthModalView = require('views/modals/auth-modal-view');

  AuthModel = require('models/auth-model');

  module.exports = AuthModalController = (function(_super) {

    __extends(AuthModalController, _super);

    function AuthModalController() {
      this.loggedIn = __bind(this.loggedIn, this);

      this.loggedOut = __bind(this.loggedOut, this);
      return AuthModalController.__super__.constructor.apply(this, arguments);
    }

    AuthModalController.prototype.initialize = function() {
      AuthModalController.__super__.initialize.apply(this, arguments);
      console.log('auth controller initialize');
      this.model = mediator.auth;
      if (this.model.get('login')) {
        console.log('auth controller initialize - user zalogowany');
        this.loggedIn();
      } else {
        console.log('auth controller initialize - user niezalogowany');
        this.loggedOut();
      }
      this.model.on('logout', this.loggedOut);
      return this.model.on('login', this.loggedIn);
    };

    AuthModalController.prototype.loggedOut = function() {
      console.log("show modal");
      this.redirectTo("/");
      this.showForm();
      return this.publishEvent('!logout');
    };

    AuthModalController.prototype.loggedIn = function() {
      console.log("hide modal");
      this.hideForm();
      return this.publishEvent('!login');
    };

    AuthModalController.prototype.showForm = function() {
      var _ref;
      if ((_ref = this.view) != null) {
        _ref.dispose();
      }
      return this.view = new AuthModalView({
        model: this.model
      });
    };

    AuthModalController.prototype.hideForm = function() {
      var _ref;
      if ((_ref = this.view) != null) {
        _ref.dispose();
      }
      return this.view = null;
    };

    return AuthModalController;

  })(ModalController);
  
}});

window.require.define({"controllers/base/controller": function(exports, require, module) {
  var Chaplin, Controller, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  mediator = require('mediator');

  module.exports = Controller = (function(_super) {

    __extends(Controller, _super);

    function Controller() {
      return Controller.__super__.constructor.apply(this, arguments);
    }

    return Controller;

  })(Chaplin.Controller);
  
}});

window.require.define({"controllers/base/modal-controller": function(exports, require, module) {
  var Chaplin, Controller, ModalController,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  Controller = require('controllers/base/controller');

  module.exports = ModalController = (function(_super) {

    __extends(ModalController, _super);

    function ModalController() {
      return ModalController.__super__.constructor.apply(this, arguments);
    }

    ModalController.prototype.inidialize = function() {
      return this.view = new ModalView();
    };

    return ModalController;

  })(Controller);
  
}});

window.require.define({"controllers/base/page-controller": function(exports, require, module) {
  var Chaplin, Controller, PageController,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  Controller = require('controllers/base/controller');

  module.exports = PageController = (function(_super) {

    __extends(PageController, _super);

    function PageController() {
      return PageController.__super__.constructor.apply(this, arguments);
    }

    PageController.prototype.updateMenu = function(pageName) {
      var img, menuItem;
      $('.refresh-info').addClass('hidden');
      if (pageName === 'feed') {
        $('.btn-refresh').css('opacity', 1);
      } else {
        $('.btn-refresh').css('opacity', 0.01);
      }
      if (pageName === '') {
        $('.nav li.selected').removeClass('selected');
        return this.clearMenu();
      } else {
        menuItem = $('.nav li.' + pageName);
        if (!menuItem.hasClass('selected')) {
          img = $('.nav li.' + pageName + ' img');
          this.clearMenu();
          try {
            img.attr('src', img.attr('src').replace('.png', '_on.png'));
          } catch (_error) {}
          $('.nav li.selected').removeClass('selected');
          return menuItem.addClass('selected');
        }
      }
    };

    PageController.prototype.clearMenu = function() {
      var imgs,
        _this = this;
      imgs = $('.nav li img');
      return _.each(imgs, function(img) {
        img = $(img);
        try {
          return img.attr('src', img.attr('src').replace('_on.png', '.png'));
        } catch (_error) {}
      });
    };

    PageController.prototype.updateLogo = function(page) {
      var backButton;
      backButton = $('.topbar .backbutton');
      if (page === 'main') {
        backButton.addClass('hidden');
        return backButton.parent().unbind("click").click((function() {}));
      } else {
        $('.refresh-info').addClass('hidden');
        backButton.removeClass('hidden');
        return backButton.parent().unbind("click").click(function(e) {
          e.preventDefault();
          return history.back();
        });
      }
    };

    return PageController;

  })(Controller);
  
}});

window.require.define({"controllers/feed-controller": function(exports, require, module) {
  var BirthdayModel, BirthdayView, FeedCollection, FeedController, FeedMainView, FeedView, PageController,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageController = require('controllers/base/page-controller');

  FeedMainView = require('views/feed/feed-main-view');

  BirthdayView = require('views/feed/birthdays-view');

  FeedView = require('views/feed/feed-view');

  BirthdayModel = require('models/birthdays-model');

  FeedCollection = require('models/feed-collection');

  module.exports = FeedController = (function(_super) {

    __extends(FeedController, _super);

    function FeedController() {
      return FeedController.__super__.constructor.apply(this, arguments);
    }

    FeedController.prototype.title = 'Feed';

    FeedController.prototype.index = function(refresh) {
      $('.comment-add-focus').stop();
      this.view = new FeedMainView({
        refresh: refresh
      });
      this.birthdaysView = new BirthdayView;
      this.feed = new FeedCollection;
      this.feedView = new FeedView({
        collection: this.feed
      });
      this.view.subview("birthdays", this.birthdaysView);
      this.view.subview("feed", this.feedView);
      this.feed.fetch();
      this.view.render();
      this.updateMenu('feed');
      return this.updateLogo('main');
    };

    FeedController.prototype.refresh = function() {
      return this.index(true);
    };

    return FeedController;

  })(PageController);
  
}});

window.require.define({"controllers/header-controller": function(exports, require, module) {
  var Controller, HeaderView, HeadersController,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Controller = require('controllers/base/controller');

  HeaderView = require('views/header-view');

  module.exports = HeadersController = (function(_super) {

    __extends(HeadersController, _super);

    function HeadersController() {
      return HeadersController.__super__.constructor.apply(this, arguments);
    }

    HeadersController.prototype.initialize = function() {
      this.view = new HeaderView;
      return HeadersController.__super__.initialize.apply(this, arguments);
    };

    return HeadersController;

  })(Controller);
  
}});

window.require.define({"controllers/mail-controller": function(exports, require, module) {
  var MailBoxView, MailCollection, MailComposeView, MailController, MailView, PageController, UserModel,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageController = require('controllers/base/page-controller');

  MailBoxView = require('views/mailbox-page-view');

  MailView = require('views/mail-view');

  MailComposeView = require('views/mail-compose-page-view');

  MailCollection = require('models/mail-collection');

  UserModel = require('models/user-model');

  module.exports = MailController = (function(_super) {

    __extends(MailController, _super);

    function MailController() {
      return MailController.__super__.constructor.apply(this, arguments);
    }

    MailController.prototype.title = 'Mail';

    MailController.prototype.index = function() {
      var _this = this;
      if (!window.mailModels) {
        window.mailModels = [];
      }
      this.collection = new MailCollection(window.mailModels);
      this.view = new MailBoxView({
        collection: this.collection
      });
      this.updateMenu('mail');
      this.updateLogo('main');
      return this.collection.fetch({
        update: false,
        success: function() {
          _this.total = _this.collection.total;
          _this.perPage = _this.collection.itemsPerPage;
          _this.startIndex = _this.collection.startIndex;
          window.mailModels = _.sortBy(_.uniq(_this.collection.models.concat(window.mailModels), false, function(el) {
            return el.attributes.id;
          }), function(el) {
            return -el.attributes.timestamp;
          });
          _this.collection = new MailCollection(window.mailModels);
          _this.collection.total = _this.total;
          _this.collection.perPage = _this.perPage;
          _this.collection.startIndex = _this.startIndex;
          _this.view.dispose();
          _this.view = new MailBoxView({
            collection: _this.collection
          });
          return _this.view.render();
        }
      });
    };

    MailController.prototype.details = function(params) {
      var mailId, mailModel;
      this.updateLogo('subpage');
      mailId = params.mail_id;
      this.collection = new MailCollection(window.mailModels);
      mailModel = this.collection.find(function(el) {
        return el.attributes.id === parseInt(mailId);
      });
      return this.mailView = new MailView({
        model: mailModel,
        mailId: mailId
      });
    };

    MailController.prototype.compose = function(params) {
      var userModel,
        _this = this;
      userModel = new UserModel({
        id: params.user_id
      });
      return userModel.fetch({
        success: function(data) {
          console.log(data);
          return _this.view = new MailComposeView({
            model: userModel
          });
        }
      });
    };

    return MailController;

  })(PageController);
  
}});

window.require.define({"controllers/menu-controller": function(exports, require, module) {
  var Controller, MenuController, MenuView, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Controller = require('controllers/base/controller');

  MenuView = require('views/menu-view');

  mediator = require('mediator');

  module.exports = MenuController = (function(_super) {

    __extends(MenuController, _super);

    function MenuController() {
      return MenuController.__super__.constructor.apply(this, arguments);
    }

    MenuController.prototype.initialize = function() {
      this.view = new MenuView();
      return MenuController.__super__.initialize.apply(this, arguments);
    };

    return MenuController;

  })(Controller);
  
}});

window.require.define({"controllers/photo-controller": function(exports, require, module) {
  var FeedCollection, PageController, PhotoCommentsView, PhotoFeedItemView, PhotoMainView, PhotoModel, PhotoUploadView, PhotosController, View,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageController = require('controllers/base/page-controller');

  PhotoUploadView = require('views/photo-upload-view');

  View = require('views/base/view');

  PhotoMainView = require('views/photo-main-view');

  PhotoFeedItemView = require('views/feed/photo-feed-item-view');

  PhotoCommentsView = require('views/photo/comments-view');

  FeedCollection = require('models/feed-collection');

  PhotoModel = require('models/photo-model');

  module.exports = PhotosController = (function(_super) {

    __extends(PhotosController, _super);

    function PhotosController() {
      this.showPhoto = __bind(this.showPhoto, this);

      this.addFromAlbum = __bind(this.addFromAlbum, this);
      return PhotosController.__super__.constructor.apply(this, arguments);
    }

    PhotosController.prototype.index = function() {
      this.updateMenu('photo');
      return this.view = new PhotoPageView();
    };

    PhotosController.prototype.addFromCamera = function() {
      var _this = this;
      this.updateLogo('photo');
      this.updateMenu('photo');
      this.view = new PhotoUploadView('camera');
      this.view.on('photo-uploaded', function() {
        return _this.redirectTo('/refresh');
      });
      return this.subscribeEvent("refreshView", function() {
        _this.view.dispose();
        _this.view = new PhotoUploadView('camera');
        return _this.view.on('photo-uploaded', function() {
          return _this.redirectTo('/refresh');
        });
      });
    };

    PhotosController.prototype.addFromAlbum = function() {
      var _this = this;
      this.updateLogo('photo');
      this.updateMenu('photo');
      this.view = new PhotoUploadView('album');
      this.view.on('photo-uploaded', function() {
        return _this.redirectTo('/refresh');
      });
      return this.subscribeEvent("refreshView", function() {
        _this.view.dispose();
        _this.view = new PhotoUploadView('album');
        return _this.view.on('photo-uploaded', function() {
          return _this.redirectTo('/refresh');
        });
      });
    };

    PhotosController.prototype.showPhotoPage = function(params) {
      params.focus = null;
      return this.showPage(params);
    };

    PhotosController.prototype.showComments = function(params) {
      params.focus = 'comments';
      return this.showPage(params);
    };

    PhotosController.prototype.showAddComment = function(params) {
      params.focus = 'addComment';
      return this.showPage(params);
    };

    PhotosController.prototype.showPage = function(params) {
      var feed,
        _this = this;
      this.focusElement = params.focus;
      this.updateLogo('photo');
      this.updateMenu('');
      feed = new FeedCollection;
      this.view = new PhotoMainView;
      return feed.fetch({
        success: function(collection) {
          var callback, model;
          model = collection.find(function(el) {
            if (!el.attributes.author.raw_user) {
              return;
            }
            return el.attributes.author.raw_user.uid === parseInt(params.user_id) && el.attributes.photo_id === parseInt(params.photo_id);
          });
          callback = function() {
            collection = model.getComments();
            collection.fetch({
              success: function(data) {
                var countComments, textComments, _ref;
                countComments = $('.media .actions .count-comments');
                countComments.removeClass('hide');
                textComments = $('.media .actions .comment_count');
                textComments.html(data.total);
                return (_ref = $('.media .last_comment')) != null ? _ref.remove() : void 0;
              },
              error: function(collection, xhr, options) {
                var input;
                if (xhr.status === 400) {
                  xhr.status = 200;
                  console.log(decodeURIComponent(xhr.responseText));
                  input = $('.comment-add form input');
                  input.attr('disabled', 'disabled');
                  input.attr('placeholder', 'Brak uprawnień');
                  $('.comment-add form button').attr('disabled', 'disabled');
                  $('.photo-comment-add').addClass('disabled', 'disabled');
                  return $('.photo-comment-add').click(function(e) {
                    e.preventDefault();
                    return console.log('nie mozna dodac komentarza');
                  });
                }
              }
            });
            return new PhotoCommentsView({
              collection: collection
            });
          };
          if (true) {
            if (params.gallery_id) {
              model = new PhotoModel({
                gallery_id: params.gallery_id,
                photo_id: params.photo_id
              });
            } else {
              model = new PhotoModel({
                user_id: params.user_id,
                photo_id: params.photo_id,
                album_id: params.album_id
              });
            }
            return model.fetch({
              success: function(data) {
                return _this.showPhoto(model, callback);
              },
              error: function(model, xhr, options) {
                return window.alert(JSON.parse(xhr.responseText), function() {
                  return history.back();
                });
              }
            });
          } else {
            return _this.showPhoto(model, callback, true);
          }
        }
      });
    };

    PhotosController.prototype.showPhoto = function(model, callback, single) {
      var _this = this;
      this.view.subview('photo', new PhotoFeedItemView({
        model: model,
        single: true
      }));
      this.view.subview('comments', callback(model));
      this.view.render();
      setTimeout(function() {
        var element, offset;
        if (_this.focusElement) {
          if (_this.focusElement === 'comments') {
            return window.scrollTo(0, Math.ceil($('.comment-list').position().top) - 110);
          } else {
            element = '.comment-add-focus';
            offset = -200;
            return $('body').scrollTo($(element), {
              offsetTop: offset,
              duration: 0
            });
          }
        }
      }, 230);
      this.updateMenu('');
      return this.updateLogo('photo');
    };

    return PhotosController;

  })(PageController);
  
}});

window.require.define({"controllers/profile-controller": function(exports, require, module) {
  var AlbumCollection, FriendsView, GalleryAlbumPageView, GalleryPageView, PageController, PhotoCollection, PhotosView, ProfileCommentCollection, ProfileCommentsView, ProfileController, ProfileGalleryPageView, ProfilePageView, UserCollection, UserModel, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageController = require('controllers/base/page-controller');

  ProfilePageView = require('views/profile-page-view');

  ProfileCommentsView = require('views/profile/comments-view');

  ProfileGalleryPageView = require('views/profile-gallery-page-view');

  GalleryPageView = require('views/gallery-page-view');

  GalleryAlbumPageView = require('views/gallery/gallery-album-page-view');

  FriendsView = require('views/friends-view');

  UserModel = require('models/user-model');

  UserCollection = require('models/user-collection');

  AlbumCollection = require('models/album-collection');

  PhotoCollection = require('models/photo-collection');

  ProfileCommentCollection = require('models/profile-comment-collection');

  PhotosView = require('views/photos-view');

  mediator = require('mediator');

  module.exports = ProfileController = (function(_super) {

    __extends(ProfileController, _super);

    function ProfileController() {
      return ProfileController.__super__.constructor.apply(this, arguments);
    }

    ProfileController.prototype.title = 'Profil';

    ProfileController.prototype.index = function(req) {
      var _this = this;
      this.userModel = new UserModel({
        id: req.user_id
      });
      this.view = new ProfilePageView({
        model: this.userModel
      });
      if (mediator.auth.id === req.user_id) {
        this.updateMenu('profile');
        this.updateLogo('main');
      } else {
        setTimeout(function() {
          return _this.updateMenu('');
        }, 30);
        this.updateLogo('subpage');
      }
      return this.userModel.fetch({
        success: function() {
          var profileComments;
          profileComments = new ProfileCommentCollection(window.profile_comments[req.user_id], {
            user_id: req.user_id
          });
          _this.view.subview('comments', new ProfileCommentsView({
            collection: profileComments
          }));
          profileComments.fetch({
            update: true,
            remove: false,
            success: function(collection) {
              window.profile_comments[req.user_id] = collection.models.concat([]);
              if (collection.models.length < collection.total) {
                return $('.btn-older-comments').css('display', 'inline-block');
              } else {
                return $('.btn-older-comments').css('display', 'none');
              }
            },
            error: function(model, xhr) {
              $('.comment-content').attr('disabled', 'disabled');
              $('.comment-content').parent().parent().find('button').attr('disabled', 'disabled');
              return $('.comment-content').attr('placeholder', JSON.parse(xhr.responseText));
            }
          });
          return _this.view.render();
        },
        error: function(model, xhr) {
          if (xhr.status === 400) {
            xhr.status = 200;
            return window.alert(JSON.parse(xhr.responseText), function() {
              return history.back();
            });
          }
        }
      });
    };

    ProfileController.prototype.friends = function(req) {
      var _this = this;
      if (mediator.auth.id === req.user_id) {
        this.updateMenu('friends');
        this.updateLogo('main');
      } else {
        setTimeout(function() {
          return _this.updateMenu('');
        }, 30);
        this.updateLogo('subpage');
      }
      this.collection = new UserCollection(null, {
        id: req.user_id
      });
      this.view = new FriendsView({
        collection: this.collection
      });
      return this.collection.fetch({
        success: function() {
          console.log(_this.collection.serialize());
          return _this.view.render();
        }
      });
    };

    ProfileController.prototype.gallery = function(req) {
      var _this = this;
      if (mediator.config.gallery === true) {
        this.collection = new AlbumCollection(window.albumCollection[req.user_id], {
          user_id: req.user_id
        });
        this.view = new GalleryPageView({
          collection: this.collection
        });
        this.updateMenu('');
        this.updateLogo('subpage');
        return this.collection.fetch({
          update: true,
          remove: false,
          success: function() {
            _this.total = _this.collection.total;
            _this.perPage = _this.collection.itemsPerPage;
            _this.startIndex = _this.collection.startIndex;
            _this.collection.user_id = req.user_id;
            window.albumCollection[req.user_id] = _this.collection.models.concat([]);
            return _this.view.render();
          },
          error: function(model, xhr) {
            if (xhr.status === 400) {
              xhr.status = 200;
              return window.alert(JSON.parse(xhr.responseText), function() {
                return history.back();
              });
            }
          }
        });
      } else {
        return this.view = new ProfileGalleryPageView();
      }
    };

    ProfileController.prototype.album = function(req) {
      var _this = this;
      if (mediator.config.gallery === true) {
        this.view = new GalleryAlbumPageView();
        this.photoCollection = new PhotoCollection(window.photoCollection[req.user_id + '-' + req.album_id], {
          userId: req.user_id,
          albumId: req.album_id
        });
        window.photoCollection[req.user_id + '-' + req.album_id] = this.photoCollection.models.concat([]);
        this.photosView = new PhotosView({
          collection: this.photoCollection
        });
        this.view.subview("photos", this.photosView);
        this.photoCollection.fetch({
          update: true,
          remove: false,
          success: function(collection) {
            console.log('kolekcja fot');
            console.log(collection);
            window.photoCollection[req.user_id + '-' + req.album_id] = collection.models.concat([]);
            if (collection.total <= collection.length) {
              return $('.load-more').attr('disabled', 'disabled');
            }
          }
        });
        return this.view.render();
      } else {
        return this.view = new ProfileGalleryPageView();
      }
    };

    return ProfileController;

  })(PageController);
  
}});

window.require.define({"controllers/shout-controller": function(exports, require, module) {
  var FeedCollection, PageController, ShoutCommentsView, ShoutFeedItemView, ShoutMainView, ShoutModel, ShoutStarsView, ShoutsController,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageController = require('controllers/base/page-controller');

  ShoutMainView = require('views/shout-main-view');

  ShoutFeedItemView = require('views/feed/shout-feed-item-view');

  ShoutCommentsView = require('views/shout/comments-view');

  ShoutStarsView = require('views/shout/stars-view');

  FeedCollection = require('models/feed-collection');

  ShoutModel = require('models/shout-model');

  module.exports = ShoutsController = (function(_super) {

    __extends(ShoutsController, _super);

    function ShoutsController() {
      this.showShout = __bind(this.showShout, this);
      return ShoutsController.__super__.constructor.apply(this, arguments);
    }

    ShoutsController.prototype.focusElement = true;

    ShoutsController.prototype.showComments = function(params) {
      var _this = this;
      return this.show('comments', params, function(model) {
        var collection;
        collection = model.getComments();
        collection.fetch({
          success: function(col) {
            if (col.total > col.models.length) {
              return $('.btn-older-comments').show();
            } else {
              return $('.btn-older-comments').hide();
            }
          }
        });
        return new ShoutCommentsView({
          collection: collection
        });
      });
    };

    ShoutsController.prototype.showStars = function(params) {
      var _this = this;
      this.focusElement = false;
      return this.show('stars', params, function(model) {
        var collection;
        collection = model.getStars();
        collection.fetch();
        return new ShoutStarsView({
          collection: collection
        });
      });
    };

    ShoutsController.prototype.show = function(name, params, callback) {
      var feed,
        _this = this;
      feed = new FeedCollection;
      this.updateLogo('shout');
      this.updateMenu('');
      return feed.fetch({
        success: function(collection) {
          var model;
          model = collection.find(function(el) {
            return el.attributes.user_id === (parseInt(params.user_id) && el.attributes.shout_id === parseInt(params.shout_id));
          });
          if (model) {
            return _this.showShout(model, name, callback);
          } else {
            console.log(params.user_id);
            model = new ShoutModel({
              user_id: params.user_id,
              shout_id: params.shout_id
            });
            return model.fetch({
              success: function(data) {
                return _this.showShout(model, name, callback);
              }
            });
          }
        }
      });
    };

    ShoutsController.prototype.showShout = function(model, name, callback) {
      var _this = this;
      this.view = new ShoutMainView({
        model: model
      });
      this.view.on('showStars', function(params) {
        return _this.showStars(params);
      });
      this.view.on('showComments', function(params) {
        return _this.showComments(params);
      });
      this.view.subview('shout', new ShoutFeedItemView({
        model: model
      }));
      try {
        this.view.subview(name, callback(model));
        this.view.render();
        return setTimeout(function() {
          var element, offset;
          if (_this.focusElement) {
            element = '.comment-add-focus';
            offset = -200;
            return $('body').scrollTo($(element), {
              offsetTop: offset
            });
          }
        }, 110);
      } catch (e) {
        return console.error(e);
      }
    };

    return ShoutsController;

  })(PageController);
  
}});

window.require.define({"initialize": function(exports, require, module) {
  var Application, init;

  Application = require('application');

  window.top.initialized = false;

  init = function() {
    var app;
    console.log("INIT");
    window.top.initialized = true;
    app = new Application();
    return app.initialize();
  };

  if (navigator.userAgent.match(/Chrome\/3[0-9]{1}/)) {
    $(window).bind('ready', init);
  }

  document.addEventListener("deviceready", init, false);
  
}});

window.require.define({"lib/next-tick": function(exports, require, module) {
  
  module.exports = (function() {
    var MESSAGE, head, onGlobalMessage, tail;
    MESSAGE = "q-nextTick-" + Math.random();
    head = {};
    tail = head;
    onGlobalMessage = function(event) {
      var task;
      if (event.source === window && event.data === MESSAGE) {
        head = head.next;
        task = head.task;
        delete head.task;
        return task();
      }
    };
    if (window.addEventListener) {
      window.addEventListener("message", onGlobalMessage, false);
    } else {
      window.attachEvent("onmessage", onGlobalMessage);
    }
    return function(task) {
      tail = tail.next = {
        task: task
      };
      return postMessage(MESSAGE, "*");
    };
  })();
  
}});

window.require.define({"lib/support": function(exports, require, module) {
  var Chaplin, support, utils;

  Chaplin = require('chaplin');

  utils = require('lib/utils');

  support = utils.beget(Chaplin.support);

  module.exports = support;
  
}});

window.require.define({"lib/utils": function(exports, require, module) {
  var Chaplin, utils;

  Chaplin = require('chaplin');

  utils = Chaplin.utils.beget(Chaplin.utils);

  module.exports = utils;
  
}});

window.require.define({"lib/view-helper": function(exports, require, module) {
  var mediator, utils;

  mediator = require('mediator');

  utils = require('chaplin/lib/utils');

  Handlebars.registerHelper('if_logged_in', function(options) {
    if (mediator.user) {
      return options.fn(this);
    } else {
      return options.inverse(this);
    }
  });

  Handlebars.registerHelper('with', function(context, options) {
    if (!context || Handlebars.Utils.isEmpty(context)) {
      return options.inverse(this);
    } else {
      return options.fn(context);
    }
  });

  Handlebars.registerHelper('without', function(context, options) {
    var inverse;
    inverse = options.inverse;
    options.inverse = options.fn;
    options.fn = inverse;
    return Handlebars.helpers["with"].call(this, context, options);
  });

  Handlebars.registerHelper('with_user', function(options) {
    var context, _ref;
    context = ((_ref = mediator.user) != null ? _ref.serialize() : void 0) || {};
    return Handlebars.helpers["with"].call(this, context, options);
  });

  Handlebars.registerPartial('nk_domain', function() {
    return 'http://nk.pl';
  });

  Handlebars.registerHelper('text_cut', function(text, limit) {
    return text.substring(0, limit);
  });

  Handlebars.registerPartial('logged_user_id', function() {
    return mediator.auth.id;
  });

  Handlebars.registerHelper('nl2br', function(value) {
    return $('<div/>').text(value).html().replace(/\n/g, '<br>');
  });

  Handlebars.registerHelper('html2text', function(html) {
    return $(html).text();
  });

  Handlebars.registerHelper('liczebnik', function(n, komentarz, komentarze, komentarzy) {
    switch (n) {
      case 0:
        return komentarzy;
      case 1:
        return komentarz;
      case 2:
      case 3:
      case 4:
        return komentarze;
      default:
        if (n < 22) {
          return komentarzy;
        }
        n %= 10;
        if (n === 2 || n === 3 || n === 4) {
          return komentarze;
        }
        return komentarzy;
    }
  });

  Handlebars.registerHelper('polish_date', function(timestamp) {
    var date;
    if (!timestamp) {
      return '';
    } else {
      date = new Date();
      date.setTime(parseInt(timestamp) * 1000);
      return date.get_polish();
    }
  });

  Handlebars.registerHelper('gender', function(context, options) {
    if (context === 'm') {
      return 'Mężczyzna';
    } else if (context === 'f') {
      return 'Kobieta';
    } else {
      return '';
    }
  });

  Handlebars.registerHelper('debugger', function(context, options) {
    debugger;
  });

  Handlebars.registerHelper('my_profile', function(context, options) {
    if (context.toString() === mediator.auth.id.toString()) {
      console.log('jest moj profil');
      return options.fn(this);
    } else {
      console.log('nie moj profil');
      return options.inverse(this);
    }
  });

  Handlebars.registerHelper('if_eq', function(context, options) {
    if (context === options.hash.compare) {
      return options.fn(this);
    }
    return options.inverse(this);
  });

  Handlebars.registerPartial('feed-shout', function(context) {
    return require('views/templates/feed-shout')(context);
  });
  
}});

window.require.define({"mediator": function(exports, require, module) {
  
  module.exports = require('chaplin').mediator;
  
}});

window.require.define({"models/album-collection": function(exports, require, module) {
  var AlbumCollection, Collection, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('models/base/collection');

  mediator = require('chaplin').mediator;

  module.exports = AlbumCollection = (function(_super) {

    __extends(AlbumCollection, _super);

    function AlbumCollection() {
      return AlbumCollection.__super__.constructor.apply(this, arguments);
    }

    AlbumCollection.prototype.initialize = function(albums, options) {
      this.user_id = options.user_id;
      return AlbumCollection.__super__.initialize.call(this);
    };

    AlbumCollection.prototype.url = function() {
      return "/profile/" + this.user_id + "/gallery";
    };

    AlbumCollection.prototype.parse = function(data) {
      var entry, _i, _len, _ref, _results;
      this.total = data.album_count;
      _ref = data.albums;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        entry = _ref[_i];
        _results.push(entry);
      }
      return _results;
    };

    return AlbumCollection;

  })(Collection);
  
}});

window.require.define({"models/auth-model": function(exports, require, module) {
  var AuthModel, Chaplin, LocalStorage, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  LocalStorage = require('models/base/localstorage');

  mediator = require('mediator');

  module.exports = AuthModel = (function(_super) {

    __extends(AuthModel, _super);

    function AuthModel() {
      this.login = __bind(this.login, this);

      this.relogin = __bind(this.relogin, this);

      this.logout = __bind(this.logout, this);
      return AuthModel.__super__.constructor.apply(this, arguments);
    }

    AuthModel.prototype.url = "/login";

    AuthModel.prototype.logout = function() {
      var _this = this;
      return $.ajax('/logout', {
        success: function() {
          window.alert('Zostałeś wylogowany z aplikacji NK', function() {
            return location.replace(location.href.replace(location.hash, ''));
          }, 'Komunikat', 'OK');
          return _this.destroy();
        }
      });
    };

    AuthModel.prototype.destroy = function() {
      this.trigger("logout");
      return AuthModel.__super__.destroy.apply(this, arguments);
    };

    AuthModel.prototype.relogin = function(callback) {
      var _this = this;
      return $.ajax(this.url, {
        type: 'get',
        success: function() {
          return callback(true);
        },
        error: function() {
          return callback(false);
        }
      });
    };

    AuthModel.prototype.login = function(login, pass) {
      var _this = this;
      console.log('model auth login action');
      return $.ajax(this.url, {
        type: 'post',
        data: JSON.stringify({
          login: login,
          password: pass,
          remember: 1
        }),
        success: function(data, status, jqXHR) {
          _this.save({
            id: data.nk_uid,
            login: login,
            remember_mobile: data.remember_mobile
          });
          _this.trigger("login");
          return $.cookie('remember_mobile', data.remember_mobile, {
            domain: mediator.config.host
          });
        }
      });
    };

    return AuthModel;

  })(LocalStorage);
  
}});

window.require.define({"models/base/cached-collection": function(exports, require, module) {
  var CachedCollection, CachedModel, Collection, Storage,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('./collection');

  CachedModel = require('./cached-model');

  Storage = require('./storage');

  module.exports = CachedCollection = (function(_super) {

    __extends(CachedCollection, _super);

    function CachedCollection() {
      return CachedCollection.__super__.constructor.apply(this, arguments);
    }

    CachedCollection.prototype.storage = new Storage("collection:");

    CachedCollection.prototype.sync = CachedModel.prototype.sync;

    return CachedCollection;

  })(Collection);
  
}});

window.require.define({"models/base/cached-model": function(exports, require, module) {
  var CachedModel, Model, Storage, nextTick,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('./model');

  Storage = require('./storage');

  nextTick = require('lib/next-tick');

  module.exports = CachedModel = (function(_super) {

    __extends(CachedModel, _super);

    function CachedModel() {
      return CachedModel.__super__.constructor.apply(this, arguments);
    }

    CachedModel.prototype.storage = new Storage("cache:");

    CachedModel.prototype.sync = function(method, model, options) {
      var output,
        _this = this;
      if ((options != null ? options.cache : void 0) === false) {
        CachedModel.__super__.sync.call(this, method, model, options);
        return;
      }
      switch (method) {
        case 'create':
        case 'update':
          if (options && options.local) {
            this.storage.set(model);
            return options.success(model, 'cached');
          } else {
            return CachedModel.__super__.sync.call(this, method, model, {
              success: function(resp, status, xhr) {
                _this.storage.set(model);
                return options.success(resp, status, xhr);
              }
            });
          }
          break;
        case 'delete':
          this.storage.remove(model);
          return CachedModel.__super__.sync.call(this, method, model, options);
        case 'read':
          output = this.storage.get(model);
          if ((options != null ? options.refresh : void 0) || !output) {
            return CachedModel.__super__.sync.call(this, method, model, {
              success: function(resp, status, xhr) {
                options.success(resp, status, xhr);
                return _this.storage.set(model);
              }
            });
          } else {
            return nextTick(function() {
              return options.success(output, 'cached');
            });
          }
      }
    };

    return CachedModel;

  })(Model);
  
}});

window.require.define({"models/base/collection": function(exports, require, module) {
  var Chaplin, Collection, Model,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  Model = require('models/base/model');

  module.exports = Collection = (function(_super) {

    __extends(Collection, _super);

    function Collection() {
      return Collection.__super__.constructor.apply(this, arguments);
    }

    Collection.prototype.model = Model;

    return Collection;

  })(Chaplin.Collection);
  
}});

window.require.define({"models/base/comments-collection": function(exports, require, module) {
  var Collection, CommentModel, PhotoCommentsCollection, nextTick,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('models/base/collection');

  CommentModel = require('models/photo/comment-model');

  nextTick = require('lib/next-tick');

  module.exports = PhotoCommentsCollection = (function(_super) {

    __extends(PhotoCommentsCollection, _super);

    function PhotoCommentsCollection() {
      this.getOlderComments = __bind(this.getOlderComments, this);
      return PhotoCommentsCollection.__super__.constructor.apply(this, arguments);
    }

    PhotoCommentsCollection.prototype.model = CommentModel;

    PhotoCommentsCollection.prototype.total = 0;

    PhotoCommentsCollection.prototype.perPage = 0;

    PhotoCommentsCollection.prototype.startIndex = 0;

    PhotoCommentsCollection.prototype.offset = 0;

    PhotoCommentsCollection.prototype.limit = 10;

    PhotoCommentsCollection.prototype.getOlderComments = function(callback) {
      var _this = this;
      if (this.total > this.models.length) {
        this.offset += this.limit;
        return this.fetch({
          update: true,
          remove: false,
          data: {
            offset: this.offset,
            limit: this.limit
          },
          success: function(collection) {
            if (callback) {
              callback(collection);
            }
            return _this.sort();
          }
        });
      }
    };

    PhotoCommentsCollection.prototype.parse = function(data) {
      var entry, _i, _len, _ref, _results;
      this.total = data.totalResults;
      this.perPage = data.itemsPerPage;
      this.startIndex = data.startIndex;
      this.length += data.perPage;
      _ref = data.entry;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        entry = _ref[_i];
        console.log(entry);
        _results.push(entry);
      }
      return _results;
    };

    PhotoCommentsCollection.prototype.comparator = function(row1, row2) {
      if (row1.get('timestamp') * 1 > row2.get('timestamp') * 1) {
        return 1;
      }
      if (row1.get('timestamp') * 1 < row2.get('timestamp') * 1) {
        return -1;
      }
      if (row1.get('timestamp') * 1 === row2.get('timestamp') * 1) {
        return 0;
      }
    };

    return PhotoCommentsCollection;

  })(Collection);
  
}});

window.require.define({"models/base/localstorage": function(exports, require, module) {
  var Chaplin, LocalStorage,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  module.exports = LocalStorage = (function(_super) {

    __extends(LocalStorage, _super);

    function LocalStorage() {
      return LocalStorage.__super__.constructor.apply(this, arguments);
    }

    LocalStorage.prototype.url = "/";

    LocalStorage.prototype.sync = function(method, model, options) {
      var output, storage, _ref;
      storage = localStorage;
      switch (method) {
        case 'create':
        case 'update':
          if ((_ref = model.id) == null) {
            model.id = 1;
          }
          output = storage.setItem(model.url, JSON.stringify(model.toJSON()));
          break;
        case 'delete':
          output = storage.removeItem(model.url);
          break;
        case 'read':
          output = storage.getItem(model.url);
          if (output !== null) {
            output = JSON.parse(output);
          }
          console.log("LocalStorage dla \"/login:\"", output);
      }
      if (typeof options.success === "function") {
        options.success(output);
      }
      return true;
    };

    return LocalStorage;

  })(Chaplin.Model);
  
}});

window.require.define({"models/base/model": function(exports, require, module) {
  var Chaplin, Model,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  module.exports = Model = (function(_super) {

    __extends(Model, _super);

    function Model() {
      return Model.__super__.constructor.apply(this, arguments);
    }

    return Model;

  })(Chaplin.Model);
  
}});

window.require.define({"models/base/storage": function(exports, require, module) {
  var Storage;

  module.exports = Storage = (function() {

    function Storage(prefix, storage) {
      this.prefix = prefix;
      this.storage = storage != null ? storage : localStorage;
    }

    Storage.prototype.set = function(model) {
      return this.storage.setItem(this.prefix + model.url, JSON.stringify(model.toJSON()));
    };

    Storage.prototype.get = function(model) {
      var output;
      output = this.storage.getItem(this.prefix + model.url);
      if (output !== null) {
        return JSON.parse(this.storage.getItem(this.prefix + model.url));
      } else {
        return output;
      }
    };

    Storage.prototype.remove = function(model) {
      return this.storage.removeItem(this.prefix + model.url);
    };

    return Storage;

  })();
  
}});

window.require.define({"models/birthdays-model": function(exports, require, module) {
  var Birthdays, Model,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('models/base/model');

  module.exports = Birthdays = (function(_super) {

    __extends(Birthdays, _super);

    function Birthdays() {
      return Birthdays.__super__.constructor.apply(this, arguments);
    }

    return Birthdays;

  })(Model);
  
}});

window.require.define({"models/event-model": function(exports, require, module) {
  var EventModel, Model,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('./base/model');

  module.exports = EventModel = (function(_super) {

    __extends(EventModel, _super);

    function EventModel() {
      return EventModel.__super__.constructor.apply(this, arguments);
    }

    return EventModel;

  })(Model);
  
}});

window.require.define({"models/feed-collection": function(exports, require, module) {
  var CachedCollection, Collection, EventModel, FeedCollection, PhotoModel, ShoutModel, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
    __indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

  mediator = require('chaplin').mediator;

  Collection = require('models/base/collection');

  CachedCollection = require('models/base/cached-collection');

  ShoutModel = require('models/shout-model');

  PhotoModel = require('models/photo-model');

  EventModel = require('models/event-model');

  module.exports = FeedCollection = (function(_super) {

    __extends(FeedCollection, _super);

    function FeedCollection() {
      return FeedCollection.__super__.constructor.apply(this, arguments);
    }

    FeedCollection.prototype.url = '/aifeed';

    FeedCollection.prototype.comparator = function(row1, row2) {
      if (row1.get('sort_timestamp') * 1 < row2.get('sort_timestamp') * 1) {
        return 1;
      }
      if (row1.get('sort_timestamp') * 1 > row2.get('sort_timestamp') * 1) {
        return -1;
      }
      if (row1.get('sort_timestamp') * 1 === row2.get('sort_timestamp') * 1) {
        return 0;
      }
    };

    FeedCollection.prototype.offset = 0;

    FeedCollection.prototype.limit = 10;

    FeedCollection.prototype.escape = function(elementHtml) {
      return $('<span/>').text(elementHtml).html();
    };

    FeedCollection.prototype.refresh = function(callback) {
      var _this = this;
      this.once("add", callback);
      return this.fetch({
        update: true,
        remove: true,
        refresh: true,
        success: function(collection) {
          var buttonRefresh;
          _this.sort();
          $('.refresh-info').addClass('hidden');
          $('.refresh-info')[0].style.webkitTransform = 'scale(1)';
          buttonRefresh = $('.btn-refresh');
          $('.btn-refresh').removeClass('hidden');
          buttonRefresh[0].style.display = 'none';
          buttonRefresh[0].offsetHeight;
          buttonRefresh[0].style.display = 'block';
          buttonRefresh[0].style.webkitTransform = 'scale(1)';
          return _this.off("add", callback);
        }
      });
    };

    FeedCollection.prototype.parse = function(feed) {
      var collection, date, event, eventHead, eventHtml, htmlAnchors, htmlP, model, row, tempHtml, user_id, _i, _len, _ref, _ref1, _ref2, _ref3, _results,
        _this = this;
      _results = [];
      for (_i = 0, _len = feed.length; _i < _len; _i++) {
        row = feed[_i];
        date = new Date();
        date.setTime(row.timestamp * 1000);
        row.time = date.toString();
        if (row.feed_type === 'shout' || row.feed_type === 'photo') {
          _.each(row.events_box, function(event) {
            var eventHead, eventHtml, htmlAnchors, htmlP, tempHtml, _ref;
            tempHtml = '';
            try {
              eventHtml = $(event.html);
              eventHead = $(eventHtml.find('span')[0]);
              if (eventHead.text().indexOf('Wpis użytkownika') === 0) {
                tempHtml += _this.escape($(eventHead[0].childNodes[0]).text());
                tempHtml += '<strong>' + _this.escape($(eventHead[0].childNodes[1]).text()) + '</strong>';
                tempHtml += _this.escape($(eventHtml.find('p')[0].childNodes[3]).text());
                tempHtml += '<strong>' + _this.escape($(eventHtml.find('p')[0].childNodes[4]).text()) + '</strong>';
                event.html = tempHtml;
              } else if (eventHead.text().indexOf('Twój wpis') === 0) {
                tempHtml += _this.escape($(eventHead[0].childNodes[0]).text().slice(0, -1));
                tempHtml += _this.escape($(eventHtml.find('p')[0].childNodes[3]).text());
                tempHtml += '<strong>' + _this.escape($(eventHtml.find('p')[0].childNodes[4]).text()) + '</strong>';
                event.html = tempHtml;
              } else {
                try {
                  htmlP = $($(event.html).find('p')[0]);
                  htmlAnchors = htmlP.find('a');
                  _.each(htmlAnchors, function(el) {
                    if (/profile\/[0-9]+$/.test(el.href)) {
                      return $(el).after('<strong>' + _this.escape($(el).text()) + '</strong>');
                    } else {
                      return $(el).after(_this.escape($(el).text()));
                    }
                  });
                  $(htmlP.find('a')).remove();
                  if ((_ref = htmlP[0]) != null ? _ref.innerHTML : void 0) {
                    tempHtml = htmlP[0].innerHTML;
                    event.html = tempHtml;
                  }
                } catch (_error) {}
              }
              event.parsed = true;
            } catch (_error) {}
            if (event.parsed !== true && tempHtml.length === 0) {
              event.html = _this.escape($(event.html).text());
              return event.parsed = true;
            }
          });
        }
        if (row.feed_type === 'event') {
          event = row;
          tempHtml = '';
          try {
            eventHtml = $(event.html);
            eventHead = $(eventHtml.find('span')[0]);
            if (eventHead.text().indexOf('Wpis użytkownika') === 0) {
              tempHtml += this.escape($(eventHead[0].childNodes[0]).text());
              tempHtml += '<strong>' + this.escape($(eventHead[0].childNodes[1]).text()) + '</strong>';
              tempHtml += ' <span class="shout_event">' + this.escape($(eventHtml.find('p')[0].childNodes[2]).text()) + '</span> ';
              tempHtml += this.escape($(eventHtml.find('p')[0].childNodes[3]).text());
              tempHtml += '<strong>' + this.escape($(eventHtml.find('p')[0].childNodes[4]).text()) + '</strong>';
              row.content = tempHtml;
            } else if (eventHead.text().indexOf('Twój wpis') === 0) {
              tempHtml += this.escape($(eventHead[0].childNodes[0]).text().slice(0, -1));
              tempHtml += ' <span class="shout_event">' + this.escape($(eventHtml.find('p')[0].childNodes[2]).text()) + '</span> ';
              tempHtml += this.escape($(eventHtml.find('p')[0].childNodes[3]).text());
              tempHtml += '<strong>' + this.escape($(eventHtml.find('p')[0].childNodes[4]).text()) + '</strong>';
              row.content = tempHtml;
            } else {
              try {
                htmlP = $(eventHtml.find('p')[0]);
                htmlAnchors = htmlP.find('a');
                _.each(htmlAnchors, function(el) {
                  var escapedEl;
                  escapedEl = _this.escape($(el).text());
                  if (/profile\/[0-9]+$/.test(el.href) && $(el).text() !== 'profilu') {
                    return $(el).after('<strong>' + escapedEl + '</strong>');
                  } else {
                    return $(el).after(escapedEl);
                  }
                });
                $($(htmlP).find('a')).remove();
                if ((_ref = htmlP[0]) != null ? _ref.innerHTML : void 0) {
                  tempHtml = htmlP[0].innerHTML;
                  if (tempHtml !== '') {
                    row.content = tempHtml;
                  }
                }
                row.parsed = true;
              } catch (_error) {}
            }
          } catch (_error) {}
          if (row.parsed !== true && tempHtml.length === 0) {
            row.content = this.escape($(event.html).text());
            row.parsed = true;
          }
        }
        if (row.feed_type === 'photo') {
          row.user_id = (_ref1 = row.author.raw_user) != null ? _ref1.uid : void 0;
          row.photo_id = row.photo_id || row.id;
        }
        if (row.feed_type === 'shout') {
          row.id = row.feed_type + '/' + row.user_id + '/' + row.shout_id + '/' + row.sort_timestamp;
        } else {
          row.id = row.feed_type + '/' + (((_ref2 = row.author.raw_user) != null ? _ref2.uid : void 0) || ((_ref3 = row.author.raw_group) != null ? _ref3.id : void 0)) + '/' + (row.photo_id || row.sort_timestamp) + '/' + row.sort_timestamp;
        }
        if (row.feed_type === 'event' && row.type === 152) {
          row.type_event = true;
        }
        user_id = parseInt(mediator.auth.get('id'), 10);
        if (row.feed_type === 'shout') {
          if ((__indexOf.call(row.stars_authors_ids, user_id) >= 0)) {
            row.starred = true;
          }
        }
        model = (function() {
          switch (row.feed_type) {
            case 'shout':
              return new ShoutModel(row);
            case 'event':
              return new EventModel(row);
            case 'photo':
              return new PhotoModel(row);
            default:
              return row;
          }
        })();
        collection = this;
        model.on('change', function() {
          collection.add(this, {
            merge: true
          });
          return collection.sync('update', collection, {
            local: true,
            success: (function() {})
          });
        });
        _results.push(model);
      }
      return _results;
    };

    return FeedCollection;

  })(CachedCollection);
  
}});

window.require.define({"models/feed-photo-model": function(exports, require, module) {
  var FeedPhotoModel, Model,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('./base/model');

  module.exports = FeedPhotoModel = (function(_super) {

    __extends(FeedPhotoModel, _super);

    function FeedPhotoModel() {
      return FeedPhotoModel.__super__.constructor.apply(this, arguments);
    }

    FeedPhotoModel.prototype.url = function() {
      return "photo/" + this.get("id");
    };

    return FeedPhotoModel;

  })(Model);
  
}});

window.require.define({"models/mail-collection": function(exports, require, module) {
  var Collection, MailCollection, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('models/base/collection');

  mediator = require('chaplin').mediator;

  module.exports = MailCollection = (function(_super) {

    __extends(MailCollection, _super);

    function MailCollection() {
      return MailCollection.__super__.constructor.apply(this, arguments);
    }

    MailCollection.prototype.url = '/mail/inbox';

    MailCollection.prototype.parse = function(data) {
      var entry, _i, _len, _ref, _results;
      this.total = data.totalResults;
      this.perPage = data.itemsPerPage;
      this.startIndex = data.startIndex;
      _ref = data.entry;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        entry = _ref[_i];
        _results.push(entry);
      }
      return _results;
    };

    return MailCollection;

  })(Collection);
  
}});

window.require.define({"models/mail-model": function(exports, require, module) {
  var MailModel, Model,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('./base/model');

  module.exports = MailModel = (function(_super) {

    __extends(MailModel, _super);

    function MailModel() {
      return MailModel.__super__.constructor.apply(this, arguments);
    }

    MailModel.prototype.url = function() {
      return "/mail/inbox/" + this.get("id");
    };

    return MailModel;

  })(Model);
  
}});

window.require.define({"models/photo-collection": function(exports, require, module) {
  var Collection, PhotoCollection, PhotoModel,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('models/base/collection');

  PhotoModel = require('models/photo-model');

  module.exports = PhotoCollection = (function(_super) {

    __extends(PhotoCollection, _super);

    function PhotoCollection() {
      return PhotoCollection.__super__.constructor.apply(this, arguments);
    }

    PhotoCollection.prototype.initialize = function(photos, options) {
      this.userId = options.userId;
      this.albumId = options.albumId;
      return PhotoCollection.__super__.initialize.apply(this, arguments);
    };

    PhotoCollection.prototype.url = function(e) {
      return '/profile/' + this.userId + '/album/' + this.albumId;
    };

    PhotoCollection.prototype.parse = function(coll) {
      var photo, _i, _len, _ref, _results;
      this.total = coll.photo_count;
      _ref = coll.photos;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        photo = _ref[_i];
        photo.photo_id = photo.id;
        _results.push(new PhotoModel(photo));
      }
      return _results;
    };

    return PhotoCollection;

  })(Collection);
  
}});

window.require.define({"models/photo-model": function(exports, require, module) {
  var Model, PhotoCommentsCollection, PhotoModel, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('./base/model');

  mediator = require('mediator');

  PhotoCommentsCollection = require('models/photo/comments-collection');

  module.exports = PhotoModel = (function(_super) {

    __extends(PhotoModel, _super);

    function PhotoModel() {
      this.addStar = __bind(this.addStar, this);
      return PhotoModel.__super__.constructor.apply(this, arguments);
    }

    PhotoModel.prototype.url = function() {
      if (this.get('gallery_id')) {
        return "/gallery/" + this.get("gallery_id") + '/photo/' + this.get("photo_id");
      } else {
        return "/profile/" + this.get("user_id") + '/album/' + this.get("album_id") + '/' + this.get("photo_id");
      }
    };

    PhotoModel.prototype.initialize = function(data) {
      var userId;
      PhotoModel.__super__.initialize.apply(this, arguments);
      if (data && data.gallery_id) {
        userId = parseInt(mediator.auth.id);
        try {
          if (data.author.raw_user.uid === userId || !data.ratings) {
            return this.attributes.cannot_rate = true;
          } else {
            return this.attributes.cannot_rate = false;
          }
        } catch (e) {
          return this.attributes.cannot_rate = false;
        }
      }
    };

    PhotoModel.prototype.getComments = function() {
      return new PhotoCommentsCollection(this.attributes.author.raw_user.uid, this.get("album_id"), this.get("photo_id"));
    };

    PhotoModel.prototype.getStars = function() {
      return new ShoutStarsCollection(this.get("user_id"), this.get("shout_id"));
    };

    PhotoModel.prototype.parse = function(response) {
      var userId;
      userId = parseInt(mediator.auth.id);
      if (response.author.raw_user.uid === userId || !response.ratings || response.rated) {
        this.attributes.cannot_rate = true;
      } else {
        this.attributes.cannot_rate = false;
      }
      return PhotoModel.__super__.parse.apply(this, arguments);
    };

    PhotoModel.prototype.addStar = function(callback) {
      var gallery_id, photo_id,
        _this = this;
      gallery_id = this.get("gallery_id");
      photo_id = this.get("photo_id");
      return $.ajax("/gallery/" + gallery_id + "/photo/" + photo_id + "/rating", {
        type: 'post',
        data: JSON.stringify({
          rating: 5
        }),
        success: function() {
          var rating;
          rating = _this.get("ratings");
          rating.rating_count += 1;
          _this.set("rating_count", rating);
          _this.trigger('change');
          return callback();
        }
      });
    };

    return PhotoModel;

  })(Model);
  
}});

window.require.define({"models/photo/comment-model": function(exports, require, module) {
  var CommentModel, Model,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('models/base/model');

  module.exports = CommentModel = (function(_super) {

    __extends(CommentModel, _super);

    function CommentModel() {
      this.url = __bind(this.url, this);
      return CommentModel.__super__.constructor.apply(this, arguments);
    }

    CommentModel.prototype.idAttribute = 'id';

    CommentModel.prototype.url = function() {
      return "/photo/comment_add";
    };

    return CommentModel;

  })(Model);
  
}});

window.require.define({"models/photo/comments-collection": function(exports, require, module) {
  var CommentModel, CommentsCollection, PhotoCommentsCollection,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CommentsCollection = require('models/base/comments-collection');

  CommentModel = require('models/photo/comment-model');

  module.exports = PhotoCommentsCollection = (function(_super) {

    __extends(PhotoCommentsCollection, _super);

    PhotoCommentsCollection.prototype.model = CommentModel;

    function PhotoCommentsCollection(user_id, album_id, photo_id) {
      this.user_id = user_id;
      this.album_id = album_id;
      this.photo_id = photo_id;
      PhotoCommentsCollection.__super__.constructor.call(this);
    }

    PhotoCommentsCollection.prototype.url = function() {
      return "/profile/" + this.user_id + "/album/" + this.album_id + "/" + this.photo_id + "/comments";
    };

    return PhotoCommentsCollection;

  })(CommentsCollection);
  
}});

window.require.define({"models/photo/stars-collection": function(exports, require, module) {
  var Collection, ShoutStarsCollection,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('models/base/collection');

  module.exports = ShoutStarsCollection = (function(_super) {

    __extends(ShoutStarsCollection, _super);

    function ShoutStarsCollection(user_id, shout_id) {
      this.user_id = user_id;
      this.shout_id = shout_id;
      ShoutStarsCollection.__super__.constructor.call(this);
    }

    ShoutStarsCollection.prototype.url = function() {
      return "/shout/" + this.user_id + "/" + this.shout_id + "/fajne";
    };

    ShoutStarsCollection.prototype.parse = function(data) {
      var entry, _i, _len, _ref, _results;
      this.total = data.total_results;
      this.perPage = data.itemsPerPage;
      this.startIndex = data.startIndex;
      _ref = data.entry;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        entry = _ref[_i];
        _results.push(entry);
      }
      return _results;
    };

    return ShoutStarsCollection;

  })(Collection);
  
}});

window.require.define({"models/profile-comment-collection": function(exports, require, module) {
  var CommentsCollection, ProfileCommentCollection,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CommentsCollection = require('models/base/comments-collection');

  module.exports = ProfileCommentCollection = (function(_super) {

    __extends(ProfileCommentCollection, _super);

    function ProfileCommentCollection() {
      return ProfileCommentCollection.__super__.constructor.apply(this, arguments);
    }

    ProfileCommentCollection.prototype.initialize = function(models, options) {
      this.userId = options.user_id;
      return ProfileCommentCollection.__super__.initialize.call(this);
    };

    ProfileCommentCollection.prototype.url = function(e) {
      return '/profile/' + this.userId + '/comments';
    };

    ProfileCommentCollection.prototype.parse = function(comments) {
      var comment, _i, _len, _ref, _results;
      this.total = comments.totalResults;
      _ref = comments.entry;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        comment = _ref[_i];
        _results.push(comment);
      }
      return _results;
    };

    ProfileCommentCollection.prototype.comparator = function(row1, row2) {
      if (row1.get('datetime') * 1 < row2.get('datetime') * 1) {
        return 1;
      }
      if (row1.get('datetime') * 1 > row2.get('datetime') * 1) {
        return -1;
      }
      if (row1.get('datetime') * 1 === row2.get('datetime') * 1) {
        return 0;
      }
    };

    return ProfileCommentCollection;

  })(CommentsCollection);
  
}});

window.require.define({"models/shout-model": function(exports, require, module) {
  var Model, ShoutCommentsCollection, ShoutModel, ShoutStarsCollection, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('./base/model');

  mediator = require('mediator');

  ShoutCommentsCollection = require('models/shout/comments-collection');

  ShoutStarsCollection = require('models/shout/stars-collection');

  module.exports = ShoutModel = (function(_super) {

    __extends(ShoutModel, _super);

    function ShoutModel() {
      return ShoutModel.__super__.constructor.apply(this, arguments);
    }

    ShoutModel.prototype.url = function() {
      return "/shout/" + this.get("user_id") + '/' + this.get("shout_id");
    };

    ShoutModel.prototype.getComments = function() {
      return new ShoutCommentsCollection(this.get("user_id"), this.get("shout_id"));
    };

    ShoutModel.prototype.getStars = function() {
      return new ShoutStarsCollection(this.get("user_id"), this.get("shout_id"));
    };

    ShoutModel.prototype.addStar = function(callback) {
      var shout_id, user_id,
        _this = this;
      user_id = this.get("user_id");
      shout_id = this.get("shout_id");
      return $.ajax("/shout/fajne_add", {
        type: 'post',
        data: JSON.stringify({
          shout_user_id: user_id,
          shout_id: shout_id
        }),
        success: function() {
          var stars_authors_ids;
          _this.set("star_count", _this.get("star_count") + 1, {
            silent: true
          });
          stars_authors_ids = _this.get("stars_authors_ids");
          stars_authors_ids.push(mediator.auth.id);
          _this.set("stars_authors_ids", _.unique(stars_authors_ids), {
            silent: true
          });
          _this.set("starred", true, {
            silent: true
          });
          _this.trigger('change');
          return callback();
        }
      });
    };

    return ShoutModel;

  })(Model);
  
}});

window.require.define({"models/shout/comment-model": function(exports, require, module) {
  var CommentModel, Model,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('models/base/model');

  module.exports = CommentModel = (function(_super) {

    __extends(CommentModel, _super);

    function CommentModel() {
      return CommentModel.__super__.constructor.apply(this, arguments);
    }

    CommentModel.prototype.idAttribute = 'comment_id';

    CommentModel.prototype.url = "/shout/comment_add";

    return CommentModel;

  })(Model);
  
}});

window.require.define({"models/shout/comments-collection": function(exports, require, module) {
  var CommentModel, CommentsCollection, ShoutCommentsCollection,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CommentsCollection = require('models/base/comments-collection');

  CommentModel = require('models/shout/comment-model');

  module.exports = ShoutCommentsCollection = (function(_super) {

    __extends(ShoutCommentsCollection, _super);

    ShoutCommentsCollection.prototype.model = CommentModel;

    function ShoutCommentsCollection(user_id, shout_id) {
      this.user_id = user_id;
      this.shout_id = shout_id;
      ShoutCommentsCollection.__super__.constructor.call(this);
    }

    ShoutCommentsCollection.prototype.url = function() {
      return "/shout/" + this.user_id + "/" + this.shout_id + "/comments";
    };

    return ShoutCommentsCollection;

  })(CommentsCollection);
  
}});

window.require.define({"models/shout/stars-collection": function(exports, require, module) {
  var Collection, ShoutStarsCollection,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('models/base/collection');

  module.exports = ShoutStarsCollection = (function(_super) {

    __extends(ShoutStarsCollection, _super);

    ShoutStarsCollection.prototype.total = 0;

    ShoutStarsCollection.prototype.perPage = 0;

    ShoutStarsCollection.prototype.startIndex = 0;

    ShoutStarsCollection.prototype.offset = 0;

    ShoutStarsCollection.prototype.limit = 10;

    function ShoutStarsCollection(user_id, shout_id) {
      this.user_id = user_id;
      this.shout_id = shout_id;
      this.getOlderStars = __bind(this.getOlderStars, this);

      ShoutStarsCollection.__super__.constructor.call(this);
    }

    ShoutStarsCollection.prototype.url = function() {
      return "/shout/" + this.user_id + "/" + this.shout_id + "/fajne";
    };

    ShoutStarsCollection.prototype.parse = function(data) {
      var entry, _i, _len, _ref, _results;
      this.total = data.totalResults;
      this.perPage = data.itemsPerPage;
      this.startIndex = data.startIndex;
      this.length += data.perPage;
      _ref = data.entry;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        entry = _ref[_i];
        _results.push(entry);
      }
      return _results;
    };

    ShoutStarsCollection.prototype.getOlderStars = function() {
      if (this.total > this.models.length) {
        this.offset += this.limit;
        return this.fetch({
          update: true,
          remove: false,
          data: {
            offset: this.offset,
            limit: this.limit
          }
        });
      }
    };

    return ShoutStarsCollection;

  })(Collection);
  
}});

window.require.define({"models/user-collection": function(exports, require, module) {
  var Collection, UserCollection, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Collection = require('models/base/collection');

  mediator = require('chaplin').mediator;

  module.exports = UserCollection = (function(_super) {

    __extends(UserCollection, _super);

    function UserCollection() {
      return UserCollection.__super__.constructor.apply(this, arguments);
    }

    UserCollection.prototype.initialize = function(models, options) {
      this.userId = options.id;
      return UserCollection.__super__.initialize.call(this);
    };

    UserCollection.prototype.url = function(e) {
      return '/friends/' + this.userId;
    };

    UserCollection.prototype.parse = function(users) {
      var user, _i, _len, _ref, _results;
      this.total = users.total_results;
      this.count = users.count;
      _ref = users.entry;
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        user = _ref[_i];
        _results.push(user);
      }
      return _results;
    };

    return UserCollection;

  })(Collection);
  
}});

window.require.define({"models/user-model": function(exports, require, module) {
  var Model, UserModel,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Model = require('./base/model');

  module.exports = UserModel = (function(_super) {

    __extends(UserModel, _super);

    function UserModel() {
      return UserModel.__super__.constructor.apply(this, arguments);
    }

    UserModel.prototype.url = function() {
      return "/profile/" + this.get("id");
    };

    return UserModel;

  })(Model);
  
}});

window.require.define({"routes": function(exports, require, module) {
  
  module.exports = function(match) {
    match('', 'feed#index');
    match('refresh', 'feed#refresh');
    match('poczta', 'mail#index');
    match('mail/:mail_id', 'mail#details', {
      constraints: {
        mail_id: /^\d+$/
      }
    });
    match('mail/:user_id/compose', 'mail#compose', {
      constraints: {
        user_id: /^\d+$/
      }
    });
    match('profile/:user_id', 'profile#index', {
      constraints: {
        user_id: /^\d+$/
      }
    });
    match('profile/:user_id/friends', 'profile#friends', {
      constraints: {
        user_id: /^\d+$/
      }
    });
    match('profile/:user_id/gallery', 'profile#gallery', {
      constraints: {
        user_id: /^\d+$/
      }
    });
    match('shout/:user_id/:shout_id/comments', 'shout#showComments');
    match('shout/:user_id/:shout_id/stars', 'shout#showStars');
    match('photo/:user_id/:album_id/:photo_id', 'photo#showPhotoPage');
    match('galleryphoto/:gallery_id/:photo_id', 'photo#showPhotoPage');
    match('photo/:user_id/:album_id/:photo_id/comments', 'photo#showComments');
    match('galleryphoto/:gallery_id/:photo_id/comments', 'photo#showComments');
    match('photo/:user_id/:album_id/:photo_id/addComment', 'photo#showAddComment');
    match('galleryphoto/:gallery_id/:photo_id/addComment', 'photo#showAddComment');
    match('album/:user_id/:album_id', 'profile#album', {
      constraints: {
        user_id: /^\d+$/,
        album_id: /^\d+$/
      }
    });
    match('photo/add/camera', 'photo#addFromCamera');
    return match('photo/add/album', 'photo#addFromAlbum');
  };
  
}});

window.require.define({"views/albumlist-view": function(exports, require, module) {
  var AlbumlistView, PageView, template,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  template = require('views/templates/albumlist');

  module.exports = AlbumlistView = (function(_super) {

    __extends(AlbumlistView, _super);

    function AlbumlistView() {
      return AlbumlistView.__super__.constructor.apply(this, arguments);
    }

    AlbumlistView.template('albumlist');

    AlbumlistView.prototype.container = '#albumlist-container';

    AlbumlistView.prototype.autoRender = false;

    AlbumlistView.prototype.initialize = function(options) {
      this.data = options.data;
      console.log(this.data);
      return AlbumlistView.__super__.initialize.call(this);
    };

    AlbumlistView.prototype.getTemplateData = function() {
      return this.data;
    };

    return AlbumlistView;

  })(PageView);
  
}});

window.require.define({"views/base/cachable-view": function(exports, require, module) {
  var CachableView, View, nextTick,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  nextTick = require('lib/next-tick');

  module.exports = CachableView = (function(_super) {

    __extends(CachableView, _super);

    function CachableView() {
      var cached;
      cached = this.constructor.cached;
      if (!cached) {
        CachableView.__super__.constructor.apply(this, arguments);
        return;
      } else {
        if (cached.autoRender) {
          cached.render();
        }
        console.log("returned from grave:", cached);
        return cached;
      }
    }

    CachableView.prototype.render = function() {
      if (!this.constructor.cached) {
        CachableView.__super__.render.apply(this, arguments);
      }
    };

    CachableView.prototype.dispose = function() {
      $(window).unbind('scroll');
      this.constructor.cached = this;
      return this.$el = $(this.$el).detach();
    };

    return CachableView;

  })(View);
  
}});

window.require.define({"views/base/collection-view": function(exports, require, module) {
  var Chaplin, CollectionView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  View = require('views/base/view');

  module.exports = CollectionView = (function(_super) {

    __extends(CollectionView, _super);

    function CollectionView() {
      return CollectionView.__super__.constructor.apply(this, arguments);
    }

    CollectionView.prototype.getTemplateFunction = View.prototype.getTemplateFunction;

    CollectionView.prototype.animationDuration = 0;

    CollectionView.prototype.afterRender = function() {
      CollectionView.__super__.afterRender.apply(this, arguments);
      return this.trigger("afterRender");
    };

    return CollectionView;

  })(Chaplin.CollectionView);
  
}});

window.require.define({"views/base/modal-view": function(exports, require, module) {
  var ModalView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  module.exports = ModalView = (function(_super) {

    __extends(ModalView, _super);

    function ModalView() {
      return ModalView.__super__.constructor.apply(this, arguments);
    }

    ModalView.prototype.autoRender = true;

    ModalView.prototype.container = "#modal";

    return ModalView;

  })(View);
  
}});

window.require.define({"views/base/page-view": function(exports, require, module) {
  var PageView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  module.exports = PageView = (function(_super) {

    __extends(PageView, _super);

    function PageView() {
      return PageView.__super__.constructor.apply(this, arguments);
    }

    PageView.prototype.container = '#page-container';

    PageView.prototype.afterRender = function() {
      var subview, _i, _len, _ref, _results;
      PageView.__super__.afterRender.apply(this, arguments);
      this.enableScroll();
      if (this.subviews) {
        _ref = this.subviews;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          subview = _ref[_i];
          _results.push(subview.render());
        }
        return _results;
      }
    };

    PageView.prototype.disableScroll = function() {
      var _this = this;
      return $(document.body).bind('touchmove.stop-scroll', function(e) {
        return e.preventDefault();
      });
    };

    PageView.prototype.enableScroll = function() {
      return $(document.body).unbind('touchmove.stop-scroll');
    };

    return PageView;

  })(View);
  
}});

window.require.define({"views/base/refresh-view": function(exports, require, module) {
  var PageView, RefreshView,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  module.exports = RefreshView = (function(_super) {

    __extends(RefreshView, _super);

    function RefreshView() {
      this.scrollTop = __bind(this.scrollTop, this);
      return RefreshView.__super__.constructor.apply(this, arguments);
    }

    RefreshView.prototype.autoRender = false;

    RefreshView.prototype.container = "#page-container";

    RefreshView.prototype.events = {
      'click .scroll-top': 'scrollTop'
    };

    RefreshView.prototype.scrollTop = function() {
      return window.scrollTo(0, 0);
    };

    RefreshView.prototype.afterRender = function() {
      var subview, _i, _len, _ref, _results;
      RefreshView.__super__.afterRender.apply(this, arguments);
      if (this.subviews) {
        _ref = this.subviews;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          subview = _ref[_i];
          _results.push(subview.on("visibilityChange", function() {
            return $('.scroll-top, .btn-refresh').removeClass('hidden');
          }));
        }
        return _results;
      }
    };

    return RefreshView;

  })(PageView);
  
}});

window.require.define({"views/base/view": function(exports, require, module) {
  var Chaplin, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  require('lib/view-helper');

  module.exports = View = (function(_super) {

    __extends(View, _super);

    function View() {
      return View.__super__.constructor.apply(this, arguments);
    }

    View.template = function(template) {
      return this.prototype.template = require('views/templates/' + template);
    };

    View.prototype.initialize = function() {
      this.new_position = window.top.scrollPositions[location.hash.toString() || 'main'] || 0;
      return View.__super__.initialize.apply(this, arguments);
    };

    View.prototype.getTemplateFunction = function() {
      return this.template;
    };

    View.prototype.afterRender = function() {
      View.__super__.afterRender.apply(this, arguments);
      return this.trigger("afterRender");
    };

    View.prototype.scroll = function() {
      var new_position,
        _this = this;
      new_position = this.new_position;
      setTimeout(function() {
        try {
          console.log(_this.constructor.name);
          console.log(location.hash.toString());
          console.log('szybki new pos ' + new_position + ' last el:' + $($('#feed-container article').last()).position().top);
          console.log('szybki wysokosc ' + $('#feed-container').height());
        } catch (_error) {}
        if (new_position > 0) {
          window.scrollTo(0, new_position);
          return setTimeout(function() {
            window.last_scroll = 0;
            return console.log('zeruje scroll');
          }, 100);
        }
      }, 133);
      return setTimeout(function() {
        try {
          console.log(_this.constructor.name);
          console.log(location.hash.toString());
          console.log('czas - ' + (new Date().getTime() - window.last_scroll));
          console.log('wolny new pos ' + new_position + ' last el:' + $($('#feed-container article').last()).position().top);
          console.log('wolny wysokosc ' + $('#feed-container').height());
        } catch (_error) {}
        console.log('czas - ' + (new Date().getTime() - window.last_scroll));
        if (new_position > 0 && (!window.last_scroll || window.last_scroll & (new Date().getTime() - window.last_scroll > 2800))) {
          console.log('slow scroll run!');
          return window.scrollTo(0, new_position);
        }
      }, 3100);
    };

    View.prototype.dispose = function() {
      $('.comment-add-focus').stop();
      return View.__super__.dispose.apply(this, arguments);
    };

    return View;

  })(Chaplin.View);
  
}});

window.require.define({"views/feed/birthdays-view": function(exports, require, module) {
  var BirthdaysView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  module.exports = BirthdaysView = (function(_super) {

    __extends(BirthdaysView, _super);

    function BirthdaysView() {
      return BirthdaysView.__super__.constructor.apply(this, arguments);
    }

    BirthdaysView.template('feed/birthdays');

    BirthdaysView.prototype.container = "#birthdays-container";

    BirthdaysView.prototype.autoRender = false;

    return BirthdaysView;

  })(View);
  
}});

window.require.define({"views/feed/event-feed-item-view": function(exports, require, module) {
  var EventFeedItemView, View, template,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  template = require('views/templates/feed-event');

  module.exports = EventFeedItemView = (function(_super) {

    __extends(EventFeedItemView, _super);

    function EventFeedItemView() {
      return EventFeedItemView.__super__.constructor.apply(this, arguments);
    }

    EventFeedItemView.prototype.template = template;

    EventFeedItemView.prototype.tagName = 'article';

    EventFeedItemView.prototype.className = 'media';

    EventFeedItemView.prototype.events = {
      'click .external_link': 'open_browser'
    };

    EventFeedItemView.prototype.open_browser = function(e) {
      var ref;
      e.preventDefault();
      ref = window.open(encodeURI(e.currentTarget.href), '_blank', 'location=yes,closebuttoncaption=Wróć');
      return false;
    };

    return EventFeedItemView;

  })(View);
  
}});

window.require.define({"views/feed/feed-item-view": function(exports, require, module) {
  var FeedItemView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  module.exports = FeedItemView = (function(_super) {

    __extends(FeedItemView, _super);

    function FeedItemView() {
      return FeedItemView.__super__.constructor.apply(this, arguments);
    }

    FeedItemView.template('feed/feed');

    FeedItemView.prototype.tagName = 'article';

    FeedItemView.prototype.className = 'media';

    return FeedItemView;

  })(View);
  
}});

window.require.define({"views/feed/feed-main-view": function(exports, require, module) {
  var FeedMainView, PhotoMainView, RefreshView, nextTick,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  RefreshView = require('views/base/refresh-view');

  nextTick = require('lib/next-tick');

  PhotoMainView = require('views/photo-main-view');

  module.exports = FeedMainView = (function(_super) {

    __extends(FeedMainView, _super);

    function FeedMainView() {
      this.afterRender = __bind(this.afterRender, this);

      this.render = __bind(this.render, this);

      this.dispose = __bind(this.dispose, this);

      this.refresh = __bind(this.refresh, this);

      this.getPhotoModelBySrc = __bind(this.getPhotoModelBySrc, this);
      return FeedMainView.__super__.constructor.apply(this, arguments);
    }

    FeedMainView.template('feed/main');

    FeedMainView.prototype.autoRender = false;

    FeedMainView.prototype.refreshOnInit = false;

    FeedMainView.prototype.events = {
      'click .main-img img': 'handleImageClick'
    };

    FeedMainView.prototype.getPhotoModelBySrc = function(coll, src) {
      var i;
      i = 0;
      while (i < coll.models.length) {
        if (coll.models[i].attributes.photo && coll.models[i].attributes.photo.uri === src) {
          return coll.models[i];
        }
        i++;
      }
      return null;
    };

    FeedMainView.prototype.handleImageClick = function(e) {
      var albumId, coll, img, photoId, photoModel, photoView, userId,
        _this = this;
      img = $(e.currentTarget);
      userId = img.attr('data-user-id');
      albumId = img.attr('data-album-id');
      photoId = img.attr('photo-id');
      e.preventDefault();
      coll = this.subview('feed').collection;
      photoModel = this.getPhotoModelBySrc(coll, img.attr('src'));
      photoView = new PhotoMainView();
      photoView.on('starAdded', function(photoModel) {
        return coll.add(photoModel, {
          merge: true
        });
      });
      return photoView.handleFullscreen(userId, albumId, {
        src: img.attr('src')
      }, photoModel);
    };

    FeedMainView.prototype.initialize = function(options) {
      var _this = this;
      this.subscribeEvent("!refresh", this.refresh);
      this.refreshOnInit = options.refresh;
      $('.btn-refresh').unbind('click');
      $('.btn-refresh').click(function() {
        return _this.refresh();
      });
      this.enableScroll();
      return FeedMainView.__super__.initialize.apply(this, arguments);
    };

    FeedMainView.prototype.refresh = function(callback) {
      var _ref;
      console.log('refresh');
      if ((_ref = this.subview('feed')) != null) {
        _ref.collection.refresh();
      }
      try {
        $('.btn-refresh').addClass('hidden');
        $('.refresh-info').removeClass('hidden');
      } catch (_error) {}
      return this.enableScroll();
    };

    FeedMainView.prototype.dispose = function() {
      var _ref;
      if ((_ref = this.addShoutButton) != null) {
        _ref.remove();
      }
      return FeedMainView.__super__.dispose.apply(this, arguments);
    };

    FeedMainView.prototype.render = function() {
      console.log('main feed');
      return FeedMainView.__super__.render.apply(this, arguments);
    };

    FeedMainView.prototype.afterRender = function() {
      var _ref,
        _this = this;
      FeedMainView.__super__.afterRender.apply(this, arguments);
      if (this.refreshOnInit === true) {
        this.refresh(function() {});
      } else {
        this.scroll();
        console.log('scrollujemy');
      }
      this.addShoutButton = $('<div><a href="#" class="btn btn-add-shout btn-danger">Dodaj wpis</a></div>');
      $('.topbar .action-button').append(this.addShoutButton);
      return (_ref = this.addShoutButton) != null ? _ref.click(function(e) {
        console.log('shout button');
        _this.disableScroll();
        _this.shoutAddForm = $('\
          <form name="form-shout-add" action="#" class="form-add-shout form_4_keyboard remove-on-backbutton">\
            <textarea class="shout-input content" placeholder="Treść"></textarea>\
            <div class="form_4_keyboard_btm">\
              <div class="only_friends_wrp">\
                <input class="only-friends" name="only-friends" type="checkbox" id="only-friends"  data-on="Tylko znajomi" data-off="Tylko znajomi">\
              </div>\
              <button style="display: block; z-index: 999; position:absolute; top: 0; right:-6px" class="btn submit-button remove-on-backbutton" type="submit">Dodaj</button>\
              <button style="display: block; z-index: 999; position:absolute; top: 0; right:67px" class="btn cancel-button" type="button">Anuluj</button>\
            </div>\
          </form>\
          <script>\
          $(".only_friends_wrp input[type=checkbox]").tzCheckbox();\
          </script>\
          ');
        $(document.body).prepend(_this.shoutAddForm);
        _this.addShoutButton.css('display', 'none');
        _this.content = _this.shoutAddForm.find('textarea.content');
        _this.toFriends = _this.shoutAddForm.find('input.only-friends');
        _this.content.click(function() {
          return _this.disableScroll();
        });
        setTimeout((function() {
          $('form').css('height', '100%');
          return $('form').css('width', '100%');
        }), 1000);
        $('.form-add-shout textarea')[0].focus();
        $('.cancel-button').click(function() {
          _this.shoutAddForm.remove();
          _this.addShoutButton.css('display', '');
          return _this.enableScroll();
        });
        return _this.shoutAddForm.submit(function(e) {
          var contentValue;
          console.log('wyslano wpis');
          e.preventDefault();
          contentValue = _this.content.val().trim();
          if (contentValue.length !== 0) {
            return $.ajax('/shout/add', {
              type: 'post',
              data: JSON.stringify({
                shout: contentValue,
                shout_privacy: _this.toFriends.attr('checked') === 'checked'
              }),
              success: function(data, status, jqXHR) {
                return window.alert('Wpis dodany', function() {
                  _this.shoutAddForm.remove();
                  _this.addShoutButton.css('display', '');
                  window.scrollTo(0, 0);
                  $('.refresh-info').removeClass('hidden');
                  $('.btn-refresh').addClass('hidden');
                  _this.enableScroll();
                  return setTimeout(function() {
                    return _this.refresh(function() {});
                  }, 2200);
                }, 'Wpis');
              },
              error: function(jqXHR) {
                _this.addShoutButton.css('display', '');
                _this.buttons.remove();
                _this.shoutAddForm.remove();
                _this.enableScroll();
                return _this.refresh();
              }
            });
          }
        });
      }) : void 0;
    };

    return FeedMainView;

  })(RefreshView);
  
}});

window.require.define({"views/feed/feed-view": function(exports, require, module) {
  var CollectionView, EventFeedItemView, FeedView, PhotoFeedItemView, ShoutFeedItemView, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CollectionView = require('views/base/collection-view');

  EventFeedItemView = require('views/feed/event-feed-item-view');

  ShoutFeedItemView = require('views/feed/shout-feed-item-view');

  PhotoFeedItemView = require('views/feed/photo-feed-item-view');

  mediator = require('mediator');

  module.exports = FeedView = (function(_super) {

    __extends(FeedView, _super);

    function FeedView() {
      return FeedView.__super__.constructor.apply(this, arguments);
    }

    FeedView.prototype.autoRender = false;

    FeedView.prototype.animationDuration = 0;

    FeedView.prototype.container = '#feed-container';

    FeedView.prototype.className = 'feed';

    FeedView.prototype.id = 'feed';

    FeedView.prototype.getView = function(model) {
      switch (model.attributes.feed_type) {
        case 'photo':
          return new PhotoFeedItemView({
            model: model
          });
        case 'event':
          return new EventFeedItemView({
            model: model
          });
        case 'shout':
          return new ShoutFeedItemView({
            model: model
          });
      }
    };

    return FeedView;

  })(CollectionView);
  
}});

window.require.define({"views/feed/photo-feed-item-view": function(exports, require, module) {
  var FeedCollection, PhotoFeedItemView, View, template,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  template = require('views/templates/feed-photo');

  FeedCollection = require('models/feed-collection');

  module.exports = PhotoFeedItemView = (function(_super) {

    __extends(PhotoFeedItemView, _super);

    function PhotoFeedItemView() {
      this.updateStar = __bind(this.updateStar, this);

      this.initialize = __bind(this.initialize, this);
      return PhotoFeedItemView.__super__.constructor.apply(this, arguments);
    }

    PhotoFeedItemView.prototype.template = template;

    PhotoFeedItemView.prototype.tagName = 'article';

    PhotoFeedItemView.prototype.container = ".photo-content";

    PhotoFeedItemView.prototype.className = 'media';

    PhotoFeedItemView.prototype.events = {
      'click .add-star': 'addStar',
      'click .disabled.star': 'doNothing'
    };

    PhotoFeedItemView.prototype.getTemplateData = function() {
      var data;
      data = _.clone(this.model.attributes);
      if (this.single) {
        data.last_comment = null;
      }
      return data;
    };

    PhotoFeedItemView.prototype.initialize = function(opts) {
      var _this = this;
      this.single = opts.single;
      PhotoFeedItemView.__super__.initialize.apply(this, arguments);
      if (this.single) {
        this.feed = new FeedCollection;
        this.feed.fetch({
          success: function() {
            var feedModel;
            feedModel = _this.feed.findWhere({
              photo_id: parseInt(_this.model.get('id')),
              album_id: parseInt(_this.model.get('album_id')),
              user_id: parseInt(_this.model.get('user_id'))
            });
            if (!feedModel) {
              try {
                feedModel = _this.feed.findWhere({
                  photo_id: parseInt(_this.model.get('id')),
                  album_id: parseInt(_this.model.get('album_id')),
                  user_id: parseInt(_this.model.get('author').raw_user.uid)
                });
              } catch (_error) {}
            }
            if (feedModel) {
              try {
                if (_this.model.get('comments').length > 0) {
                  feedModel.set('comments', _this.model.get('comments'));
                } else {
                  feedModel.set('comment_count', 0);
                }
              } catch (_error) {}
              try {
                return feedModel.set('ratings', _this.model.get('ratings'));
              } catch (_error) {}
            }
          }
        });
      }
      if (!this.single) {
        return this.model.on('change', function() {
          console.log("change photo feed item!");
          return _this.render();
        });
      }
    };

    PhotoFeedItemView.prototype.doNothing = function(e) {
      return e.preventDefault();
    };

    PhotoFeedItemView.prototype.addStar = function(e) {
      var addStarButton, _ref,
        _this = this;
      e.preventDefault();
      addStarButton = $(e.currentTarget);
      if (addStarButton.hasClass('disabled')) {
        return;
      }
      addStarButton.addClass('disabled', 'disabled');
      setTimeout(function() {
        return addStarButton.removeClass('disabled', 'disabled');
      }, 2000);
      return (_ref = this.model) != null ? _ref.addStar(function() {
        var countComments, feedModel;
        _this.render();
        if (_this.single) {
          countComments = $('.media .actions .count-comments');
          countComments.find('.comment_count').html(_this.model.get('comments').comment_count);
          countComments.removeClass('hide');
          _this.feed = new FeedCollection;
          _this.feed.fetch({
            success: function() {}
          }, feedModel = _this.feed.findWhere({
            photo_id: parseInt(_this.model.get('id')),
            album_id: parseInt(_this.model.get('album_id')),
            user_id: parseInt(_this.model.get('user_id'))
          }), (function() {
            if (!feedModel) {
              try {
                return feedModel = this.feed.findWhere({
                  photo_id: parseInt(this.model.get('id')),
                  album_id: parseInt(this.model.get('album_id')),
                  user_id: parseInt(this.model.get('author').raw_user.uid)
                });
              } catch (_error) {}
            }
          }).call(_this), (function() {
            if (feedModel) {
              try {
                if (this.model.get('comments').length > 0) {
                  feedModel.set('comments', this.model.get('comments'));
                } else {
                  feedModel.set('comment_count', 0);
                }
              } catch (_error) {}
              try {
                return feedModel.set('ratings', this.model.get('ratings'));
              } catch (_error) {}
            }
          }).call(_this));
        }
        return setTimeout(function() {
          return _this.updateStar();
        }, 10);
      }) : void 0;
    };

    PhotoFeedItemView.prototype.updateStar = function(photoModel) {
      var addStarButton, countComments;
      if (photoModel) {
        this.model.set(photoModel.attributes);
        this.render();
        countComments = $('.media .actions .count-comments');
        countComments.find('.comment_count').html(this.model.get('comments').comment_count);
        countComments.removeClass('hide');
      }
      addStarButton = $(this.el).find('.add-star');
      return addStarButton.html('<i class="icon-ok"></i>');
    };

    return PhotoFeedItemView;

  })(View);
  
}});

window.require.define({"views/feed/shout-feed-item-view": function(exports, require, module) {
  var ShoutFeedItemView, View, template,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  template = require('views/templates/feed-shout');

  module.exports = ShoutFeedItemView = (function(_super) {

    __extends(ShoutFeedItemView, _super);

    function ShoutFeedItemView() {
      return ShoutFeedItemView.__super__.constructor.apply(this, arguments);
    }

    ShoutFeedItemView.prototype.template = template;

    ShoutFeedItemView.prototype.tagName = 'article';

    ShoutFeedItemView.prototype.container = ".shout-content";

    ShoutFeedItemView.prototype.className = 'media';

    ShoutFeedItemView.prototype.events = {
      'click .add-star': 'addStar',
      'click .external_link': 'open_browser'
    };

    ShoutFeedItemView.prototype.open_browser = function(e) {
      var ref;
      e.preventDefault();
      ref = window.open(encodeURI(e.currentTarget.href), '_blank', 'location=yes,closebuttoncaption=Wróć');
      return false;
    };

    ShoutFeedItemView.prototype.initialize = function() {
      var _this = this;
      ShoutFeedItemView.__super__.initialize.apply(this, arguments);
      this.model.on('change', function() {
        console.log("change!");
        return _this.render();
      });
      return this.on("addedToDOM", function() {
        var el, escapedUrl, i, il, searchText, textUrl, urlR, urls;
        el = $(this.el).find('.feed-shout-content');
        if (el.hasClass('added')) {
          return;
        }
        el.addClass('added');
        searchText = $('<div />').text(el.text()).html();
        urlR = /(http|ftp|https):\/\/[\w-]+(\.[\w-]+)+([\w.,@?^=%&amp;:\/~+#-]*[\w@?^=%&amp;\/~+#-])?/ig;
        urls = searchText.match(urlR);
        if (!urls) {
          return;
        }
        i = 0;
        il = urls.length;
        while (i < il) {
          escapedUrl = $('<div />').text(urls[i]).html();
          if (escapedUrl.length > 30) {
            textUrl = escapedUrl.substring(0, 30) + '&hellip;';
          } else {
            textUrl = escapedUrl;
          }
          searchText = searchText.replace(urls[i], '<a class="external_link" href="' + escapedUrl + '">' + textUrl + '</a>');
          i++;
        }
        return el.html(searchText);
      });
    };

    ShoutFeedItemView.prototype.addStar = function(e) {
      var addStarButton, _ref;
      e.preventDefault();
      addStarButton = $(e.currentTarget);
      if (addStarButton.hasClass('disabled')) {
        return;
      }
      addStarButton.addClass('disabled');
      return (_ref = this.model) != null ? _ref.addStar(function() {
        return addStarButton.removeClass('disabled', 'disabled');
      }) : void 0;
    };

    return ShoutFeedItemView;

  })(View);
  
}});

window.require.define({"views/friendlist-view": function(exports, require, module) {
  var FriendlistView, View, template,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  template = require('views/templates/friendlist');

  module.exports = FriendlistView = (function(_super) {

    __extends(FriendlistView, _super);

    function FriendlistView() {
      return FriendlistView.__super__.constructor.apply(this, arguments);
    }

    FriendlistView.template('friendlist');

    FriendlistView.prototype.container = '#friendlist-container';

    FriendlistView.prototype.autoRender = false;

    FriendlistView.prototype.initialize = function(options) {
      this.data = options.data;
      console.log(this.data);
      return FriendlistView.__super__.initialize.call(this);
    };

    FriendlistView.prototype.getTemplateData = function() {
      return this.data;
    };

    FriendlistView.prototype.afterRender = function() {
      FriendlistView.__super__.afterRender.call(this);
      this.scroll();
      setTimeout(function() {
        if ($('.show-more').position().top < $('.navbar-fixed-bottom').position().top - window.scrollY) {
          console.log('hide');
          return $('.scroll-top').hide();
        } else {
          console.log('show');
          return $('.scroll-top').show();
        }
      }, 10);
      return setTimeout(function() {
        if ($('.show-more').position().top < $('.navbar-fixed-bottom').position().top - window.scrollY) {
          console.log('hide');
          return $('.scroll-top').hide();
        } else {
          console.log('show');
          return $('.scroll-top').show();
        }
      }, 200);
    };

    return FriendlistView;

  })(View);
  
}});

window.require.define({"views/friends-view": function(exports, require, module) {
  var FriendListView, FriendsView, View, template,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  template = require('views/templates/friends');

  FriendListView = require('views/friendlist-view');

  module.exports = FriendsView = (function(_super) {

    __extends(FriendsView, _super);

    function FriendsView() {
      this.renderList = __bind(this.renderList, this);

      this.doFilter = __bind(this.doFilter, this);

      this.filterUsers = __bind(this.filterUsers, this);

      this.showMore = __bind(this.showMore, this);

      this.scrollTop = __bind(this.scrollTop, this);

      this.reset = __bind(this.reset, this);

      this.hideReset = __bind(this.hideReset, this);

      this.showReset = __bind(this.showReset, this);

      this.initialize = __bind(this.initialize, this);
      return FriendsView.__super__.constructor.apply(this, arguments);
    }

    FriendsView.template('friends');

    FriendsView.prototype.container = '#page-container';

    FriendsView.prototype.autoRender = false;

    FriendsView.prototype.events = {
      'keyup .user-search .search-query': 'filterUsers',
      'click .show-more': 'showMore',
      'click .scroll-top': 'scrollTop',
      'click .reset-search': 'reset',
      'focus .user-search .search-query': 'showReset',
      'blur .user-search .search-query': 'hideReset',
      'submit .form-search.user-search': 'formSubmit'
    };

    FriendsView.prototype.page = 0;

    FriendsView.prototype.perPage = 18;

    FriendsView.prototype.list = [];

    FriendsView.prototype.initialize = function() {
      this.renderBounce = _.debounce(this.renderList, 100);
      return FriendsView.__super__.initialize.call(this);
    };

    FriendsView.prototype.formSubmit = function(e) {
      return e.preventDefault();
    };

    FriendsView.prototype.showReset = function() {
      $('.input-spreader').removeClass('full');
      return $('.reset-search').removeClass('hidden');
    };

    FriendsView.prototype.hideReset = function() {
      return setTimeout(function() {
        if ($('.user-search .search-query').val().length === 0) {
          $('.input-spreader').addClass('full');
          return $('.reset-search').addClass('hidden');
        }
      }, 100);
    };

    FriendsView.prototype.reset = function() {
      var user_id;
      if ($('.user-search .search-query').val()) {
        $('.input-spreader').addClass('full');
        $('.reset-search').addClass('hidden');
        this.page = 0;
        this.list = this.collection.models;
        user_id = parseInt(this.collection.userId);
        window.friends_page[user_id] = 0;
        window.friends[user_id] = this.list.concat([]);
        window.friends_filter[user_id] = '';
        return this.renderList(true);
      }
    };

    FriendsView.prototype.scrollTop = function() {
      return window.scrollTo(0, 0);
    };

    FriendsView.prototype.showMore = function() {
      var user_id;
      this.page++;
      user_id = parseInt(this.collection.userId);
      window.friends_page[user_id] = this.page;
      return this.renderList(false);
    };

    FriendsView.prototype.filterUsers = function(e) {
      var search, user_id;
      user_id = parseInt(this.collection.userId);
      search = e.currentTarget.value;
      this.page = 0;
      window.friends_page[user_id] = 0;
      this.doFilter(search);
      return this.renderBounce();
    };

    FriendsView.prototype.doFilter = function(search) {
      var filtered, user, user_id;
      user_id = parseInt(this.collection.userId);
      if (search && search.length) {
        filtered = (function() {
          var _i, _len, _ref, _results;
          _ref = this.collection.models;
          _results = [];
          for (_i = 0, _len = _ref.length; _i < _len; _i++) {
            user = _ref[_i];
            if (user.attributes.name.toLowerCase().search(search.toLowerCase()) >= 0) {
              _results.push(user);
            }
          }
          return _results;
        }).call(this);
        this.list = filtered;
      } else {
        search = '';
        this.list = this.collection.models;
      }
      window.friends[user_id] = this.list.concat([]);
      return window.friends_filter[user_id] = search.toLowerCase();
    };

    FriendsView.prototype.afterRender = function() {
      FriendsView.__super__.afterRender.call(this);
      this.list = this.collection.models;
      console.log(this.list);
      return this.renderList();
    };

    FriendsView.prototype.renderList = function(reset) {
      var slice_start, slicedList, user_id;
      if (reset == null) {
        reset = true;
      }
      console.log('rendering');
      if (reset && this.friendlistView) {
        console.log('reset');
        this.friendlistView.remove();
        $('#friendlist-container').html('');
      }
      if (this.list) {
        user_id = parseInt(this.collection.userId);
        if (window.friends_page[user_id] > 0 && reset === true) {
          console.log('resetttted');
          slice_start = 0;
          this.page = window.friends_page[user_id];
        } else {
          console.log('nie reseted');
          slice_start = this.page * this.perPage;
        }
        if (window.friends_filter[user_id] && window.friends_filter[user_id].length > 0) {
          this.showReset();
          this.doFilter(window.friends_filter[user_id]);
          setTimeout(function() {
            return $('.search-query').val(window.friends_filter[user_id]);
          }, 100);
        }
        slicedList = this.list.slice(slice_start, this.page * this.perPage + this.perPage);
        if (slicedList.length < this.perPage) {
          $('.show-more').attr('disabled', 'disabled');
        } else {
          $('.show-more').removeAttr('disabled');
        }
        this.friendlistView = new FriendListView({
          data: {
            users: slicedList
          }
        });
        return this.friendlistView.render();
      }
    };

    return FriendsView;

  })(View);
  
}});

window.require.define({"views/gallery-page-view": function(exports, require, module) {
  var AlbumListView, GalleryPageView, PageView, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  AlbumListView = require('views/albumlist-view');

  mediator = require('mediator');

  module.exports = GalleryPageView = (function(_super) {

    __extends(GalleryPageView, _super);

    function GalleryPageView() {
      this.renderList = __bind(this.renderList, this);

      this.scrollTop = __bind(this.scrollTop, this);
      return GalleryPageView.__super__.constructor.apply(this, arguments);
    }

    GalleryPageView.template('gallery');

    GalleryPageView.prototype.autoRender = false;

    GalleryPageView.prototype.className = 'gallery-page profile-page';

    GalleryPageView.prototype.id = 'profile';

    GalleryPageView.prototype.events = {
      'click .load-more': 'loadMore',
      'click .scroll-top': 'scrollTop'
    };

    GalleryPageView.prototype.page = 0;

    GalleryPageView.prototype.perPage = 10;

    GalleryPageView.prototype.list = [];

    GalleryPageView.prototype.full_list = [];

    GalleryPageView.prototype.scrollTop = function() {
      return window.scrollTo(0, 0);
    };

    GalleryPageView.prototype.loadMore = function() {
      var _this = this;
      return this.collection.fetch({
        update: true,
        success: function(collection) {
          _this.page = _this.page + 1;
          _this.list = collection.models;
          _this.full_list = _this.full_list.concat(collection.models);
          if (_this.full_list.length >= collection.total) {
            $('.load-more').attr('disabled', 'disabled');
          }
          _this.afterRender();
          return window.albumCollection[collection.user_id] = _this.full_list.concat([]);
        },
        data: {
          offset: this.full_list.length,
          limit: this.perPage
        }
      });
    };

    GalleryPageView.prototype.render = function() {
      console.log(this.collection);
      return GalleryPageView.__super__.render.apply(this, arguments);
    };

    GalleryPageView.prototype.afterRender = function() {
      GalleryPageView.__super__.afterRender.call(this);
      if (this.full_list.length === 0) {
        this.list = this.collection.models;
        this.full_list = this.collection.models.concat([]);
      }
      return this.renderList();
    };

    GalleryPageView.prototype.renderList = function() {
      var _this = this;
      this.albumlistView = new AlbumListView({
        data: {
          albums: this.list,
          user_id: this.collection.user_id
        }
      });
      this.albumlistView.render();
      this.scroll();
      setTimeout(function() {
        return $('.action-buttons').removeClass('invisible');
      }, 600);
      if (this.full_list.length >= this.collection.total) {
        $('.load-more').attr('disabled', 'disabled');
      }
      setTimeout(function() {
        if ($('.load-more').position().top < $('.navbar-fixed-bottom').position().top - window.scrollY) {
          console.log('hide');
          return $('.scroll-top').hide();
        } else {
          console.log('show');
          return $('.scroll-top').show();
        }
      }, 10);
      return setTimeout(function() {
        if ($('.load-more').position().top < $('.navbar-fixed-bottom').position().top - window.scrollY) {
          console.log('hide');
          return $('.scroll-top').hide();
        } else {
          console.log('show');
          return $('.scroll-top').show();
        }
      }, 700);
    };

    return GalleryPageView;

  })(PageView);
  
}});

window.require.define({"views/gallery/gallery-album-page-view": function(exports, require, module) {
  var GalleryAlbumPageView, PageView, PhotoMainView, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  mediator = require('mediator');

  PhotoMainView = require('views/photo-main-view');

  module.exports = GalleryAlbumPageView = (function(_super) {

    __extends(GalleryAlbumPageView, _super);

    function GalleryAlbumPageView() {
      this.loadMore = __bind(this.loadMore, this);

      this.scrollTop = __bind(this.scrollTop, this);
      return GalleryAlbumPageView.__super__.constructor.apply(this, arguments);
    }

    GalleryAlbumPageView.template("gallery/album");

    GalleryAlbumPageView.prototype.autoRender = false;

    GalleryAlbumPageView.prototype.className = 'gallery-page';

    GalleryAlbumPageView.prototype.id = 'album';

    GalleryAlbumPageView.prototype.perPage = 10;

    GalleryAlbumPageView.prototype.events = {
      'click .load-more': 'loadMore',
      'click .scroll-top': 'scrollTop',
      'click .main-img img': 'handleImageClick'
    };

    GalleryAlbumPageView.prototype.handleImageClick = function(e) {
      var coll, img, photoView,
        _this = this;
      img = $(e.currentTarget);
      coll = this.subview('photos').collection;
      e.preventDefault();
      photoView = new PhotoMainView();
      photoView.handleFullscreen(coll.userId, coll.albumId, {
        src: img.attr('src')
      }, null, coll);
      return photoView.on('starAdded', function(photoModel) {
        return coll.add(photoModel, {
          merge: true
        });
      });
    };

    GalleryAlbumPageView.prototype.initialize = function(options) {
      return GalleryAlbumPageView.__super__.initialize.apply(this, arguments);
    };

    GalleryAlbumPageView.prototype.scrollTop = function() {
      return window.scrollTo(0, 0);
    };

    GalleryAlbumPageView.prototype.loadMore = function() {
      var collection, photosView,
        _this = this;
      photosView = this.subview('photos');
      collection = photosView.collection;
      return collection.fetch({
        update: true,
        remove: false,
        data: {
          offset: collection.length,
          limit: this.perPage
        },
        success: function(coll) {
          _this.handleTopButton();
          window.photoCollection[coll.userId + '-' + coll.albumId] = coll.models.concat([]);
          if (coll.total <= coll.length) {
            return $('.load-more').attr('disabled', 'disabled');
          }
        }
      });
    };

    GalleryAlbumPageView.prototype.afterRender = function() {
      var _this = this;
      GalleryAlbumPageView.__super__.afterRender.apply(this, arguments);
      this.scroll();
      return setTimeout(function() {
        $('.action-buttons').removeClass('invisible');
        return _this.handleTopButton();
      }, 600);
    };

    GalleryAlbumPageView.prototype.handleTopButton = function() {
      setTimeout(function() {
        if ($('.load-more').position().top < $('.navbar-fixed-bottom').position().top - window.scrollY) {
          console.log('hide');
          return $('.scroll-top').hide();
        } else {
          console.log('show');
          return $('.scroll-top').show();
        }
      }, 10);
      return setTimeout(function() {
        if ($('.load-more').position().top < $('.navbar-fixed-bottom').position().top - window.scrollY) {
          console.log('hide');
          return $('.scroll-top').hide();
        } else {
          console.log('show');
          return $('.scroll-top').show();
        }
      }, 700);
    };

    return GalleryAlbumPageView;

  })(PageView);
  
}});

window.require.define({"views/header-view": function(exports, require, module) {
  var HeaderView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  View = require('views/base/view');

  module.exports = HeaderView = (function(_super) {

    __extends(HeaderView, _super);

    function HeaderView() {
      return HeaderView.__super__.constructor.apply(this, arguments);
    }

    HeaderView.template('header');

    HeaderView.prototype.autoRender = true;

    HeaderView.prototype.container = '#header';

    HeaderView.prototype.className = "navbar-inner";

    return HeaderView;

  })(View);
  
}});

window.require.define({"views/layout": function(exports, require, module) {
  var Chaplin, Layout,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  module.exports = Layout = (function(_super) {

    __extends(Layout, _super);

    function Layout() {
      return Layout.__super__.constructor.apply(this, arguments);
    }

    Layout.prototype.events = {
      'scroll': 'scroll'
    };

    Layout.prototype.scroll = function(e) {
      return this.publishEvent("!scroll", e);
    };

    Layout.prototype.initialize = function() {
      console.log('Initializing FastClick');
      try {
        new FastClick($('.navbar-fixed-bottom')[0]);
      } catch (_error) {}
      return Layout.__super__.initialize.apply(this, arguments);
    };

    return Layout;

  })(Chaplin.Layout);
  
}});

window.require.define({"views/mail-compose-page-view": function(exports, require, module) {
  var MailComposeView, PageView,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  module.exports = MailComposeView = (function(_super) {

    __extends(MailComposeView, _super);

    function MailComposeView() {
      return MailComposeView.__super__.constructor.apply(this, arguments);
    }

    MailComposeView.template('mail-compose');

    MailComposeView.prototype.autoRender = true;

    MailComposeView.prototype.className = 'mail-page';

    MailComposeView.prototype.events = {
      'submit #mail-compose': 'mailCompose'
    };

    MailComposeView.prototype.mailCompose = function(e) {
      var content, contentElement, title,
        _this = this;
      e.preventDefault();
      contentElement = $(e.currentTarget).find('.mail-content');
      title = 'Wiadomość z aplikacji nk.pl';
      content = contentElement.val().trim();
      if (content.length !== 0) {
        return $.ajax('/mailCompose', {
          type: 'post',
          data: JSON.stringify({
            subject: title,
            content: content,
            id: this.model.attributes.id
          }),
          success: function(data, status, jqXHR) {
            return window.alert('Wiadomość wysłana', function() {
              return history.back();
            }, 'Poczta');
          },
          error: function(jqXHR) {
            return window.alert('Nie udało się wysłać wiadomości');
          }
        });
      }
    };

    return MailComposeView;

  })(PageView);
  
}});

window.require.define({"views/mail-page-view": function(exports, require, module) {
  var MailView, View, template,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  template = require('views/templates/mail');

  View = require('views/base/view');

  module.exports = MailView = (function(_super) {

    __extends(MailView, _super);

    function MailView() {
      return MailView.__super__.constructor.apply(this, arguments);
    }

    MailView.prototype.autoRender = false;

    MailView.prototype.className = 'mail-page';

    MailView.prototype.container = '#page-container';

    MailView.prototype.template = template;

    return MailView;

  })(View);
  
}});

window.require.define({"views/mail-view": function(exports, require, module) {
  var MailModel, MailPageView, PageView,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  MailModel = require('models/mail-model');

  module.exports = MailPageView = (function(_super) {

    __extends(MailPageView, _super);

    function MailPageView() {
      return MailPageView.__super__.constructor.apply(this, arguments);
    }

    MailPageView.template('mail');

    MailPageView.prototype.autoRender = false;

    MailPageView.prototype.className = 'mail-page';

    MailPageView.prototype.container = '#page-container';

    MailPageView.prototype.events = {
      'submit #mail-compose': 'mailCompose'
    };

    MailPageView.prototype.initialize = function(params) {
      MailPageView.__super__.initialize.call(this);
      if (!params.model) {
        return this.getMail(params.mailId);
      } else {
        return this.render();
      }
    };

    MailPageView.prototype.getMail = function(id) {
      var _this = this;
      this.model = new MailModel({
        id: id
      });
      return this.model.fetch({
        success: function(data) {
          _this.model = data;
          return _this.render();
        }
      });
    };

    MailPageView.prototype.afterRender = function() {
      var mailModel,
        _this = this;
      MailPageView.__super__.afterRender.call(this);
      if (!this.model.attributes.nav) {
        mailModel = new MailModel({
          id: this.model.attributes.id
        });
        return mailModel.fetch({
          success: function(data, status, jqXHR) {
            var modelInList;
            _this.model = data;
            modelInList = _.find(window.mailModels, function(mail) {
              return mail.id === _this.model.attributes.id;
            });
            modelInList.attributes.is_read = true;
            $('.mail-title').html(data.title);
            console.log(_this.model);
            return console.log('title zmieniony na ' + _this.model.attributes.title);
          }
        });
      }
    };

    MailPageView.prototype.mailCompose = function(e) {
      var content, contentElement,
        _this = this;
      e.preventDefault();
      contentElement = $(e.currentTarget).find('.mail-content');
      content = contentElement.val().trim();
      if (content.length !== 0) {
        return $.ajax('/mailCompose', {
          type: 'post',
          data: JSON.stringify({
            subject: $("<div/>").html(this.model.attributes.title).text(),
            content: content,
            id: this.model.attributes.from_id
          }),
          success: function(data, status, jqXHR) {
            return window.alert('Wiadomość wysłana', function() {
              return contentElement.val('');
            }, 'Poczta');
          },
          error: function(jqXHR) {}
        });
      }
    };

    return MailPageView;

  })(PageView);
  
}});

window.require.define({"views/mailbox-page-view": function(exports, require, module) {
  var MailListView, MailView, MailboxPageView, PageView,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  MailListView = require('views/maillist-view');

  MailView = require('views/mail-view');

  module.exports = MailboxPageView = (function(_super) {

    __extends(MailboxPageView, _super);

    function MailboxPageView() {
      this.renderList = __bind(this.renderList, this);

      this.scrollTop = __bind(this.scrollTop, this);
      return MailboxPageView.__super__.constructor.apply(this, arguments);
    }

    MailboxPageView.template("mailbox");

    MailboxPageView.prototype.autoRender = false;

    MailboxPageView.prototype.className = 'mail-page';

    MailboxPageView.prototype.container = '#page-container';

    MailboxPageView.prototype.autoRender = false;

    MailboxPageView.prototype.events = {
      'click .load-more': 'loadMore',
      'click .scroll-top': 'scrollTop'
    };

    MailboxPageView.prototype.page = 0;

    MailboxPageView.prototype.perPage = 10;

    MailboxPageView.prototype.list = [];

    MailboxPageView.prototype.scrollTop = function() {
      return window.scrollTo(0, 0);
    };

    MailboxPageView.prototype.loadMore = function() {
      var _this = this;
      return this.collection.fetch({
        update: true,
        success: function(collection) {
          _this.page = _this.page + 1;
          window.mailModels = window.mailModels.concat(collection.models);
          if (window.mailModels.length >= collection.total) {
            $('.load-more').attr('disabled', 'disabled');
          }
          return _this.afterRender();
        },
        data: {
          offset: window.mailModels.length,
          limit: this.perPage
        }
      });
    };

    MailboxPageView.prototype.afterRender = function() {
      MailboxPageView.__super__.afterRender.call(this);
      this.list = this.collection.models;
      return this.renderList();
    };

    MailboxPageView.prototype.renderList = function() {
      var _this = this;
      this.maillistView = new MailListView({
        data: {
          mails: this.list
        }
      });
      this.maillistView.render();
      this.scroll();
      setTimeout(function() {
        return $('.action-buttons').removeClass('invisible');
      }, 600);
      if (window.mailModels.length >= this.collection.total) {
        return $('.load-more').attr('disabled', 'disabled');
      }
    };

    return MailboxPageView;

  })(PageView);
  
}});

window.require.define({"views/maillist-view": function(exports, require, module) {
  var MaillistView, PageView, template,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  template = require('views/templates/maillist');

  module.exports = MaillistView = (function(_super) {

    __extends(MaillistView, _super);

    function MaillistView() {
      return MaillistView.__super__.constructor.apply(this, arguments);
    }

    MaillistView.template('maillist');

    MaillistView.prototype.container = '#maillist-container';

    MaillistView.prototype.autoRender = false;

    MaillistView.prototype.initialize = function(options) {
      this.data = options.data;
      console.log(this.data);
      return MaillistView.__super__.initialize.call(this);
    };

    MaillistView.prototype.getTemplateData = function() {
      return this.data;
    };

    return MaillistView;

  })(PageView);
  
}});

window.require.define({"views/menu-view": function(exports, require, module) {
  var MenuView, View, mediator, nextTick,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  mediator = require('chaplin').mediator;

  View = require('views/base/view');

  nextTick = require('lib/next-tick');

  module.exports = MenuView = (function(_super) {
    var photoMenu;

    __extends(MenuView, _super);

    function MenuView() {
      this.hidePhotoMenu = __bind(this.hidePhotoMenu, this);

      this.photoButtonClicked = __bind(this.photoButtonClicked, this);
      return MenuView.__super__.constructor.apply(this, arguments);
    }

    MenuView.template('menu');

    MenuView.prototype.autoRender = true;

    MenuView.prototype.container = '#menu';

    photoMenu = false;

    MenuView.prototype.events = {
      'click   .nav li > a': 'menuButtonClicked',
      'click  .nav li.photo > a': 'photoButtonClicked'
    };

    MenuView.prototype.menuButtonClicked = function(e) {
      if ($(e.currentTarget).parent().hasClass('selected')) {
        window.scrollTo(0, 0);
        return this.publishEvent("!refresh");
      } else {
        return e.stopPropagation();
      }
    };

    MenuView.prototype.photoButtonClicked = function(e) {
      var _this = this;
      e.preventDefault();
      e.stopPropagation();
      if (this.photoMenu) {
        this.hidePhotoMenu(e);
        return;
      }
      this.photoMenu = true;
      this.$popover[0].style.display = 'inline-block';
      setTimeout((function() {
        return _this.$popover[0].style.display = 'block';
      }), 30);
      return nextTick(function() {
        $(document.body).on('click tap', _this.hidePhotoMenu);
        return $(window).on('scroll', _this.hidePhotoMenu);
      });
    };

    MenuView.prototype.hidePhotoMenu = function(e) {
      var _this = this;
      if (!this.photoMenu) {
        return;
      }
      if ($(e.target).is('.btn-camera, .btn-album')) {
        return;
      }
      this.photoMenu = false;
      setTimeout((function() {
        return _this.$popover[0].style.display = 'none';
      }), 30);
      $(document.body).off('click tap', this.hidePhotoMenu);
      return $(window).off('scroll', this.hidePhotoMenu);
    };

    MenuView.prototype.afterRender = function() {
      var _this = this;
      MenuView.__super__.afterRender.apply(this, arguments);
      this.$photoButton = this.$('.nav li.photo a');
      this.$popover = this.$('.popover');
      return this.$popover.find('a').bind('click', function(e) {
        _this.publishEvent("refreshView");
        _this.photoMenu = false;
        return _this.$popover.hide();
      });
    };

    return MenuView;

  })(View);
  
}});

window.require.define({"views/modals/auth-modal-view": function(exports, require, module) {
  var AuthModalView, ModalView, template,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  ModalView = require('views/base/modal-view');

  template = require('views/templates/login');

  module.exports = AuthModalView = (function(_super) {

    __extends(AuthModalView, _super);

    function AuthModalView() {
      this.loginUser = __bind(this.loginUser, this);

      this.focus = __bind(this.focus, this);
      return AuthModalView.__super__.constructor.apply(this, arguments);
    }

    AuthModalView.prototype.template = template;

    AuthModalView.prototype.events = {
      'submit .form-signin': 'loginUser',
      'click .form-signin input': 'focus'
    };

    AuthModalView.prototype.initialize = function() {
      $('html').addClass('login');
      return AuthModalView.__super__.initialize.apply(this, arguments);
    };

    AuthModalView.prototype.focus = function(e) {
      var _this = this;
      return setTimeout(function() {
        console.log('focus login element');
        return e.currentTarget.focus();
      }, 50);
    };

    AuthModalView.prototype.loginUser = function(e) {
      var login, password;
      e.preventDefault();
      if (!e.target) {
        return;
      }
      login = $('.login-input').val();
      password = $('.password-input').val();
      if (!(login.length === 0 || password.length === 0)) {
        return this.model.login(login, password);
      }
    };

    AuthModalView.prototype.dispose = function() {
      $('html').removeClass('login');
      return AuthModalView.__super__.dispose.apply(this, arguments);
    };

    return AuthModalView;

  })(ModalView);
  
}});

window.require.define({"views/modals/loading-modal-view": function(exports, require, module) {
  var LoadingModalView, ModalView, template,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  ModalView = require('views/base/modal-view');

  template = require('views/templates/modals/loading');

  module.exports = LoadingModalView = (function(_super) {

    __extends(LoadingModalView, _super);

    function LoadingModalView() {
      return LoadingModalView.__super__.constructor.apply(this, arguments);
    }

    LoadingModalView.prototype.template = template;

    return LoadingModalView;

  })(ModalView);
  
}});

window.require.define({"views/optional_layout": function(exports, require, module) {
  var Chaplin, Layout,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  Chaplin = require('chaplin');

  module.exports = Layout = (function(_super) {

    __extends(Layout, _super);

    function Layout() {
      this.untoggleMove = __bind(this.untoggleMove, this);

      this.toggleMove = __bind(this.toggleMove, this);

      this.cssMove = __bind(this.cssMove, this);
      return Layout.__super__.constructor.apply(this, arguments);
    }

    Layout.prototype.events = {
      'touchstart .container': 'toggleMove',
      'touchend   .container': 'untoggleMove',
      'touchmove  .container': 'move',
      'mousedown .container': 'toggleMove',
      'mouseup   .container': 'untoggleMove',
      'mousemove .container': 'move',
      'touchmove body': 'scroll',
      'click .nav a': 'showPanel'
    };

    Layout.prototype.initialize = function() {
      new FastClick(document.body);
      return Layout.__super__.initialize.apply(this, arguments);
    };

    Layout.prototype.showPanel = function() {
      return this.cssMove($('.container')[0], 0);
    };

    Layout.prototype.start = 0;

    Layout.prototype.end = 0;

    Layout.prototype.speed = 0;

    Layout.prototype.getX = function(e) {
      var _ref;
      return ((_ref = e.originalEvent.touches) != null ? _ref[0].clientX : void 0) || e.clientX;
    };

    Layout.prototype.cssMove = function(elem, x) {
      $(elem).css({
        '-webkit-transform': "translate3d('+x+'px, 0px, 0px)\nscaleX(1) scaleY(1) scaleZ(1)\nrotateX(0deg) rotateY(0deg) rotateZ(0deg)\nskewX(0deg) skewY(0deg)"
      });
      this.speed = x - this.end;
      return this.end = x;
    };

    Layout.prototype.toggleMove = function(e) {
      console.log('popins');
      this.moving = true;
      $(e.currentTarget).removeClass('moving');
      return this.start = this.getX(e) - this.end;
    };

    Layout.prototype.untoggleMove = function(e) {
      var width;
      width = $(window.document.body).width();
      $(e.currentTarget).addClass('moving');
      if (this.end < width / 2) {
        this.cssMove(e.currentTarget, 0);
      } else {
        this.cssMove(e.currentTarget, width - 30);
      }
      return this.moving = false;
    };

    Layout.prototype.move = function(e) {
      if (!this.moving) {
        return;
      }
      if (this.getX(e) - this.start <= 0) {
        return this.cssMove(e.currentTarget, 0);
      } else {
        return this.cssMove(e.currentTarget, this.getX(e) - this.start);
      }
    };

    Layout.prototype.scroll = function(e) {
      return e.preventDefault();
    };

    return Layout;

  })(Chaplin.Layout);
  
}});

window.require.define({"views/photo-main-view": function(exports, require, module) {
  var FeedCollection, PageView, PhotoCollection, PhotoCommentModel, PhotoMainView, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  mediator = require('mediator');

  PhotoCommentModel = require('models/photo/comment-model');

  PhotoCollection = require('models/photo-collection');

  FeedCollection = require('models/feed-collection');

  module.exports = PhotoMainView = (function(_super) {

    __extends(PhotoMainView, _super);

    function PhotoMainView() {
      this.handleZoom = __bind(this.handleZoom, this);

      this.handleFullscreenClick = __bind(this.handleFullscreenClick, this);

      this.handleFullscreen = __bind(this.handleFullscreen, this);

      this.handleFullscreenChange = __bind(this.handleFullscreenChange, this);

      this.handleFullscreenFadeOut = __bind(this.handleFullscreenFadeOut, this);

      this.getIndexBySrc = __bind(this.getIndexBySrc, this);

      this.appendPhotos = __bind(this.appendPhotos, this);

      this.loadMore = __bind(this.loadMore, this);

      this.handleHammer = __bind(this.handleHammer, this);

      this.showPane = __bind(this.showPane, this);

      this.prev = __bind(this.prev, this);

      this.next = __bind(this.next, this);

      this.setPaneDimensions = __bind(this.setPaneDimensions, this);

      this.carousel = __bind(this.carousel, this);

      this.stopWatchRotation = __bind(this.stopWatchRotation, this);

      this.startWatchRotation = __bind(this.startWatchRotation, this);
      return PhotoMainView.__super__.constructor.apply(this, arguments);
    }

    PhotoMainView.template("photo/single");

    PhotoMainView.prototype.clicked = false;

    PhotoMainView.prototype.imageScale = 1;

    PhotoMainView.prototype.imageScale2 = 1;

    PhotoMainView.prototype.zooming = false;

    PhotoMainView.prototype.singlePhoto = false;

    PhotoMainView.prototype.loadingMore = false;

    PhotoMainView.prototype.changeTime = 0;

    PhotoMainView.prototype.panes = [];

    PhotoMainView.prototype.events = {
      'click .btn-older-comments': 'getOlderComments',
      'submit .comment-add form': 'addComment',
      'click .main-img a': 'handleFullscreenPhoto',
      'click .photo-comment-add': 'focusCommentAdd'
    };

    PhotoMainView.prototype.handleFullscreenPhoto = function(e) {
      var albumId, img, photoModel, userId,
        _this = this;
      e.preventDefault();
      img = $(e.currentTarget).find('img');
      photoModel = this.subview('photo').model;
      userId = photoModel.attributes.author.raw_user.uid;
      albumId = photoModel.attributes.album_id;
      setTimeout(function() {
        return _this.handleFullscreen(userId, albumId, {
          src: img.attr('src')
        }, photoModel);
      }, 150);
      return this.on('starAdded', function(photoModel) {
        return _this.subview('photo').updateStar(photoModel);
      });
    };

    PhotoMainView.prototype.focusCommentAdd = function(e) {
      var _this = this;
      console.log('focus comment add');
      e.preventDefault();
      return setTimeout(function() {
        window.scrollTo(0, Math.ceil($('.comments-list').height()) + Math.ceil($('.single-comment-add').height()) + Math.ceil($('.btn-older-comments').parent().height()));
        return setTimeout(function() {
          var n;
          n = document.createTextNode(' ');
          $('.page-container').append(n);
          return setTimeout(function() {
            return n.parentNode.removeChild(n);
          }, 0);
        }, 50);
      }, 50);
    };

    PhotoMainView.prototype.focusCommentList = function(e) {
      var _this = this;
      console.log('focus comment list');
      e.preventDefault();
      return setTimeout(function() {
        return window.scrollTo(0, Math.ceil($('.comment-list').position().top) - 110);
      }, 50);
    };

    PhotoMainView.prototype.getOlderComments = function() {
      return this.subview('comments').collection.getOlderComments();
    };

    PhotoMainView.prototype.addComment = function(e) {
      var album_id, comment, input, model, photo, photoModel, photo_id, profile_id,
        _this = this;
      e.preventDefault();
      input = this.$('input');
      comment = input.val().trim();
      if (input.hasClass('disabled')) {
        return;
      }
      input.addClass('disabled');
      setTimeout(function() {
        return input.removeClass('disabled');
      }, 2000);
      if (comment.length !== 0) {
        input.attr('disabled', 'disabled');
        photo = this.subview('photo').model.attributes;
        photoModel = this.subview('photo').model;
        profile_id = photo.author.raw_user.uid;
        album_id = photo.album_id;
        photo_id = photo.photo_id;
        model = new PhotoCommentModel({
          profile_id: profile_id,
          album_id: album_id,
          photo_id: photo_id,
          comment: comment
        });
        return model.save(null, {
          complete: function() {
            return input.removeAttr('disabled');
          },
          success: function() {
            input.val('');
            $('.comment-list').removeClass('hidden');
            return _this.subview('comments').collection.fetch({
              update: true,
              remove: false,
              success: function(data) {
                var countComments, textComments;
                _this.feed = new FeedCollection;
                _this.feed.fetch({
                  success: function() {
                    var comments, feedModel;
                    feedModel = _this.feed.findWhere({
                      photo_id: parseInt(photo_id),
                      album_id: parseInt(album_id),
                      user_id: parseInt(profile_id)
                    });
                    comments = photoModel.get('comments');
                    comments.comment_count = data.total;
                    return feedModel.set('comments', comments);
                  }
                });
                countComments = $('.media .actions .count-comments');
                countComments.removeClass('hide');
                textComments = $('.media .actions .comment_count');
                textComments.html(data.total);
                return photo.comments.comment_count = data.total;
              }
            });
          }
        });
      }
    };

    PhotoMainView.prototype.startWatchRotation = function() {
      var options;
      options = {
        frequency: 300
      };
      return this.watchID = navigator.accelerometer.watchAcceleration((function(e) {
        var rotate;
        if (e.x > 4.5) {
          rotate = 90;
          window.rotated = true;
          window.topdown = false;
        } else if (e.x < -4.5) {
          rotate = -90;
          window.rotated = true;
          window.topdown = false;
        } else if (e.y > -0.5) {
          rotate = 0;
          window.rotated = false;
          window.topdown = false;
        } else {
          rotate = 180;
          window.rotated = false;
          window.topdown = true;
        }
        if (rotate !== window.last_rotate) {
          window.last_rotate = rotate;
          window.transform_rotate = 'rotate(' + rotate + 'deg) ';
          $('.fullscreen_info_layer').css('display', 'none');
          return $('.fullsceen-photo').css('-webkit-transform', window.transform_rotate + window.transform_iscroll);
        }
      }), (function() {}), options);
    };

    PhotoMainView.prototype.stopWatchRotation = function() {
      navigator.accelerometer.clearWatch(this.watchID);
      return this.watchID = null;
    };

    PhotoMainView.prototype.carousel = function(element) {
      var self;
      self = this;
      this.carouselElement = $(element);
      this.carouselContainer = $(">ul", this.carouselElement);
      this.carouselPanes = $(">ul>li", this.carouselElement);
      this.pane_width = 0;
      this.pane_count = this.carouselPanes.length;
      this.current_pane = 0;
      return this.setPaneDimensions();
    };

    PhotoMainView.prototype.setPaneDimensions = function() {
      var _this = this;
      this.carouselContainer = $(">ul", this.carouselElement);
      this.carouselPanes = $(">ul>li", this.carouselElement);
      this.pane_width = $(window).width();
      this.pane_height = $(window).height();
      this.carouselContainer.width(this.pane_width * this.pane_count);
      return this.carouselPanes.each(function(key, el) {
        $(el).width(_this.pane_width);
        return $(el).height(_this.pane_height);
      });
    };

    PhotoMainView.prototype.setImageMargin = function(img) {
      var $img, $win;
      img.width = $(window).width();
      img.height = '';
      $win = $(window);
      $img = $(img);
      $img.css('margin-top', (parseInt($win.height() / 2) - parseInt($img.height() / 2)) + 'px');
      return $img.css('margin-left', (parseInt($win.width() / 2) - parseInt($img.width() / 2)) + 'px');
    };

    PhotoMainView.prototype.next = function() {
      return this.showPane(this.current_pane + 1, true);
    };

    PhotoMainView.prototype.prev = function() {
      return this.showPane(this.current_pane - 1, true);
    };

    PhotoMainView.prototype.showPane = function(index, animate, fade) {
      var $current, container, current, current_element, infoLayer, nextImg, offset, photos, prevImg,
        _this = this;
      if (index >= this.pane_count - 1) {
        this.loadMore(index);
      }
      index = Math.max(0, Math.min(index, this.pane_count - 1));
      this.current_pane = index;
      offset = -((100 / this.pane_count) * this.current_pane);
      photos = $(this.photoContainer).find('li');
      current_element = $(photos[index]);
      current = current_element.find('img')[0];
      $current = $(current);
      this.current = $current;
      current.src = $current.attr('data-src');
      current.width = $(window).width();
      current.height = $(window).height();
      if (!animate && !fade) {
        container = $current.parent().parent().parent();
        infoLayer = container.find('.fullscreen_info_layer');
        setTimeout(function() {
          return infoLayer.fadeIn({
            duration: 0
          });
        }, 10);
        setTimeout(function() {
          return infoLayer.fadeOut({
            duration: 500
          });
        }, 5000);
      }
      try {
        nextImg = $(current_element).next().find('img')[0];
        nextImg.src = $(nextImg).attr('data-src');
      } catch (_error) {}
      try {
        prevImg = $(current_element).prev().find('img')[0];
        prevImg.src = $(prevImg).attr('data-src');
      } catch (_error) {}
      current.onload = function(e) {
        return _this.setImageMargin(e.target);
      };
      if (!this.panes[index]) {
        this.handleZoom($current.parent(), $current);
      }
      this.panes[index] = true;
      return this.setContainerOffset(offset, animate);
    };

    PhotoMainView.prototype.setContainerOffset = function(percent, animate) {
      var px;
      this.carouselContainer.removeClass("animate");
      if (animate) {
        this.carouselContainer.addClass("animate");
      }
      if (Modernizr.csstransforms3d) {
        return this.carouselContainer.css("transform", "translate3d(" + percent + "%,0,0) scale3d(1,1,1)");
      } else if (Modernizr.csstransforms) {
        return this.carouselContainer.css("transform", "translate(" + percent + "%,0)");
      } else {
        px = ((this.pane_width * this.pane_count) / 100) * percent;
        return this.carouselContainer.css("left", px + "px");
      }
    };

    PhotoMainView.prototype.handleHammer = function(ev) {
      var tag;
      if (this.zooming || this.imageScale > 1 || this.imageScale2 > 1 || ev.gesture.scale > 1 || this.loadingMore) {
        return;
      }
      ev.gesture.preventDefault();
      switch (ev.type) {
        case "dragright":
        case "dragleft":
          tag = ev.srcElement.tagName.toLowerCase();
          if (['i', 'span', 'a'].indexOf(tag) > -1) {
            return true;
          }
          return this.handleFullscreenFadeOut(0);
        case "swipeleft":
          this.handleFullscreenFadeOut(0);
          this.next();
          return ev.gesture.stopDetect();
        case "swiperight":
          this.handleFullscreenFadeOut(0);
          this.prev();
          return ev.gesture.stopDetect();
        case "release":
          if (Math.abs(ev.gesture.deltaX) > this.pane_width / 2.5) {
            if (ev.gesture.direction === "right") {
              return this.prev();
            } else {
              return this.next();
            }
          } else {
            return this.showPane(this.current_pane, true);
          }
      }
    };

    PhotoMainView.prototype.canLoadMore = true;

    PhotoMainView.prototype.loadMore = function(index) {
      var album_id, loadingMessage, photo, photo_id, profile_id,
        _this = this;
      if (this.singlePhoto) {
        return;
      }
      if (!this.canLoadMore) {
        return;
      }
      try {
        photo = this.subview('photo').model.attributes;
        profile_id = photo.author.raw_user.uid;
        album_id = photo.album_id;
        photo_id = photo.photo_id;
      } catch (e) {
        profile_id = this.profile_id;
        album_id = this.album_id;
      }
      this.photos = this.photoAlbumCollection;
      console.log('liczba fot w kolekcji - ' + this.photos.length);
      loadingMessage = $('<div class="loading-more-msg" style="z-index: 2147482666; position: absolute; top:5px; color: white; width:100%; height:16px;"><center>wczytuję kolejne zdjęcia...</center></div>');
      this.loadingMore = true;
      $(document.body).append(loadingMessage);
      return this.photos.fetch({
        update: true,
        remove: false,
        timeout: 15000,
        data: {
          offset: this.photos.length,
          limit: this.perPage
        },
        complete: function() {
          return setTimeout(function() {
            _this.loadingMore = false;
            return loadingMessage.remove();
          }, 3000);
        },
        error: function() {
          loadingMessage.html('<div style="z-index: 2147482666; position: absolute; top:5px; color: white; width:100%; height:16px;"><center>wystąpił błąd podczas wczytywania</center></div>');
          return setTimeout(function() {
            _this.loadingMore = false;
            return loadingMessage.remove();
          }, 3000);
        },
        success: function(coll) {
          var photoList;
          _this.loadingMore = false;
          loadingMessage.remove();
          window.photoCollection[coll.userId + '-' + coll.albumId] = coll.models.concat([]);
          photoList = coll.models.concat([]);
          _this.appendPhotos(photoList, index);
          if (coll.total <= coll.length) {
            return _this.canLoadMore = false;
          }
        }
      });
    };

    PhotoMainView.prototype.appendPhotos = function(elems, index) {
      var elems_html, win_height, win_width,
        _this = this;
      elems_html = '';
      _.each(elems, function(el) {
        if (_this.getIndexBySrc(el.attributes.photo.uri) === -1) {
          return elems_html += _this.createImageListElement(el);
        }
      });
      $(this.photoContainer).find('ul').append($(elems_html));
      $('.fullscreen_info_layer').fadeOut(0);
      setTimeout(function() {
        var infoLayerElement, infoTransform;
        $('.fullscreen_close_button').unbind('click').click(function() {
          return _this.handleFullscreenClick();
        });
        infoTransform = " translate3d(0,0,0) scale3d(1,1,0) ";
        infoLayerElement = $(_this.photoContainer).find('.fullscreen_info_layer');
        infoLayerElement.find('span,i,strong,a').css('webkitTransform', infoTransform);
        return $(_this.photoContainer).find('.fullscreen_comment_count_button').find('span').css('webkitTransform', infoTransform);
      }, 300);
      this.pane_count = $(this.photoContainer).find('ul li').length;
      this.setPaneDimensions();
      win_height = $(window).height();
      win_width = $(window).width();
      $(this.photoContainer).find('li div').css('width', win_width + 'px');
      $(this.photoContainer).find('li div').css('height', win_height + 'px');
      $(this.photoContainer).css('height', win_height + 'px');
      this.showPane(this.current_pane, false, true);
      return this.photoCollection = elems;
    };

    PhotoMainView.prototype.getIndexBySrc = function(src) {
      var i;
      console.log(src);
      if (!this.photoCollection) {
        console.log('brak photoCollection');
        return -1;
      }
      i = 0;
      while (i < this.photoCollection.length) {
        if (this.photoCollection[i].attributes.photo.uri === src) {
          return i;
        }
        i++;
      }
      return -1;
    };

    PhotoMainView.prototype.handleFullscreenFadeOut = function(duration) {
      var container, infoLayerElement, loadingMessage;
      this.infoLayerVisible = false;
      container = this.current.parent().parent().parent();
      if (container.find('.fullscreen_info_layer')[0].style.display === 'none') {
        this.dontChange = false;
        return;
      } else {
        this.dontChange = true;
      }
      infoLayerElement = container.find('.fullscreen_info_layer');
      infoLayerElement.css('display', 'none');
      this.loadingMore = false;
      loadingMessage = $('.loading-more-msg');
      return loadingMessage.remove();
    };

    PhotoMainView.prototype.handleFullscreenChange = function(ev) {
      var tag,
        _this = this;
      if (ev.srcElement) {
        this.target = ev.srcElement;
        tag = ev.srcElement.tagName.toLowerCase();
        if (['i', 'span', 'a'].indexOf(tag) > -1) {
          return true;
        }
        if ($(ev.srcElement).hasClass('fullscreen_info_layer')) {
          return true;
        }
        return setTimeout(function() {
          var infoLayerElement;
          if (_this.dontChange) {
            return;
          }
          if (_this.target.tagName.toLowerCase() === 'img') {
            infoLayerElement = $(_this.target).parent().parent().parent().find('.fullscreen_info_layer');
          } else {
            infoLayerElement = $(_this.target).parent().parent().find('.fullscreen_info_layer');
          }
          return infoLayerElement.fadeToggle(500);
        }, 10);
      }
    };

    PhotoMainView.prototype.createImageListElement = function(el) {
      var albumId, comment_count, galleryId, infoLayer, photoId, starElement, userId;
      userId = el.attributes.author.raw_user.uid;
      albumId = el.attributes.album_id;
      photoId = el.attributes.photo_id;
      galleryId = el.attributes.gallery_id;
      if (el.attributes.cannot_rate) {
        starElement = '<i style="color:#aaa !important">Fajne</i>';
      } else {
        starElement = '<a href="#photo/' + userId + '/' + albumId + '/' + photoId + '/addStar">Fajne</a>';
      }
      infoLayer = '\
              <span style="display: none;" class="fullscreen_info_layer fullscreen_close_button button"><span>zamknij</span></span>\
              <span style="display: none" class="fullscreen_info_layer fullscreen_star_button" data-src="' + el.attributes.photo.uri + '"><span>' + starElement + '</span></span>\
              <span style="display: none" class="fullscreen_info_layer fullscreen_comment_button"><a href="#galleryphoto/' + galleryId + '/' + photoId + '/addComment">Skomentuj</a></span>';
      if (el.attributes.ratings) {
        infoLayer += '\
              <strong style="display: none; position: absolute; bottom:15px; right: 15px; " class="fullscreen_info_layer right rating-count"><img src=\"images/i_star.png\" width=\"19\" alt=\"Fajne\"><span> ' + el.attributes.ratings.rating_count + '</span></strong>';
      } else {
        infoLayer += '\
              <strong style="display: none; position: absolute; bottom:15px; right: 15px; " class="fullscreen_info_layer right rating-count"><img src=\"images/i_star.png\" width=\"19\" alt=\"Fajne\"><span> -</span></strong>';
      }
      comment_count = el.attributes.comment_count === void 0 ? el.attributes.comments.comment_count : el.attributes.comment_count;
      if (comment_count === void 0) {
        comment_count = 0;
      }
      infoLayer += '<strong style="display: none; position: absolute; bottom:14px; right: 60px; z-index:99999999" class="fullscreen_info_layer right fullscreen_comment_count_button"><span href="#galleryphoto/' + galleryId + '/' + photoId + '/comments"><img src=\"images/i_comment.png\" width=\"24\" alt=\"Komentarze\"> ' + comment_count + '</span></strong>';
      return '<li style="display:block;margin:0;padding:0; width:100%; height: 100%" data-id="' + el.id + '"><div style="margin:0;padding:0;width: 100%; height: 100%;  ">\
          <div style="position: absolute; top:0;left:0;"><img data-src="' + el.attributes.photo.uri + '" class="fullsceen-photo" style="max-width:100%; background: #000; max-height:100%; position: absolute" /></div>\
          </div>' + infoLayer + '</li>';
    };

    PhotoMainView.prototype.handleFullscreen = function(profile_id, album_id, image, photoModel, photoAlbumCollection) {
      var carouselHammer, container, elems, elems_html, transform, win_height, win_width,
        _this = this;
      this.photoAlbumCollection = photoAlbumCollection;
      this.scrollFull = window.scrollY;
      setTimeout(function() {
        return window.scrollTo(0, 0);
      }, 100);
      this.panes = [];
      window.loadMore = this.loadMore;
      window.tapButton = this.handleFullscreenClick;
      this.profile_id = profile_id;
      this.album_id = album_id;
      elems = window.photoCollection[profile_id + '-' + album_id];
      this.photoCollection = elems;
      if (this.getIndexBySrc(image.src) === -1) {
        console.log(image.src);
        console.log('singe photo');
        this.singlePhoto = true;
        elems = [photoModel];
        this.photoCollection = elems;
      }
      if (this.clicked) {
        return;
      }
      this.clicked = true;
      transform = " translate3d(0,0,0) scale3d(1,1,0) ";
      window.transform_iscroll = transform;
      transform += window.transform_rotate;
      container = $('<div class="click-on-backbutton" style="position: fixed; top:0; left:0" id="carousel"><ul></ul></div>');
      this.fullscreenContainer = container;
      this.photoContainer = container;
      elems_html = '';
      _.each(elems, function(el) {
        return elems_html += _this.createImageListElement(el);
      });
      $(container).find('ul').append($(elems_html));
      setTimeout(function() {
        var infoLayerElement, infoTransform;
        $('.fullscreen_close_button').click(function() {
          return _this.handleFullscreenClick();
        });
        $('.fullscreen_comment_button').click(function(e) {
          console.log('fullscreen click comment button');
          _this.handleFullscreenClick();
          e.stopPropagation();
          if (location.href.indexOf('#photo\/') === -1) {
            location.href = e.currentTarget.childNodes[0].href;
          }
          return _this.focusCommentAdd(e);
        });
        $('.fullscreen_comment_count_button').click(function(e) {
          console.log('fullscreen click comment button');
          _this.handleFullscreenClick();
          e.preventDefault();
          e.stopPropagation();
          if (location.href.indexOf('#photo\/') === -1) {
            location.href = $(e.currentTarget.childNodes[0]).attr('href');
          }
          return _this.focusCommentList(e);
        });
        $('.fullscreen_star_button').click(function(e) {
          var dataSrc;
          if ($(e.currentTarget).find('a').length) {
            console.log('mozna ocenic');
          } else {
            console.log('nie mozna');
            return;
          }
          e.stopPropagation();
          e.stopImmediatePropagation();
          dataSrc = $(e.currentTarget).attr('data-src');
          photoModel = _this.photoCollection[_this.getIndexBySrc(dataSrc)];
          return photoModel.addStar(function() {
            var starCounter, starCounterValue;
            console.log('star added!');
            _this.feed = new FeedCollection;
            _this.feed.fetch({
              success: function() {
                var feedModel;
                console.log(photoModel.attributes.id);
                feedModel = _this.feed.findWhere({
                  photo_id: photoModel.get('id'),
                  album_id: photoModel.get('album_id'),
                  user_id: parseInt(photoModel.get('user_id'))
                });
                return feedModel.set('ratings', photoModel.get('ratings'));
              }
            });
            $(e.currentTarget).html('<i><img src="images/ok.png" width="18" alt="Fajne">Fajne</i>');
            starCounter = $(e.currentTarget).parent().find('.rating-count span');
            starCounterValue = parseInt(starCounter.text().trim());
            starCounter.text(starCounterValue + 1);
            return _this.trigger('starAdded', photoModel);
          });
        });
        infoTransform = " translate3d(0,0,0) scale3d(1,1,0) ";
        infoLayerElement = $(container).find('.fullscreen_info_layer');
        infoLayerElement.find('span,a,i,strong').css('webkitTransform', infoTransform);
        return $(container).find('.fullscreen_comment_count_button').find('span').css('webkitTransform', infoTransform);
      }, 400);
      win_height = $(window).height();
      win_width = $(window).width();
      $(container).find('li div').css('width', win_width + 'px');
      $(container).find('li div').css('height', win_height + 'px');
      $(container).css('height', win_height + 'px');
      $(document.body).append(container);
      this.carousel(container);
      carouselHammer = Hammer(container[0], {
        drag_lock_to_axis: true
      });
      carouselHammer.on("release dragleft dragright swipeleft swiperight", this.handleHammer);
      carouselHammer.on('tap click', this.handleFullscreenChange);
      return setTimeout(function() {
        return _this.showPane(_this.getIndexBySrc(image.src), false);
      }, 1);
    };

    PhotoMainView.prototype.handleFullscreenClick = function() {
      var loadingMessage;
      window.scrollTo(0, this.scrollFull);
      try {

      } catch (_error) {}
      this.clicked = false;
      try {
        $(this.fullscreenContainer).remove();
      } catch (_error) {}
      try {
        $(this.fullscreenImageContainer).remove();
      } catch (_error) {}
      try {
        this.loadingMore = false;
        loadingMessage = $('.loading-more-msg');
        return loadingMessage.remove();
      } catch (_error) {}
    };

    PhotoMainView.prototype.afterRender = function() {
      var _this = this;
      $('.page-container').addClass('photo-container');
      if (this.subview('comments')) {
        this.$('.single-comment-add').show();
        this.subview('comments').collection.on("reset add", function(model) {
          if (model.collection.total > model.collection.models.length) {
            return _this.$('.btn-older-comments').show();
          } else {
            return _this.$('.btn-older-comments').hide();
          }
        });
      }
      PhotoMainView.__super__.afterRender.apply(this, arguments);
      $('.events-box').remove();
      return $('.merged_events').remove();
    };

    PhotoMainView.prototype.handleZoom = function(container, image) {
      var endX, endY, fullscreenImage, hammertime, lastX, lastY, last_rotation, last_scale, posX, posY, rect, rotation, scale, win_height, win_width,
        _this = this;
      fullscreenImage = image;
      fullscreenImage.css('margin-top', (parseInt($(container).height() / 2) - parseInt($(fullscreenImage).height() / 2)) + 'px');
      fullscreenImage.css('margin-left', (parseInt($(container).width() / 2) - parseInt($(fullscreenImage).width() / 2)) + 'px');
      this.fullscreenImageContainer = container;
      hammertime = Hammer(container[0], {
        transform_always_block: true,
        transform_min_scale: 0,
        drag_block_horizontal: true,
        drag_block_vertical: true,
        drag_min_distance: 10,
        drag_max_touches: 1,
        prevent_default: true,
        prevent_mouseevents: false,
        tap: true
      });
      rect = fullscreenImage[0];
      posX = 0;
      posY = 0;
      lastX = 0;
      lastY = 0;
      endX = 0;
      endY = 0;
      scale = 1;
      last_scale = 1;
      rotation = 1;
      last_rotation = 1;
      win_height = $(window).height();
      win_width = $(window).width();
      hammertime.on("dragend transformend", function(ev) {
        var boundRect, shouldScroll, transform;
        shouldScroll = false;
        switch (ev.type) {
          case "dragend":
            boundRect = rect.getBoundingClientRect();
            lastX = posX;
            lastY = posY;
        }
        _this.imageScale = scale;
        if (scale < 1.02) {
          scale = 1;
          posX = 0;
          posY = 0;
          lastX = 0;
          lastY = 0;
          transform = " translate3d(" + posX + "px," + posY + "px, 0) " + "scale3d(" + scale + "," + scale + ", 0) ";
          window.transform_iscroll = transform;
          transform += window.transform_rotate;
          rect.style.transform = transform;
          return rect.style.webkitTransform = transform;
        }
      });
      return hammertime.on("touch drag transform", function(ev) {
        var boundRect, offsetX, offsetY, old_scale, transform;
        _this.imageScale2 = ev.gesture.scale;
        old_scale = last_scale;
        switch (ev.type) {
          case "touch":
            last_scale = scale;
            last_rotation = rotation;
            break;
          case "drag":
            posX = ev.gesture.deltaX + lastX;
            posY = ev.gesture.deltaY + lastY;
            break;
          case "transform":
            rotation = last_rotation + ev.gesture.rotation;
            scale = Math.max(1, Math.min(last_scale * ev.gesture.scale, 10));
        }
        boundRect = rect.getBoundingClientRect();
        _this.zooming = true;
        if (scale < 1.02) {
          _this.zooming = false;
          posX = 0;
          posY = 0;
        } else if (old_scale !== scale) {
          posX = lastX;
          posY = lastY;
        } else {
          offsetY = (boundRect.height - win_height) / 2;
          offsetX = (boundRect.width - win_width) / 2;
          if (scale >= 1.02) {
            if (boundRect.top < 1 && win_height > boundRect.height && ev.gesture.deltaY < 0) {
              posY = Math.floor(offsetY);
              lastY = Math.floor(offsetY);
            } else if (boundRect.top > -1 && ev.gesture.deltaY >= 0 && win_height < boundRect.height) {
              posY = offsetY;
              lastY = offsetY;
            }
            if (boundRect.left < 1 && win_width > boundRect.width && ev.gesture.deltaX < 0) {
              posX = Math.floor(offsetX);
              lastX = Math.floor(offsetX);
            } else if (boundRect.left > -1 && ev.gesture.deltaX >= 0 && win_width < boundRect.width) {
              posX = offsetX;
              lastX = offsetX;
            }
            if (boundRect.bottom > win_height - 1 && win_height > boundRect.height && ev.gesture.deltaY > 0) {
              posY = -Math.floor(offsetY);
              lastY = -Math.floor(offsetY);
            } else if (boundRect.bottom < win_height + 1 && ev.gesture.deltaY <= 0 && win_height < boundRect.height) {
              posY = -offsetY;
              lastY = -offsetY;
            }
            if (boundRect.right > win_width - 1 && win_width > boundRect.width && ev.gesture.deltaX > 0) {
              posX = -Math.floor(offsetX);
              lastX = -Math.floor(offsetX);
            } else if (boundRect.right < win_width + 1 && ev.gesture.deltaX <= 0 && win_width < boundRect.width) {
              posX = -offsetX;
              lastX = -offsetX;
            }
          }
        }
        transform = " translate3d(" + posX + "px," + posY + "px, 0) " + "scale3d(" + scale + "," + scale + ", 0) ";
        window.transform_iscroll = transform;
        transform += window.transform_rotate;
        rect.style.transform = transform;
        return rect.style.webkitTransform = transform;
      });
    };

    return PhotoMainView;

  })(PageView);
  
}});

window.require.define({"views/photo-upload-view": function(exports, require, module) {
  var PageView, PhotoUploadView, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  mediator = require('mediator');

  module.exports = PhotoUploadView = (function(_super) {

    __extends(PhotoUploadView, _super);

    PhotoUploadView.template("photo-upload");

    PhotoUploadView.prototype.container = '#page-container';

    PhotoUploadView.prototype.autoRender = false;

    PhotoUploadView.prototype.rotate = 0;

    PhotoUploadView.prototype.events = {
      'click #upload': 'upload',
      'click #turnLeft': 'turnLeft',
      'click #turnRight': 'turnRight'
    };

    function PhotoUploadView(sourceType) {
      this.afterRender = __bind(this.afterRender, this);

      this.upload = __bind(this.upload, this);

      this.getPicture = __bind(this.getPicture, this);

      var _this = this;
      this.getPicture(sourceType, function(err, photo) {
        if (photo) {
          _this.photo = photo;
          return _this.render();
        } else {
          return window.history.back();
        }
      });
      PhotoUploadView.__super__.constructor.call(this);
    }

    PhotoUploadView.prototype.getPicture = function(sourceType, callback) {
      var fail, success,
        _this = this;
      sourceType = (function() {
        switch (sourceType) {
          case 'album':
            return navigator.camera.PictureSourceType.PHOTOLIBRARY;
          case 'camera':
            return navigator.camera.PictureSourceType.CAMERA;
          case 0:
            return null;
        }
      })();
      if (sourceType === null) {
        callback(null, null);
        return;
      }
      success = function(imageURI) {
        return callback(null, imageURI);
      };
      fail = function(err) {
        return callback(err, null);
      };
      return navigator.camera.getPicture(success, fail, {
        quality: 85,
        targetWidth: 1800,
        targetHeight: 1200,
        destinationType: navigator.camera.DestinationType.FILE_URI,
        sourceType: sourceType,
        correctOrientation: true,
        allowEdit: true
      });
    };

    PhotoUploadView.prototype.upload = function(e) {
      var fail, ft, options, url, win, wylij_btn,
        _this = this;
      e.preventDefault();
      url = this.$photo.attr('src');
      wylij_btn = $(e.currentTarget).html();
      $(e.currentTarget).text('Wysyłam...');
      $('.photo_upload button').attr('disabled', 'disabled');
      options = new FileUploadOptions();
      options.fileKey = "file";
      options.fileName = url.substr(url.lastIndexOf('/') + 1);
      options.mimeType = "image/png";
      options.chunkedMode = false;
      options.headers = {
        Accept: "application/json"
      };
      options.params = {
        description: "",
        rotate: this.rotate
      };
      win = function(res) {
        _this.trigger("photo-uploaded");
        return window.alert("Zdjęcie wysłano.", function() {
          return console.log('photo uploaded');
        }, "Wysyłanie zdjęcia", "OK");
      };
      fail = function(error) {
        return window.alert("Nie udało się wgrać zdjęcia. Spróbuj jeszcze raz.", function() {
          $(e.currentTarget).html(wylij_btn);
          return $('.photo_upload button').removeAttr('disabled');
        });
      };
      ft = new FileTransfer();
      return ft.upload(url, encodeURI("http://" + mediator.config.host + "/photo/upload"), win, fail, options, true);
    };

    PhotoUploadView.prototype.turnRight = function() {
      this.$photo.removeClass('rotate-' + (this.rotate * 90));
      if (this.rotate < 3) {
        this.rotate += 1;
      } else {
        this.rotate = 0;
      }
      return this.$photo.addClass('rotate-' + (this.rotate * 90));
    };

    PhotoUploadView.prototype.turnLeft = function() {
      this.$photo.removeClass('rotate-' + (this.rotate * 90));
      if (this.rotate > 0) {
        this.rotate -= 1;
      } else {
        this.rotate = 3;
      }
      return this.$photo.addClass('rotate-' + (this.rotate * 90));
    };

    PhotoUploadView.prototype.afterRender = function() {
      var _this = this;
      PhotoUploadView.__super__.afterRender.apply(this, arguments);
      this.$photo = this.$('#photo');
      this.$photo.attr('src', this.photo);
      return this.$photo.bind('load', function(e) {
        var availableWidth, height, renderedImgHeight, width, _ref;
        _ref = _this.$photo[0], width = _ref.width, height = _ref.height;
        availableWidth = _this.$('.photo_wrapper').width();
        _this.$('.photo_wrapper').height(availableWidth);
        if (width > height) {
          _this.$photo.css('height', 'auto').width(availableWidth);
          renderedImgHeight = _this.$('#photo').height();
          return _this.$photo.css('position', 'relative').css('top', availableWidth / 2 - renderedImgHeight / 2);
        } else {
          return _this.$photo.height(availableWidth).css('width', 'auto');
        }
      });
    };

    return PhotoUploadView;

  })(PageView);
  
}});

window.require.define({"views/photo/comments-view": function(exports, require, module) {
  var CollectionView, PhotoCommentItemView, PhotoCommentsView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CollectionView = require('views/base/collection-view');

  View = require('views/base/view');

  PhotoCommentItemView = (function(_super) {

    __extends(PhotoCommentItemView, _super);

    function PhotoCommentItemView() {
      return PhotoCommentItemView.__super__.constructor.apply(this, arguments);
    }

    PhotoCommentItemView.template('photo/comment');

    PhotoCommentItemView.prototype.afterRender = function() {
      return $('.comment-list').removeClass('hidden');
    };

    return PhotoCommentItemView;

  })(View);

  module.exports = PhotoCommentsView = (function(_super) {

    __extends(PhotoCommentsView, _super);

    function PhotoCommentsView() {
      return PhotoCommentsView.__super__.constructor.apply(this, arguments);
    }

    PhotoCommentsView.prototype.autoRender = false;

    PhotoCommentsView.prototype.itemView = PhotoCommentItemView;

    PhotoCommentsView.prototype.container = '.sub-content';

    return PhotoCommentsView;

  })(CollectionView);
  
}});

window.require.define({"views/photos-view": function(exports, require, module) {
  var CollectionView, PhotoFeedItemView, PhotosView, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CollectionView = require('views/base/collection-view');

  PhotoFeedItemView = require('views/feed/photo-feed-item-view');

  mediator = require('mediator');

  module.exports = PhotosView = (function(_super) {

    __extends(PhotosView, _super);

    function PhotosView() {
      return PhotosView.__super__.constructor.apply(this, arguments);
    }

    PhotosView.prototype.autoRender = false;

    PhotosView.prototype.animationDuration = 0;

    PhotosView.prototype.container = '#feed-container';

    PhotosView.prototype.className = 'feed';

    PhotosView.prototype.id = 'feed';

    PhotosView.prototype.getView = function(model) {
      return new PhotoFeedItemView({
        model: model
      });
    };

    return PhotosView;

  })(CollectionView);
  
}});

window.require.define({"views/profile-gallery-page-view": function(exports, require, module) {
  var PageView, ProfileGalleryPageView, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  mediator = require('mediator');

  module.exports = ProfileGalleryPageView = (function(_super) {

    __extends(ProfileGalleryPageView, _super);

    function ProfileGalleryPageView() {
      return ProfileGalleryPageView.__super__.constructor.apply(this, arguments);
    }

    ProfileGalleryPageView.template('profile-gallery');

    ProfileGalleryPageView.prototype.autoRender = true;

    ProfileGalleryPageView.prototype.className = 'profile-page';

    ProfileGalleryPageView.prototype.id = 'profile';

    return ProfileGalleryPageView;

  })(PageView);
  
}});

window.require.define({"views/profile-page-view": function(exports, require, module) {
  var PageView, ProfilePageView, mediator,
    __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  mediator = require('mediator');

  module.exports = ProfilePageView = (function(_super) {

    __extends(ProfilePageView, _super);

    function ProfilePageView() {
      this.composeMail = __bind(this.composeMail, this);

      this.dispose = __bind(this.dispose, this);
      return ProfilePageView.__super__.constructor.apply(this, arguments);
    }

    ProfilePageView.template('profile');

    ProfilePageView.prototype.autoRender = false;

    ProfilePageView.prototype.className = 'profile-page';

    ProfilePageView.prototype.id = 'profile';

    ProfilePageView.prototype.events = {
      'click .btn-logout': 'logout',
      'submit #form-comment-add': 'addComment',
      'click .add-friend': 'addFriend',
      'click .compose-mail-button': 'composeMail',
      'click .btn-older-comments': 'getOlderComments'
    };

    ProfilePageView.prototype.getOlderComments = function() {
      var _this = this;
      return this.subview('comments').collection.getOlderComments(function(collection) {
        window.profile_comments[collection.userId] = collection.models.concat([]);
        if (collection.total <= collection.models.length) {
          return $('.btn-older-comments').css('display', 'none');
        }
      });
    };

    ProfilePageView.prototype.afterRender = function() {
      var _this = this;
      ProfilePageView.__super__.afterRender.apply(this, arguments);
      this.scroll();
      this.enableScroll();
      if ($('.topbar .action-button .btn-logout').length) {
        return $('.profile-page .btn-logout').remove();
      } else {
        this.logoutButton = $('.btn-logout');
        if (this.logoutButton.length) {
          $('.topbar .action-button').append(this.logoutButton);
          return this.logoutButton.click(function(e) {
            e.preventDefault();
            return _this.logout();
          });
        }
      }
    };

    ProfilePageView.prototype.dispose = function() {
      if (this.logoutButton) {
        this.logoutButton.remove();
      }
      return ProfilePageView.__super__.dispose.call(this);
    };

    ProfilePageView.prototype.logout = function() {
      console.log('header logout clicked');
      return mediator.auth.logout();
    };

    ProfilePageView.prototype.addFriend = function(e) {
      var userId,
        _this = this;
      e.preventDefault();
      if (!this.$('.add-friend').hasClass('disabled')) {
        userId = parseInt(this.model.id);
        return $.ajax('/profile/' + userId + '/invite', {
          type: 'post',
          success: function(data, status, jqXHR) {
            return window.alert('Zaproszenie do listy znajomych zostało wysłane', function() {
              return _this.$('.add-friend').addClass('disabled');
            }, 'Znajomi');
          }
        });
      }
    };

    ProfilePageView.prototype.composeMail = function(e) {
      var _this = this;
      e.preventDefault();
      this.mailAddForm = $('\
        <form name="form-mail-add" action="#" class="form-add-mail form_4_keyboard remove-on-backbutton">\
          <textarea class="mail-input content"></textarea>\
          <div class="form_4_keyboard_btm">\
            <button style="display: block; z-index: 999; position:absolute; top: 0px; right:67px;" class="btn cancel-button" type="button">Anuluj</button>\
            <button style="block; z-index: 999; position:absolute; top: 0px; right:-6px;" class="btn submit-button remove-on-backbutton" type="submit">Wyślij</button>\
          </div>\
        </form>');
      $(document.body).prepend(this.mailAddForm);
      this.disableScroll();
      this.content = this.mailAddForm.find('textarea.content');
      this.content.click(function() {
        return _this.disableScroll();
      });
      setTimeout((function() {
        $('form').css('height', '100%');
        return $('form').css('width', '100%');
      }), 1000);
      $('.form-add-mail textarea')[0].focus();
      $('.cancel-button').click(function() {
        _this.enableScroll();
        return _this.mailAddForm.remove();
      });
      return this.mailAddForm.submit(function(e) {
        var content, contentElement, title, userId;
        e.preventDefault();
        contentElement = $(e.currentTarget).find('.mail-input');
        content = contentElement.val().trim();
        userId = parseInt(_this.model.id);
        title = 'Wiadomość z aplikacji nk.pl';
        if (content.length !== 0) {
          return $.ajax('/mailCompose', {
            type: 'post',
            data: JSON.stringify({
              subject: title,
              content: content,
              id: userId
            }),
            success: function(data, status, jqXHR) {
              window.alert('Wiadomość wysłana', (function() {}), 'Poczta', 'OK');
              _this.enableScroll();
              return _this.mailAddForm.remove();
            },
            error: function(jqXHR) {
              _this.enableScroll();
              _this.mailAddForm.remove();
              return _this.buttons.remove();
            }
          });
        }
      });
    };

    ProfilePageView.prototype.addComment = function(e) {
      var content, contentElement, userId,
        _this = this;
      e.preventDefault();
      contentElement = $(e.currentTarget).find('.comment-content');
      content = contentElement.val().trim();
      userId = parseInt(this.model.id);
      if (content.length !== 0) {
        return $.ajax('/profile/' + userId + '/comment_add', {
          type: 'post',
          data: JSON.stringify({
            comment: content,
            profile_id: userId
          }),
          success: function(data, status, jqXHR) {
            var commentsView, profileComments;
            contentElement.val('');
            commentsView = _this.subview('comments');
            profileComments = commentsView.collection;
            profileComments.fetch({
              update: true,
              remove: false,
              refresh: true,
              success: function(collection) {
                return window.profile_comments[userId] = collection.models.concat([]);
              }
            });
            return window.alert('Komentarz dodany', (function() {}), 'Profil');
          }
        });
      }
    };

    return ProfilePageView;

  })(PageView);
  
}});

window.require.define({"views/profile/comments-view": function(exports, require, module) {
  var CollectionView, ProfileCommentItemView, ProfileCommentsView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CollectionView = require('views/base/collection-view');

  View = require('views/base/view');

  ProfileCommentItemView = (function(_super) {

    __extends(ProfileCommentItemView, _super);

    function ProfileCommentItemView() {
      return ProfileCommentItemView.__super__.constructor.apply(this, arguments);
    }

    ProfileCommentItemView.template('profile/comment');

    ProfileCommentItemView.prototype.afterRender = function() {
      return $('.comment-list').removeClass('hidden');
    };

    return ProfileCommentItemView;

  })(View);

  module.exports = ProfileCommentsView = (function(_super) {

    __extends(ProfileCommentsView, _super);

    function ProfileCommentsView() {
      return ProfileCommentsView.__super__.constructor.apply(this, arguments);
    }

    ProfileCommentsView.prototype.autoRender = false;

    ProfileCommentsView.prototype.itemView = ProfileCommentItemView;

    ProfileCommentsView.prototype.container = '.sub-content';

    return ProfileCommentsView;

  })(CollectionView);
  
}});

window.require.define({"views/shout-main-view": function(exports, require, module) {
  var FeedCollection, PageView, ShoutCommentModel, ShoutMainView, mediator,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  PageView = require('views/base/page-view');

  mediator = require('mediator');

  ShoutCommentModel = require('models/shout/comment-model');

  FeedCollection = require('models/feed-collection');

  module.exports = ShoutMainView = (function(_super) {

    __extends(ShoutMainView, _super);

    function ShoutMainView() {
      return ShoutMainView.__super__.constructor.apply(this, arguments);
    }

    ShoutMainView.template("shout/single");

    ShoutMainView.prototype.containerMethod = 'html';

    ShoutMainView.prototype.events = {
      'click .btn-older-comments': 'getOlderComments',
      'click .btn-older-stars': 'getOlderStars',
      'submit .comment-add form': 'addComment',
      'click .shout-comment-add': 'focusCommentAdd',
      'click .countStars': 'showStars',
      'click .countComments': 'showComments'
    };

    ShoutMainView.prototype.showStars = function(e) {
      e.preventDefault();
      return this.trigger("showStars", {
        user_id: this.model.attributes.user_id,
        shout_id: this.model.attributes.shout_id
      });
    };

    ShoutMainView.prototype.showComments = function(e) {
      e.preventDefault();
      return this.trigger("showComments", {
        user_id: this.model.attributes.user_id,
        shout_id: this.model.attributes.shout_id
      });
    };

    ShoutMainView.prototype.focusCommentAdd = function(e) {
      var _this = this;
      console.log('focus comment add');
      e.preventDefault();
      return setTimeout(function() {
        window.scrollTo(0, Math.ceil($('.comment-list').height()) + Math.ceil($('.single-comment-add').height()) + Math.ceil($('.btn-older-comments').parent().height()));
        return setTimeout(function() {
          var n;
          n = document.createTextNode(' ');
          $('.page-container').append(n);
          return setTimeout(function() {
            return n.parentNode.removeChild(n);
          }, 0);
        }, 50);
      }, 50);
    };

    ShoutMainView.prototype.afterRender = function() {
      var _this = this;
      if (this.subview('comments')) {
        this.$('.single-comment-add').show();
        this.$('.btn-older-stars').hide();
        this.subview('comments').collection.on("reset add", function(model) {
          if (model.collection.total > model.collection.models.length) {
            return _this.$('.btn-older-comments').show();
          } else {
            return _this.$('.btn-older-comments').hide();
          }
        });
      }
      if (this.subview('stars')) {
        this.$('.single-comment-add').hide();
        this.$('.btn-older-comments').hide();
        this.subview('stars').collection.on("reset add", function(model) {
          if (model.collection.total > model.collection.models.length) {
            return _this.$('.btn-older-stars').show();
          } else {
            return _this.$('.btn-older-stars').hide();
          }
        });
      }
      ShoutMainView.__super__.afterRender.apply(this, arguments);
      this.scroll();
      return $('.events-box').remove();
    };

    ShoutMainView.prototype.getOlderComments = function() {
      return this.subview('comments').collection.getOlderComments();
    };

    ShoutMainView.prototype.getOlderStars = function() {
      console.log('get older stars');
      return this.subview('stars').collection.getOlderStars();
    };

    ShoutMainView.prototype.addComment = function(e) {
      var comment, input, model, shout, shout_id, user_id, _ref,
        _this = this;
      e.preventDefault();
      input = this.$('input');
      if (input.hasClass('disabled')) {
        return;
      }
      input.addClass('disabled');
      setTimeout(function() {
        return input.removeClass('disabled');
      }, 2000);
      comment = input.val().trim();
      if (comment.length !== 0) {
        input.attr('disabled', 'disabled');
        shout = this.subview('shout').model;
        _ref = shout.attributes, user_id = _ref.user_id, shout_id = _ref.shout_id;
        model = new ShoutCommentModel({
          shout_user_id: user_id,
          shout_id: shout_id,
          comment: input.val()
        });
        return model.save(null, {
          complete: function() {
            return input.removeAttr('disabled');
          },
          success: function() {
            var collection;
            $('.comment-list').removeClass('hidden');
            input.val('');
            shout.set("comment_count", shout.get("comment_count") + 1);
            collection = new FeedCollection;
            collection.fetch({
              update: true,
              remove: true,
              refresh: true
            });
            return _this.subview('comments').collection.fetch({
              update: true,
              remove: false
            });
          }
        });
      }
    };

    return ShoutMainView;

  })(PageView);
  
}});

window.require.define({"views/shout/comments-view": function(exports, require, module) {
  var CollectionView, ShoutCommentItemView, ShoutCommentsView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CollectionView = require('views/base/collection-view');

  View = require('views/base/view');

  ShoutCommentItemView = (function(_super) {

    __extends(ShoutCommentItemView, _super);

    function ShoutCommentItemView() {
      return ShoutCommentItemView.__super__.constructor.apply(this, arguments);
    }

    ShoutCommentItemView.template('shout/comment');

    ShoutCommentItemView.prototype.afterRender = function() {
      return $('.comment-list').removeClass('hidden');
    };

    return ShoutCommentItemView;

  })(View);

  module.exports = ShoutCommentsView = (function(_super) {

    __extends(ShoutCommentsView, _super);

    function ShoutCommentsView() {
      return ShoutCommentsView.__super__.constructor.apply(this, arguments);
    }

    ShoutCommentsView.prototype.itemView = ShoutCommentItemView;

    ShoutCommentsView.prototype.container = '.sub-content';

    ShoutCommentsView.prototype.autoRender = false;

    return ShoutCommentsView;

  })(CollectionView);
  
}});

window.require.define({"views/shout/stars-view": function(exports, require, module) {
  var CollectionView, ShoutStarItemView, ShoutStarsView, View,
    __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  CollectionView = require('views/base/collection-view');

  View = require('views/base/view');

  ShoutStarItemView = (function(_super) {

    __extends(ShoutStarItemView, _super);

    function ShoutStarItemView() {
      return ShoutStarItemView.__super__.constructor.apply(this, arguments);
    }

    ShoutStarItemView.template('shout/stars');

    ShoutStarItemView.prototype.afterRender = function() {
      var _this = this;
      $('.comment-list').removeClass('hidden').addClass('star-list');
      return setTimeout(function() {
        var userName;
        userName = $(_this.$el.find('.content a'));
        if (userName.height() === parseInt(userName.css('line-height'))) {
          return userName.addClass('high');
        }
      }, 1);
    };

    return ShoutStarItemView;

  })(View);

  module.exports = ShoutStarsView = (function(_super) {

    __extends(ShoutStarsView, _super);

    function ShoutStarsView() {
      return ShoutStarsView.__super__.constructor.apply(this, arguments);
    }

    ShoutStarsView.prototype.itemView = ShoutStarItemView;

    ShoutStarsView.prototype.container = '.sub-content';

    ShoutStarsView.prototype.autoRender = false;

    return ShoutStarsView;

  })(CollectionView);
  
}});

window.require.define({"views/templates/albumlist": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var stack1, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing, self=this;

  function program1(depth0,data,depth1) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n<li>\n  <a href=\"#album/";
    stack1 = depth1.user_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    <img src=\"";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.cover;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    <div class=\"info\">\n      <span class=\"count\">";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.photo_count;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + " ";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.photo_count;
    foundHelper = helpers.liczebnik;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, "zdjęcie", "zdjęcia", "zdjęć", {hash:{}}) : helperMissing.call(depth0, "liczebnik", stack1, "zdjęcie", "zdjęcia", "zdjęć", {hash:{}});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "</span>\n      <span class=\"name\">";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.title;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</span>\n    </div>\n</li>\n";
    return buffer;}

    stack1 = depth0.albums;
    stack1 = helpers.each.call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.programWithDepth(program1, data, depth0)});
    if(stack1 || stack1 === 0) { return stack1; }
    else { return ''; }});
}});

window.require.define({"views/templates/feed-event": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, stack2, foundHelper, functionType="function", escapeExpression=this.escapeExpression, self=this, helperMissing=helpers.helperMissing;

  function program1(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n    <a class=\"event_content\" href=\"#profile/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.user_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    ";
    return buffer;}

  function program3(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n    <a class=\"event_content\" href=\"#galleryphoto/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.gallery_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.photo_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/comments\">\n    ";
    return buffer;}

  function program5(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n    <a class=\"event_content\" href=\"#shout/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.user_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.shout_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/comments\">\n    ";
    return buffer;}

  function program7(depth0,data) {
    
    
    return "\n      </a>\n    ";}

  function program9(depth0,data) {
    
    
    return "\n      </a>\n    ";}

  function program11(depth0,data) {
    
    
    return "\n      </a>\n    ";}

    buffer += "<div class=\"wrp\">\n  <div class=\"content events-box\">\n    \n    <img src=\"images/i_notify.gif\" width=\"15\" class=\"event_icon\">\n    \n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "profile";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(1, program1, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(1, program1, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "photo";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(3, program3, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(3, program3, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "shout";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(5, program5, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(5, program5, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    <div class=\"media-body\">\n      <div class=\"feed_content\">";
    foundHelper = helpers.content;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.content; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "</div>\n      <div class=\"datetime\">";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "</div>\n    </div>\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "profile";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(7, program7, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(7, program7, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "photo";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(9, program9, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(9, program9, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "profile";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(11, program11, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(11, program11, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n    \n  </div>\n</div>\n\n<!-- <a class=\"pull-left\" href=\"#\">\n  event -->\n  <!-- <img class=\"media-object\" data-src=\"";
    foundHelper = helpers.img;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.img; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\" alt=\"64x64\" style=\"width: 64px; height: 64px;\" src=\"";
    foundHelper = helpers.img;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.img; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\"> -->\n<!-- </a> -->\n<!-- <div class=\"media-body\">\n  <h4 class=\"media-heading\">";
    foundHelper = helpers.name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</h4>\n  ";
    foundHelper = helpers.msg;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.msg; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n  <p>";
    foundHelper = helpers.time;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.time; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</p>\n</div> -->\n";
    return buffer;});
}});

window.require.define({"views/templates/feed-photo": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, self=this, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;

  function program1(depth0,data) {
    
    
    return "\n        <span><i class=\"icon-ok\"></i></span>\n      ";}

  function program3(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n        <a href=\"#\" ";
    stack1 = depth0.cannot_rate;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.program(6, program6, data),fn:self.program(4, program4, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += ">Fajne</a>\n      ";
    return buffer;}
  function program4(depth0,data) {
    
    
    return "class=\"disabled star\"";}

  function program6(depth0,data) {
    
    
    return "class=\"add-star\"";}

  function program8(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n<div class=\"comments last_comment std-frame bg-white no-top-brdr\">\n  <a href=\"#profile/";
    stack1 = depth0.last_comment;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\"><img class=\"comment_avatar\" src=\"";
    stack1 = depth0.last_comment;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.avatar;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\" width=\"25\"></a>\n  <div class=\"comment_content\">\n    <a href=\"#profile/";
    stack1 = depth0.last_comment;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">";
    stack1 = depth0.last_comment;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</a>\n    <a class=\"txt\" href=\"#photo/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.raw_user;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.album_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.album_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.photo_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.photo_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/comments\">";
    stack1 = depth0.last_comment;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.content;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</a>\n  </div>\n</div>\n";
    return buffer;}

  function program10(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n  <div class=\"std-frame bg-white no-top-brdr merged_events\">\n  ";
    stack1 = depth0.events_box;
    stack1 = helpers.each.call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.programWithDepth(program11, data, depth0)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n  </div>\n";
    return buffer;}
  function program11(depth0,data,depth1) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n\n    <div class=\"content events-box\">\n      <img src=\"images/i_notify.gif\" width=\"15\" class=\"event_icon\">\n      \n      <a class=\"event_content\" href=\"#photo/";
    stack1 = depth1.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.raw_user;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    stack1 = depth1.album_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    stack1 = depth1.photo_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/comments\">\n        <div class=\"media-body\">\n          <div class=\"feed_content\">";
    stack1 = depth0.html;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "</div>\n          <div class=\"datetime\">";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "</div>\n        </div>\n      </a>\n      \n    </div>\n\n  ";
    return buffer;}

    buffer += "<div class=\"wrp\">\n  <div class=\"content\">\n    <a class=\"pull-left\" href=\"/profile/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.raw_user;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n      <img class=\"img-polaroid\" src=\"";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.avatar;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    </a>\n    \n    <div class=\"media-body\">\n      <h4 class=\"media-heading\">\n        <a href=\"#profile/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.raw_user;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.display_name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</a>\n      </h4>\n      <div class=\"datetime\">";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "</div>\n    </div>\n\n    <div class=\"clear main-img\">\n      <a href=\"#photo/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.raw_user;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.album_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.album_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.photo_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.photo_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n        <img width=\"320\" src=\"";
    stack1 = depth0.photo;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\" data-user-id=\"";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.raw_user;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\" data-album-id=\"";
    foundHelper = helpers.album_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.album_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\" data-photo-id=\"";
    foundHelper = helpers.photo_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.photo_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n      </a>\n    </div>\n\n  </div>\n  \n  <ul class=\"actions clearfix\">\n    <li class=\"fajne\">\n      ";
    stack1 = depth0.rated;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.program(3, program3, data),fn:self.program(1, program1, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n    </li>\n    <li class=\"comment\">\n      <a class=\"photo-comment-add\" href=\"#galleryphoto/";
    foundHelper = helpers.gallery_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.gallery_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.photo_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.photo_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/addComment\">Skomentuj</a></li>\n    <li class=\"count\">\n      <span><img src=\"images/i_star.gif\" width=\"14\" alt=\"Fajne\">\n      <strong class=\"star_count\">";
    stack1 = depth0.ratings;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.rating_count;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</strong>\n      </span>\n    </li>\n    \n    <li class=\"count count-comments\">\n     <span><img src=\"images/i_comment.gif\" width=\"14\" alt=\"Komentarze\">\n      <strong class=\"comment_count\">";
    foundHelper = helpers.comment_count;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_count; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</strong>\n      </span>\n    </li>\n    \n  </ul>\n</div>\n\n";
    stack1 = depth0.last_comment;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(8, program8, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n";
    stack1 = depth0.events_box;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(10, program10, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n";
    return buffer;});
}});

window.require.define({"views/templates/feed-shout": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, self=this, helperMissing=helpers.helperMissing;

  function program1(depth0,data) {
    
    
    return "\n      <a class=\"pull-left\">\n    ";}

  function program3(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n      <a class=\"pull-left\" href=\"#profile/";
    foundHelper = helpers.user_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.user_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n    ";
    return buffer;}

  function program5(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n        <span>";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.display_name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</span>\n      ";
    return buffer;}

  function program7(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n        <a href=\"#";
    stack1 = depth0.mask_user_id;
    stack1 = helpers.unless.call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(8, program8, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\">";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.display_name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</a>\n      ";
    return buffer;}
  function program8(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "profile/";
    foundHelper = helpers.user_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.user_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1);
    return buffer;}

  function program10(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n      <a class=\"external_link\" href=\"";
    foundHelper = helpers.recommended_site_url;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.recommended_site_url; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n      <div class=\"recommended_site\">\n        ";
    stack1 = depth0.recommended_site_image_url;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(11, program11, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n        <strong>";
    foundHelper = helpers.recommended_site_title;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.recommended_site_title; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</strong>\n        <p>";
    foundHelper = helpers.recommended_site_description;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.recommended_site_description; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</p>\n      </div>\n      </a>\n    ";
    return buffer;}
  function program11(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n          <img class=\"img-polaroid pull-left\" src=\"";
    foundHelper = helpers.recommended_site_image_url;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.recommended_site_image_url; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\" width=\"73\">\n        ";
    return buffer;}

  function program13(depth0,data) {
    
    
    return "\n        <span><i class=\"icon-ok\"></i></span>\n      ";}

  function program15(depth0,data) {
    
    
    return "\n        <a class=\"add-star\" href=\"#\">Fajne</a>\n      ";}

  function program17(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n  <div class=\"std-frame bg-white no-top-brdr merged_events\">\n  ";
    stack1 = depth0.events_box;
    stack1 = helpers.each.call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(18, program18, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n  </div>\n";
    return buffer;}
  function program18(depth0,data) {
    
    var buffer = "", stack1, stack2, foundHelper;
    buffer += "\n\n  <div class=\"content events-box\">\n    <img src=\"images/i_notify.gif\" width=\"15\" class=\"event_icon\">\n    \n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "profile";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(19, program19, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(19, program19, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "photo";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(21, program21, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(21, program21, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "shout";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(23, program23, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(23, program23, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    <div class=\"media-body\">\n      <div class=\"feed_content\">";
    stack1 = depth0.html;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "</div>\n      <div class=\"datetime\">";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "</div>\n    </div>\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "profile";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(25, program25, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(25, program25, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "photo";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(27, program27, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(27, program27, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n    ";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.event_name;
    stack2 = {};
    stack2['compare'] = "shout";
    foundHelper = helpers.if_eq;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:stack2,inverse:self.noop,fn:self.program(29, program29, data)}) : helperMissing.call(depth0, "if_eq", stack1, {hash:stack2,inverse:self.noop,fn:self.program(29, program29, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n    \n  </div>\n\n  ";
    return buffer;}
  function program19(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n    <a class=\"event_content\" href=\"#profile/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.user_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    ";
    return buffer;}

  function program21(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n    <a class=\"event_content\" href=\"#galleryphoto/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.gallery_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.photo_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/comments>\">\n    ";
    return buffer;}

  function program23(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n    <a class=\"event_content\" href=\"#shout/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.user_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/";
    stack1 = depth0.normalized_raw_data;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.shout_id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "/comments\">\n    ";
    return buffer;}

  function program25(depth0,data) {
    
    
    return "\n      </a>\n    ";}

  function program27(depth0,data) {
    
    
    return "\n      </a>\n    ";}

  function program29(depth0,data) {
    
    
    return "\n      </a>\n    ";}

    buffer += "<div class=\"wrp\">\n  <div class=\"content\">\n    ";
    stack1 = depth0.mask_user_id;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.program(3, program3, data),fn:self.program(1, program1, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n      <img class=\"img-polaroid\" src=\"";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.avatar;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    </a>\n    \n    <div class=\"media-body\">\n      <h4 class=\"media-heading\">\n      ";
    stack1 = depth0.mask_user_id;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.program(7, program7, data),fn:self.program(5, program5, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n      </h4>\n      <div class=\"datetime\">";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "</div>\n    </div>\n\n    <div class=\"feed_content feed-shout-content\">";
    foundHelper = helpers.content;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.content; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</div>\n    \n    ";
    stack1 = depth0.recommended_site_url;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(10, program10, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n  </div> \n\n  <ul class=\"actions clearfix\">\n    <li class=\"fajne\">\n      ";
    stack1 = depth0.starred;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.program(15, program15, data),fn:self.program(13, program13, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n    </li>\n    <li class=\"comment\">\n      <a class=\"shout-comment-add\" href=\"#shout/";
    foundHelper = helpers.user_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.user_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.shout_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.shout_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/comments\">Skomentuj</a>\n    </li>\n    <li class=\"count countStars\"><a href=\"#shout/";
    foundHelper = helpers.user_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.user_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.shout_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.shout_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/stars\"><img src=\"images/i_star.gif\" width=\"14\" alt=\"Fajne\"> <strong class=\"star_count\">";
    foundHelper = helpers.star_count;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.star_count; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</strong></a></li>\n    <li class=\"count countComments\"><a href=\"#shout/";
    foundHelper = helpers.user_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.user_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/";
    foundHelper = helpers.shout_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.shout_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/comments\"><img src=\"images/i_comment.png\" width=\"14\" alt=\"Komentarze\"> <strong class=\"comment_count\">";
    foundHelper = helpers.comment_count;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_count; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</strong></a></li>\n  </ul>\n</div>\n\n";
    stack1 = depth0.events_box;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(17, program17, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n\n<!-- <a class=\"pull-left\" href=\"#\"> -->\n  <!-- shout -->\n  <!-- <img class=\"media-object\" data-src=\"";
    foundHelper = helpers.img;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.img; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\" alt=\"64x64\" style=\"width: 64px; height: 64px;\" src=\"";
    foundHelper = helpers.img;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.img; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\"> -->\n<!-- </a> -->\n<!-- <div class=\"media-body\">\n  <h4 class=\"media-heading\">";
    foundHelper = helpers.name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</h4>\n  ";
    foundHelper = helpers.msg;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.msg; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n  <p>";
    foundHelper = helpers.time;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.time; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</p> -->\n<!-- </div> -->\n";
    return buffer;});
}});

window.require.define({"views/templates/feed/birthdays": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<!-- <div class=\"alert\">\n  <strong>Sebcio</strong> obchodzi dzisiaj urodziny!\n</div> -->";});
}});

window.require.define({"views/templates/feed/feed": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression;


    buffer += "<a class=\"pull-left\" href=\"#\">\n  <img class=\"media-object\" data-src=\"";
    foundHelper = helpers.img;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.img; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\" alt=\"64x64\" style=\"width: 64px; height: 64px;\" src=\"";
    foundHelper = helpers.img;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.img; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n</a>\n<div class=\"media-body\">\n  <h4 class=\"media-heading\">";
    foundHelper = helpers.name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</h4>\n  ";
    foundHelper = helpers.msg;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.msg; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n</div>\n\n\n";
    return buffer;});
}});

window.require.define({"views/templates/feed/main": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "";


    buffer += "<div id=\"birthdays-container\"></div>\n<div id=\"feed-container\"></div>\n<div class=\"btm-btn multi\">\n  <button class=\"scroll-top btn btn-logout hidden\">Do góry</button>\n  ";
    buffer += "\n</div>";
    return buffer;});
}});

window.require.define({"views/templates/friendlist": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var stack1, functionType="function", escapeExpression=this.escapeExpression, self=this;

  function program1(depth0,data) {
    
    var buffer = "", stack1;
    buffer += "\n<div class=\"item\">\n  <a href=\"#profile/";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    <img src=\"";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.photo_uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    <p><span>";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "</span></p>\n  </a>\n</div>\n";
    return buffer;}

    stack1 = depth0.users;
    stack1 = helpers.each.call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(1, program1, data)});
    if(stack1 || stack1 === 0) { return stack1; }
    else { return ''; }});
}});

window.require.define({"views/templates/friends": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<div class=\"friends clearfix\">\r\n  <section class=\"std-frame std-padd bg-white\">\r\n    <form class=\"form-search user-search one-line-form\">\r\n      <button type=\"reset\" class=\"btn pull-right reset-search hidden\"><i class=\"icon-remove\"></i></button>\r\n      <div class=\"input-spreader full\">\r\n        <input class=\"input-medium search-query input-blur-top\" type=\"text\" placeholder=\"Szukaj\" autocorrect=\"off\" autocapitalize=\"off\" autocomplete=\"off\"/>\r\n      </div>\r\n    </form>\r\n  </section>\r\n\r\n  <div id=\"friendlist-container\" class=\"clearfix\"></div>\r\n\r\n</div>\r\n\r\n<div class=\"btm-btn multi\">\r\n  <button class=\"scroll-top btn btn-logout\">Do góry</button>\r\n  <button class=\"show-more btn btn-logout\">Pokaż więcej</button>\r\n</div>";});
}});

window.require.define({"views/templates/gallery": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<div class=\"media\">\r\n  <div class=\"gallery_tiles\">\r\n  	<ul id=\"albumlist-container\"></ul>\r\n  </div>\r\n</div>\r\n<div class=\"btm-btn multi action-buttons invisible\">\r\n  <button class=\"scroll-top btn btn-logout\">Do góry</button>\r\n  <button class=\"btn load-more\">Więcej albumów</button>\r\n</div>";});
}});

window.require.define({"views/templates/gallery/album": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<div id=\"feed-container\"></div>\n<div class=\"multi center action-buttons invisible std-v-dist\">\n  <button class=\"scroll-top btn btn-logout\">Do góry</button>\n  <button class=\"load-more btn btn-logout\">Pokaż więcej</button>\n</div>";});
}});

window.require.define({"views/templates/header": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<div class=\"container topbar\">\n  <div class=\"brand\">\n    <a href=\"#\" title=\"NK.pl\">\n      <span class=\"backbutton hidden\">\n        <img src=\"images/back.png\" alt=\"wstecz\" width=\"13\">\n      </span>\n      <img class=\"logo\" src=\"images/logo.png\" alt=\"NK.pl\" width=\"36\" height=\"27\">\n    </a>\n  </div>\n  <div class=\"action-button pull-right\"></div> <!-- czyli tu w srodku np. button wyloguj wpadnie -->\n  <div class=\"pull-right\">\n    <a class=\"btn btn-danger btn-refresh hidden\"><img src=\"images/loader_mobile_1_100x100px.png\" alt=\"odśwież\" height=\"50\" width=\"50\"></a>\n    <a class=\"btn btn-danger refresh-info hidden disabled\"><img src=\"images/loader_mobile_2_100x100px.gif\" alt=\"ładowanie\"  height=\"50\" width=\"50\"></a>\n  </div>\n  <div class=\"fix-android-blur-image\">&nbsp;</div>\n  \n</div>";});
}});

window.require.define({"views/templates/login": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<form class=\"form-signin\">\n  <fieldset>\n    <img src=\"images/logo_b.png\" width=\"88\">\n    <!-- ಠ_ಠ -->\n    <input type=\"text\" autocorrect=\"off\" autocapitalize=\"off\" autocomplete=\"off\" class=\"input-block-level login-input login\" placeholder=\"Login / E-mail\"/>\n    <input type=\"password\" class=\"input-block-level password-input login\" placeholder=\"Hasło\" autocomplete=\"off\"/>\n    <button type=\"submit\" class=\"btn btn-large timeout-disable trigger-timeout\">Zaloguj</button>\n  </fieldset>\n</form>\n\n\n";});
}});

window.require.define({"views/templates/mail-compose": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression;


    buffer += "<section class=\"collapsed-list std-frame\">\n  <div class=\"clearfix item\">\n    <a class=\"pull-left\" href=\"#profile/";
    foundHelper = helpers.comment_author_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_author_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n      <img class=\"img-polaroid\" width=\"40\" src=\"";
    stack1 = depth0.avatar;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    </a>\n    <div class=\"content\">\n      <a class=\"author\" href=\"#profile/";
    foundHelper = helpers.comment_author_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_author_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n      ";
    foundHelper = helpers.name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n      </a>\n    </div>\n  </div>\n</section>\n\n<form name=\"mail-compose\" class=\"mail-compose clear form_4_keyboard\" id=\"mail-compose\" data-user-id=";
    foundHelper = helpers.id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + ">\n  <textarea class=\"mail-content\" placeholder=\"Treść\"></textarea>\n  <button style=\"display: block; z-index: 999; position:absolute; bottom:0px; right:0px\" class=\"btn submit-button\" type=\"submit\">Wyślij</button>\n  <button style=\"display: block; z-index: 999; position:absolute; top: 212px; right:10px\" class=\"btn cancel-button\" type=\"button\">Anuluj</button>\n</form>";
    return buffer;});
}});

window.require.define({"views/templates/mail": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;


    buffer += "<ul class=\"maillist-container\">\n  <li class=\"clearfix read\">\n    <a class=\"pull-left\" href=\"#profile/";
    foundHelper = helpers.from_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.from_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n      <img class=\"img-polaroid\" width=\"40\" src=\"";
    foundHelper = helpers.sender_photo_uri;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.sender_photo_uri; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n    </a>\n    <div class=\"content\">\n      <span class=\"pull-right datetime\">\n        ";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "\n      </span>\n      <span class=\"author\">\n        ";
    foundHelper = helpers.sender_name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.sender_name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n      </span>\n      <strong class=\"media-heading mail-title\">\n        ";
    foundHelper = helpers.title;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.title; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n      </strong>\n      <p>\n        ";
    foundHelper = helpers.body;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.body; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n      </p>\n    </div>\n  </li>\n\n\n</ul>\n\n<section class=\"std-frame std-v-dist std-padd bg-white\">\n  <form name=\"mail-compose\" class=\"one-line-form mail-compose\" id=\"mail-compose\" data-user-id=";
    foundHelper = helpers.from_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.from_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + ">\n    <button type=\"submit\" class=\"btn pull-right\"><strong>Wyślij</strong></button>\n    <div class=\"input-spreader\">\n      <input class=\"input-medium mail-content input-blur-top\" type=\"text\" placeholder=\"Odpowiedz\"/>\n    </div>\n  </form>\n</section>\n";
    return buffer;});
}});

window.require.define({"views/templates/mailbox": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<ul id=\"maillist-container\" class=\"maillist-container std-frame clearlist\"></ul>\n<div class=\"btm-btn multi action-buttons invisible\">\n  <button class=\"scroll-top btn btn-logout\">Do góry</button>\n  <button class=\"btn load-more\">Poprzednie wiadomości</button>\n</div>";});
}});

window.require.define({"views/templates/maillist": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var stack1, self=this, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;

  function program1(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n<li class=\"clearfix ";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.is_read;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(2, program2, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\">\n  <a class=\"pull-left\" data-id=";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + " href=\"#mail/";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    <img class=\"media-object img-polaroid\" width=\"40\" src=\"";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.sender_photo_uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n  </a>\n  <a class=\"content\" data-id=";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + " href=\"#mail/";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.id;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n      <span class=\"pull-right datetime\">\n        ";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "\n      </span>\n      <span class=\"author\">\n        ";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.sender_name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\n      </span>\n      <span class=\"title\">\n        ";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.title;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n      </span>\n      <p>";
    stack1 = depth0.attributes;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.body;
    foundHelper = helpers.text_cut;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, 50, {hash:{}}) : helperMissing.call(depth0, "text_cut", stack1, 50, {hash:{}});
    buffer += escapeExpression(stack1) + "</p><!-- to rypnac helperem do skracania -->\n  </a>\n   \n</li>\n";
    return buffer;}
  function program2(depth0,data) {
    
    
    return "read";}

    stack1 = depth0.mails;
    stack1 = helpers.each.call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(1, program1, data)});
    if(stack1 || stack1 === 0) { return stack1; }
    else { return ''; }});
}});

window.require.define({"views/templates/menu": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers; partials = partials || Handlebars.partials;
    var buffer = "", stack1, self=this;


    buffer += "<div class=\"navbar navbar-inverse navbar-fixed-bottom\">\n  <div class=\"navbar-inner\"> \n    <ul class=\"nav\">\n      <li class=\"feed selected\"><a href=\"#\">\n        ";
    buffer += "\n        <img src=\"images/i_feed_on.png\" width=\"52\" alt=\"Feed\">\n      </a></li>\n      <li class=\"mail\"><a href=\"#poczta\">\n        ";
    buffer += "\n        <img src=\"images/i_msg.png\" width=\"52\" alt=\"Poczta\">\n      </a></li>\n      <li class=\"photo\"><a href=\"#zdjecie/dodaj\" title=\"Dodaj zdjęcie\">\n        ";
    buffer += "\n        <img src=\"images/i_photo.png\" width=\"56\" alt=\"Dodaj zdjęcie\">\n      </a></li>\n      <li class=\"friends\"><a href=\"#profile/";
    stack1 = depth0;
    stack1 = self.invokePartial(partials.logged_user_id, 'logged_user_id', stack1, helpers, partials);;
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "/friends\">\n        ";
    buffer += "\n        <img src=\"images/i_frnd.png\" width=\"52\" alt=\"Znajomi\">\n      </a></li>\n      <li class=\"profile\"><a href=\"#profile/";
    stack1 = depth0;
    stack1 = self.invokePartial(partials.logged_user_id, 'logged_user_id', stack1, helpers, partials);;
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\">\n        ";
    buffer += "\n        <img src=\"images/i_profile.png\" width=\"52\" alt=\"Profil\">\n      </a></li>\n    </ul>\n  </div>\n</div>\n<div class=\"popover top in\"><div class=\"arrow\"></div><div class=\"popover-inner\"><h3 class=\"popover-title\">Dodaj zdjęcie</h3><div class=\"popover-content\"><p><a class=\"btn btn-block btn-large btn-camera\" href=\"#photo/add/camera\">Aparat</a><a class=\"btn btn-block btn-large btn-album\" href=\"#photo/add/album\">Album</a></p></div></div></div>";
    return buffer;});
}});

window.require.define({"views/templates/modals/loading": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<div class=\"modal\">\n  loading\n</div>\n\n";});
}});

window.require.define({"views/templates/photo-upload": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<div class=\"photo_upload\">\r\n  <div class=\"photo_wrapper\">\r\n    <img id=\"photo\" src=\"\"/>\r\n  </div>\r\n  <div class=\"btn-group std-v-dist\">\r\n    <button id=\"turnLeft\" class=\"btn btn-large\"><i class=\"icon-arrow-left\"></i> W lewo</button>\r\n    <button id=\"upload\" class=\"btn btn-large\"><i class=\"icon-upload\"></i> Wyślij</button>\r\n    <button id=\"turnRight\" class=\"btn btn-large\">W prawo <i class=\"icon-arrow-right\"></i></button>\r\n  </div>\r\n</div>";});
}});

window.require.define({"views/templates/photo/comment": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;


    buffer += "<li class=\"clearfix item\">\n  <a class=\"pull-left\" href=\"#profile/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    <img class=\"img-polaroid\" width=\"40\" src=\"";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.avatar;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n  </a>\n  <div class=\"content\">\n    <span class=\"pull-right datetime\">\n    ";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "\n    </span>\n    <a class=\"author\" href=\"#profile/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    ";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\n    </a>\n    <span class=\"clear comment\">\n    ";
    foundHelper = helpers.content;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.content; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n    </span>\n  </div>\n</li>\n";
    return buffer;});
}});

window.require.define({"views/templates/photo/single": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, functionType="function", escapeExpression=this.escapeExpression, self=this;

  function program1(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n  <button class=\"btn btn-older-comments\">Wczytaj starsze komentarze (";
    foundHelper = helpers.count;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.count; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + ")</button>\n  ";
    return buffer;}

    buffer += "<section class=\"feed photo-content\"></section>\n\n<div class=\"center\">\n  ";
    stack1 = depth0.count;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(1, program1, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n\n  <button class=\"btn btn-block btn-older-comments\">Wczytaj poprzednie</button>\n</div>\n\n<section class=\"sub-content std-frame clearlist collapsed-list comments-list comment-list hidden\">\n</section>\n\n<section class=\"comment-add single-comment-add std-frame std-v-dist std-padd bg-white\">\n  <form class=\"one-line-form\">\n    <button type=\"submit\" class=\"btn pull-right\">Dodaj</button>\n    <div class=\"input-spreader\">\n      <input class=\"input-medium bottom\" name=\"comment\" type=\"text\" placeholder=\"Dodaj komentarz\"/>\n      <a name=\"comment_add_anchor\"></a>\n    </div>\n  </form>\n</section>\n<div style=\"height:5px;width:100%;\" class=\"comment-add-focus\">&nbsp;</div>";
    return buffer;});
}});

window.require.define({"views/templates/photo/stars": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;


    buffer += "<div class=\"stars\">\n  <a href=\"#profile/";
    foundHelper = helpers.author_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.author_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n    <img src=\"";
    foundHelper = helpers.author_photo_uri;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.author_photo_uri; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\" width=\"50\">\n    ";
    foundHelper = helpers.author_name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.author_name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n  </a>\n  <span>";
    stack1 = depth0.star_date;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "</span>\n</div>";
    return buffer;});
}});

window.require.define({"views/templates/profile-gallery": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<div class=\"bg-white std-frame std-v-dist std-padd\">\r\n  <p class=\"std-v-dist std-padd btm-btn\">\r\n    <br>\r\n    Ciężko pracujemy, by już wkrótce opublikować galerię.\r\n    <br><br>\r\n  </p>\r\n</div>";});
}});

window.require.define({"views/templates/profile": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing, self=this;

  function program1(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n        ";
    foundHelper = helpers.age;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.age; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + " lat(a),\n      ";
    return buffer;}

  function program3(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n        ";
    foundHelper = helpers.city;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.city; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + ",\n      ";
    return buffer;}

  function program5(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n        ";
    stack1 = depth0.gender;
    foundHelper = helpers.gender;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "gender", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "</li>\n      ";
    return buffer;}

  function program7(depth0,data) {
    
    
    return "\n    ";}

  function program9(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n      ";
    stack1 = depth0.is_friend;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.program(12, program12, data),fn:self.program(10, program10, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n      <a href=\"#mail/";
    foundHelper = helpers.id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/compose\" class=\"btn std-v-dist profile-action compose-mail-button timeout-disable trigger-timeout\">Wyślij wiadomość</a>\n    ";
    return buffer;}
  function program10(depth0,data) {
    
    
    return "\n        <!-- don't show add friend buttton -->\n      ";}

  function program12(depth0,data) {
    
    
    return "\n        <a href=\"#\" class=\"btn std-v-dist add-friend profile-action timeout-disable trigger-timeout\">Dodaj do znajomych</a>\n      ";}

  function program14(depth0,data) {
    
    var buffer = "", stack1, foundHelper;
    buffer += "\n      <a class=\"btn\" href=\"tel:";
    foundHelper = helpers.phone_number;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.phone_number; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">Zadzwoń</a>\n      \n      O sobie\n      ";
    foundHelper = helpers.description;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.description; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n      \n      Czym się aktualnie zajmuję\n      ";
    foundHelper = helpers.job;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.job; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n    ";
    return buffer;}

  function program16(depth0,data) {
    
    
    return "\n  <a href=\"#\" class=\"btn btn-logout btn-primary\">Wyloguj</a>\n  ";}

    buffer += "\n  <div class=\"media\">\n    <a class=\"pull-left\" href=\"/profile/";
    foundHelper = helpers.id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\"><img class=\"media-object img-polaroid\" data-src=\"";
    stack1 = depth0.avatar;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\" src=\"";
    stack1 = depth0.avatar;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\" width=\"100\"></a>\n    <h4 class=\"media-heading\">";
    foundHelper = helpers.name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "</h4>\n    <p class=\"specs\">\n      ";
    stack1 = depth0.age;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(1, program1, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n      ";
    stack1 = depth0.city;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(3, program3, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n      ";
    stack1 = depth0.gender;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(5, program5, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n    </p>\n\n\n  \n    <ul class=\"nav\" style=\"top:41px; left: 0; right: 0; z-index:10\">\n      <!-- <li>\n        <a href=\"#profile/";
    foundHelper = helpers.id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/comments\">komentarze</a>\n      </li> -->\n      <li>\n        <a href=\"#profile/";
    foundHelper = helpers.id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/friends\">znajomi</a>\n      </li>\n      <li>\n        <a href=\"#profile/";
    foundHelper = helpers.id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "/gallery\">galeria</a>\n      </li>\n    </ul>\n  </div>\n  \n  <div class=\"center\">\n    ";
    stack1 = depth0.id;
    foundHelper = helpers.my_profile;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{},inverse:self.program(9, program9, data),fn:self.program(7, program7, data)}) : helperMissing.call(depth0, "my_profile", stack1, {hash:{},inverse:self.program(9, program9, data),fn:self.program(7, program7, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n  </div>\n    \n  <!--\n    ";
    stack1 = depth0.phone_number;
    stack1 = helpers['if'].call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(14, program14, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n  --> \n  <section class=\"comment-add\">\n    <form id=\"form-comment-add\" class=\"one-line-form\">\n      <button type=\"submit\" class=\"btn pull-right timeout-disable trigger-timeout\">Dodaj</button>\n      <div class=\"input-spreader\">\n        <input class=\"input-medium comment-content timeout-disable input-blur-top\" type=\"text\" placeholder=\"Dodaj komentarz\"/>\n      </div>\n    </form>\n  </section>\n  \n\n\n<ul class=\"sub-content profile-comments std-frame clearlist collapsed-list comment-list hidden\">\n</ul>\n\n<div class=\"btm-btn\">\n  <button class=\"btn btn-older-comments\">Wczytaj starsze komentarze</button>\n</div>\n\n\n\n\n\n        \n  <div class=\"logout\">\n  ";
    stack1 = depth0.id;
    foundHelper = helpers.my_profile;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{},inverse:self.noop,fn:self.program(16, program16, data)}) : helperMissing.call(depth0, "my_profile", stack1, {hash:{},inverse:self.noop,fn:self.program(16, program16, data)});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n  </div>\n";
    return buffer;});
}});

window.require.define({"views/templates/profile/comment": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;


    buffer += "<li class=\"clearfix item\">\n  <a class=\"pull-left\" href=\"#profile/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n    <img class=\"img-polaroid\" width=\"40\" src=\"";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.avatar;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uri;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n  </a>\n  <div class=\"content\">\n    <a class=\"author\" href=\"#profile/";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.uid;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\">\n  	";
    stack1 = depth0.author;
    stack1 = stack1 == null || stack1 === false ? stack1 : stack1.name;
    stack1 = typeof stack1 === functionType ? stack1() : stack1;
    buffer += escapeExpression(stack1) + "\n    </a>\n    <span class=\"datetime\">\n  	";
    stack1 = depth0.datetime;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "\n    </span>\n    <span class=\"clear comment\">\n  	";
    stack1 = depth0.content;
    foundHelper = helpers.nl2br;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "nl2br", stack1, {hash:{}});
    if(stack1 || stack1 === 0) { buffer += stack1; }
    buffer += "\n    </span>\n  </div>\n</li>";
    return buffer;});
}});

window.require.define({"views/templates/shout/comment": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;


    buffer += "<li class=\"clearfix item\">\n  <a class=\"pull-left\" href=\"#profile/";
    foundHelper = helpers.comment_author_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_author_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n    <img class=\"img-polaroid\" width=\"40\" src=\"";
    foundHelper = helpers.comment_author_photo_uri;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_author_photo_uri; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n  </a>\n  <div class=\"content\">\n    <span class=\"pull-right datetime\">\n    ";
    stack1 = depth0.timestamp;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "\n    </span>\n    <a class=\"author\" href=\"#profile/";
    foundHelper = helpers.comment_author_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_author_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n    ";
    foundHelper = helpers.comment_author_name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_author_name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n    </a>\n    <span class=\"clear comment\">\n    ";
    foundHelper = helpers.content;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.content; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n    </span>\n  </div>\n</li>";
    return buffer;});
}});

window.require.define({"views/templates/shout/single": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    


    return "<section class=\"feed shout-content\">\n</section>\n\n<div class=\"center\">\n  <button class=\"btn btn-older-comments\">Wczytaj starsze komentarze</button>\n</div>\n\n<ul class=\"sub-content std-frame clearlist collapsed-list comment-list hidden\">\n</ul>\n\n<div class=\"center std-v-dist std-padd\">\n  <button class=\"btn btn-older-stars\">Wczytaj starsze gwiazdki</button>\n</div>\n\n<section class=\"comment-add single-comment-add std-frame std-v-dist std-padd bg-white\">\n  <form class=\"one-line-form\">\n    <button type=\"submit\" class=\"btn pull-right\">Dodaj</button>\n    <div class=\"input-spreader\">\n      <input class=\"input-medium bottom\" name=\"comment\" type=\"text\" placeholder=\"Dodaj komentarz\"/>\n    </div>\n  </form>\n</section>\n\n<div style=\"margin-top:5px\" class=\"comment-add-focus\"></div>";});
}});

window.require.define({"views/templates/shout/stars": function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, functionType="function", escapeExpression=this.escapeExpression, helperMissing=helpers.helperMissing;


    buffer += "<li class=\"clearfix item stars\">\n  <a class=\"pull-left\" href=\"#profile/";
    foundHelper = helpers.author_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.author_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n    <img class=\"img-polaroid\" width=\"40\" src=\"";
    foundHelper = helpers.author_photo_uri;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.author_photo_uri; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n  </a>\n  <div class=\"content\">\n    <span class=\"pull-right datetime\">\n    ";
    stack1 = depth0.star_date;
    foundHelper = helpers.polish_date;
    stack1 = foundHelper ? foundHelper.call(depth0, stack1, {hash:{}}) : helperMissing.call(depth0, "polish_date", stack1, {hash:{}});
    buffer += escapeExpression(stack1) + "\n    </span>\n    <a class=\"author\" href=\"#profile/";
    foundHelper = helpers.comment_author_id;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.comment_author_id; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\">\n    ";
    foundHelper = helpers.author_name;
    if (foundHelper) { stack1 = foundHelper.call(depth0, {hash:{}}); }
    else { stack1 = depth0.author_name; stack1 = typeof stack1 === functionType ? stack1() : stack1; }
    buffer += escapeExpression(stack1) + "\n    </a>\n  </div>\n</li>";
    return buffer;});
}});

